#
# spec file for package yast2-installation
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           yast2-installation
Version:        3.2.50
Release:        2.3.1

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        %{name}-%{version}.tar.bz2

Url:            http://github.com/yast/yast-installation
# new y2start script
Requires:       yast2-ruby-bindings >= 3.2.10

Summary:        YaST2 - Installation Parts
License:        GPL-2.0
Group:          System/YaST

Source1:        YaST2-Second-Stage.service
Source2:        YaST2-Firstboot.service

BuildRequires:  update-desktop-files
BuildRequires:  yast2-devtools >= 3.1.10
# needed for xml agent reading about products
BuildRequires:  yast2-xml
BuildRequires:  rubygem(rspec)
BuildRequires:  rubygem(yast-rake)

# CWM::RadioButtons#vspacing
BuildRequires:  yast2 >= 3.2.20

# AutoinstSoftware.SavePackageSelection()
Requires:       autoyast2-installation >= 3.1.105

# PackageDownloader and PackageExtractor
Requires:       yast2 >= 3.2.19

# Language::GetLanguageItems and other API
# Language::Set (handles downloading the translation extensions)
Requires:       yast2-country-data >= 2.16.11

# Pkg::ProvidePackage
Requires:       yast2-pkg-bindings >= 3.1.33

# Mouse-related scripts moved to yast2-mouse
Conflicts:      yast2-mouse < 2.18.0

# Lazy loading in ProductLicense
Requires:       yast2-packager >= 3.1.113

# Storage::GetDetectedDiskPaths
Requires:       yast2-storage >= 2.24.1

# use in startup scripts
Requires:       initviocons

# Proxy settings for 2nd stage (bnc#764951)
Requires:       yast2-proxy

# Systemd default target and services. This version supports
# writing settings in the first installation stage.
Requires:       yast2-services-manager >= 3.2.1

## Moved inst_install_inf from yast2-network to this package
Requires:       yast2-network >= 3.2.25

# Augeas lenses
Requires:       augeas-lenses

# Only in inst-sys
# Requires:	yast2-add-on
# Requires:	yast2-update

# new root password cwm widget
BuildRequires:  yast2-users >= 3.2.8
Requires:       yast2-users >= 3.2.8
# new keyboard layout cwm widget
BuildRequires:  yast2-country >= 3.2.7
Requires:       yast2-country >= 3.2.7

# Pkg::SourceProvideSignedFile Pkg::SourceProvideDigestedFile
# pkg-bindings are not directly required
Conflicts:      yast2-pkg-bindings < 2.17.25

# InstError
Conflicts:      yast2 < 2.18.6

# lower version requires perl-Bootloader-YAML no longer installed
Conflicts:      yast2-bootloader < 3.1.166

# Added new function WFM::ClientExists
Conflicts:      yast2-core < 2.17.10

# Top bar with logo
Conflicts:      yast2-ycp-ui-bindings < 3.1.7

# Registration#get_updates_list does not handle exceptions
Conflicts:      yast2-registration < 3.2.3

Obsoletes:      yast2-installation-devel-doc

# tar-gzip some system files and untar-ungzip them after the installation (FATE #300421, #120103)
Requires:       coreutils
Requires:       gzip
Requires:       tar

%if 0%{?suse_version} >= 1210
%{systemd_requires}
%endif

# for the first/second stage of installation
# currently not used
# bugzilla #208307
#Requires:	/usr/bin/jpegtopnm
#Requires:	/usr/bin/pnmtopng

# BNC 446533, /sbin/lspci called but not installed
Requires:       pciutils

# install the registration module only in SLE (bsc#1043122)
%if !0%{?is_opensuse}
Recommends:     yast2-registration
%endif

Recommends:     yast2-online-update
Recommends:     yast2-firewall
Recommends:     release-notes
Recommends:     curl
Recommends:     yast2-update
Recommends:     yast2-add-on

PreReq:         %fillup_prereq

BuildArch:      noarch

%description
System installation code as present on installation media.

%prep
%setup -n %{name}-%{version}

%check
rake test:unit

%build

%install
rake install DESTDIR="%{buildroot}"

for f in `find %{buildroot}%{_datadir}/autoinstall/modules -name "*.desktop"`; do
    %suse_update_desktop_file $f
done

mkdir -p %{buildroot}%{yast_vardir}/hooks/installation
mkdir -p %{buildroot}%{yast_ystartupdir}/startup/hooks/preFirstCall
mkdir -p %{buildroot}%{yast_ystartupdir}/startup/hooks/preSecondCall
mkdir -p %{buildroot}%{yast_ystartupdir}/startup/hooks/postFirstCall
mkdir -p %{buildroot}%{yast_ystartupdir}/startup/hooks/postSecondCall
mkdir -p %{buildroot}%{yast_ystartupdir}/startup/hooks/preFirstStage
mkdir -p %{buildroot}%{yast_ystartupdir}/startup/hooks/preSecondStage
mkdir -p %{buildroot}%{yast_ystartupdir}/startup/hooks/postFirstStage
mkdir -p %{buildroot}%{yast_ystartupdir}/startup/hooks/postSecondStage

mkdir -p %{buildroot}%{_unitdir}
install -m 644 %{SOURCE1} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE2} %{buildroot}%{_unitdir}

%post
%{fillup_only -ns security checksig}

%if 0%{suse_version} > 1140

%service_add_post YaST2-Second-Stage.service YaST2-Firstboot.service

# bsc#924278 Always enable these services by default, they are already listed
# in systemd-presets-branding package, but that works for new installations
# only, it does not work for upgrades from SLE 11 where scripts had different
# name and were not handled by systemd.
# When we upgrade/update from systemd-based system, scripts are always enabled
# by the service_add_post macro.
systemctl enable YaST2-Second-Stage.service
systemctl enable YaST2-Firstboot.service

%pre
%service_add_pre YaST2-Second-Stage.service YaST2-Firstboot.service

%preun
%service_del_preun YaST2-Second-Stage.service YaST2-Firstboot.service

%postun
%service_del_postun YaST2-Second-Stage.service YaST2-Firstboot.service

%endif #suse_version

%files
%defattr(-,root,root)

# systemd service files
%{_unitdir}/YaST2-Second-Stage.service
%{_unitdir}/YaST2-Firstboot.service

%{yast_clientdir}/*.rb
%{yast_moduledir}/*.rb
%{yast_desktopdir}/*.desktop
/usr/share/autoinstall/modules/*.desktop
/usr/share/YaST2/schema/autoyast/rnc/deploy_image.rnc
/usr/share/YaST2/schema/autoyast/rnc/ssh_import.rnc
%dir /usr/share/autoinstall
%dir /usr/share/autoinstall/modules
%dir %{yast_yncludedir}/installation
%{yast_yncludedir}/installation/*
%{yast_libdir}/installation
%{yast_libdir}/transfer

# agents
%{yast_scrconfdir}/etc_passwd.scr
%{yast_scrconfdir}/cfg_boot.scr
%{yast_scrconfdir}/cfg_windowmanager.scr
%{yast_scrconfdir}/cfg_fam.scr
%{yast_scrconfdir}/etc_install_inf.scr
%{yast_scrconfdir}/etc_install_inf_alias.scr
%{yast_scrconfdir}/etc_install_inf_options.scr
%{yast_scrconfdir}/run_df.scr
# fillup
/var/adm/fillup-templates/sysconfig.security-checksig

# programs and scripts
%{yast_ystartupdir}/startup

# installation hooks
%dir %{yast_vardir}/hooks
%dir %{yast_vardir}/hooks/installation

%dir %{yast_docdir}
%doc %{yast_docdir}/COPYING
%doc %{yast_docdir}/README.md
%doc %{yast_docdir}/CONTRIBUTING.md

%changelog
* Thu Jan 18 2018 qzhao@suse.com
- Update YaST2-Firstboot.service: Depreciate plymouth --wait, add
  conflict to plymouth start service.
- Update YaST2-Second-Stage.service: Depreciate plymouth deactivate
  command and add conflict to plymouth start service. For that will
  block TTY device activation(bsc#1042554).
- 3.2.50
* Thu Aug 17 2017 shundhammer@suse.de
- Merged SLE-12-SP2-CASP branch to SLE-12-SP3 branch:
  Make filesystem type for home and root configurable in control.xml
  (bsc#1051762)
- 3.2.49
* Tue Aug  8 2017 shundhammer@suse.de
- Merged SLE-12-SP2-CASP branch to SLE-12-SP3 branch (bsc#1051200)
- 3.2.48
* Thu Jun 29 2017 jreidinger@suse.com
- openSUSE only: reword title of desktop selection dialog
  (boo#1045180)
- 3.2.47
* Thu Jun 29 2017 jreidinger@suse.com
- openSUSE only: when custom role is selected in desktop selection
  keep default value in /etc/sysconfig/windowmanager (bsc#1030873)
- 3.2.46
* Mon Jun 26 2017 shundhammer@suse.de
- Allow different mount point for home partition (Fate#323532)
- Move remaining CaaSP specific code to yast2-caasp package
  (bsc#1036838)
* Mon Jun 19 2017 lslezak@suse.cz
- install the yast2-registration package only in SLE (bsc#1043122)
- 3.2.45
* Thu Jun  1 2017 schubi@suse.de
- "custom" roles: Initialize pattern selection screen with settings
  defined in the control files. (bnc#1031295)
- 3.2.44
* Wed May 31 2017 knut.anderssen@suse.com
- Do not lose the desktop selection when the online repositories is
  pressed. (bsc#1033594)
- Do not allow to continue without desktop selection. (bsc#1040884)
- 3.2.43
* Wed May 31 2017 lslezak@suse.cz
- Fixed path to the "adddir" command (it is /sbin instead of /etc)
  (bsc#1041882)
- 3.2.42
* Mon May 29 2017 knut.anderssen@suse.com
- Added requirement of 'cwm/widget' in hiding_place as consequence
  of changes made in CWM. (boo#1039901).
- 3.2.41
* Mon May 22 2017 lslezak@suse.cz
- Fixed push button label ("Configure Online Repositories")
  (bsc#1039988)
- 3.2.40
* Mon May  8 2017 knut.anderssen@suse.com
- Don't crash if the regurl provided by linuxrc is invalid using
  the one provided by the control file as fallback (bsc#1035908).
- 3.2.39
* Wed Apr 26 2017 igonzalezsosa@suse.com
- Move CaaSP specific code to yast2-caasp package
  (bsc#1036838)
- 3.2.38
* Wed Apr 26 2017 gsouza@suse.com
- bsc#1031840
  - changed CheckFreeSpaceNow to use LANG=en_US.UTF-8
* Thu Apr 20 2017 igonzalezsosa@suse.com
- Add a NTP Servers settings to the overview dialog
  (FATE#323249)
* Wed Apr  5 2017 jreidinger@suse.com
- Use y2start script instead of y2base (bsc#1027181)
- 3.2.37
* Wed Apr  5 2017 schubi@suse.de
- Added configuration-management to inst_finish.
  (FATE#319830)
- 3.2.36
* Tue Apr  4 2017 mvidner@suse.com
- Renamed Controller Node to Administration Node (bsc#1032057).
- 3.2.35
* Mon Mar 27 2017 igonzalezsosa@suse.com
- Move CaaSP specific code to yast2-caasp (bsc#1030874)
- 3.2.34
* Mon Mar 27 2017 lslezak@suse.cz
- Use the shared package download and extraction functionality
  from FATE#320772
- 3.2.33
* Tue Mar 21 2017 ancor@suse.com
- Added some extra space to the openSUSE desktop/roles selection
  dialog (improvement on the fix for poo#14936, bsc#1025415).
- 3.2.32
* Thu Mar 16 2017 mvidner@suse.com
- Allow proceeding with the installation after a blocking condition
  has been corrected in the overview dialog (bsc#1029291).
- 3.2.31
* Wed Mar 15 2017 igonzalezsosa@suse.com
- Improve roles buttons distribution in textmode (related to
  FATE#320772)
- 3.2.30
* Tue Mar 14 2017 igonzalezsosa@suse.com
- Fix desktop selection during installation (bsc#1029312)
- 3.2.29
* Mon Mar 13 2017 igonzalezsosa@suse.com
- Support to add roles through addons (FATE#320772)
- 3.2.28
* Thu Mar  9 2017 jreidinger@suse.com
- fix crash when reading if desktop role should have default
  pre-selected (bsc#1025415)
- 3.2.27
* Wed Mar  8 2017 mvidner@suse.cz
- Really use the directory.yast file (fate#322372)
- 3.2.26
* Mon Mar  6 2017 mfilka@suse.com
- fate#322328
  - adapted all-in-one dialog according to comments from UX
- 3.2.25
* Mon Mar  6 2017 mfilka@suse.com
- CaaSP: do not crash when used a dashed url for the controller
  node location (bsc#1024965)
- CaaSP AY: Adapted requirements of yast2-services-manager.
  (FATE#321738)
- bnc#1022546
  - update all-in-one's subdialog (network/kdump/partitioning/...)
    overview when the dialog is closed and do not lose another
    content already entered by user.
- 3.2.24
* Wed Feb 15 2017 jreidinger@suse.com
- Add new desktop selection client for opensuse based on roles
  (poo#14936, bsc#1025415)
- drop "inst_new_desktop" client which was replaced by new desktop
  selection one
- 3.2.23
* Tue Feb 14 2017 igonzalezsosa@suse.com
- Self-Update only shows errors when a custom URL is used
  (bsc#1025251)
- 3.2.22
* Wed Feb  8 2017 kanderssen@suse.com
- CaaSP all-in-one-dialog: added validation to the controller node
  location field, modified label and write it to the minion
  master.conf file at the end of the installation (FATE#321738)
- CaaSP: Display the Beta product warning at start when it is
  present (bsc#1016887)
- Enable CaaSP specific services on the installed system
  (FATE#321738)
- Do not crash if role contain own service to enable (bsc#1022762)
- 3.2.21
* Fri Feb  3 2017 jsrain@suse.cz
- Downloading release notes: Do not download them at all during
  AutoYaST (bsc#1009276)
- Use the directory.yast file to check avilable
  translations (fate#322372)
- 3.2.20
* Wed Feb  1 2017 schubi@suse.de
- Downloading release notes: Do not try again if the host or the
  proxy cannot be resolved (bnc#1022784)
- 3.2.19
* Fri Jan 27 2017 kanderssen@suse.com
- Ask for installation confirmation in all-in-one dialog before
  proceed with it. (Fate#322328)
- 3.2.18
* Fri Jan 27 2017 jreidinger@suse.com
- Respect newly registered update repos in software proposal and
  do register. (FATE#322328)
* Thu Jan 26 2017 jreidinger@suse.com
- handle proposal errors in all-in-one dialog (FATE#322328)
* Wed Jan 25 2017 mvidner@suse.com
- Added an all-in-one installation overview for CaaSP (FATE#322328)
* Wed Jan 25 2017 igonzalezsosa@suse.com
- Add an option to disable the self-update feature through the
  AutoYaST profile (FATE#319716)
- 3.2.17
* Fri Jan 20 2017 mfilka@suse.com
- bnc#1017752
  - do not show language change warning in software proposal
    incorrectly when language was not changed.
- 3.2.16
* Tue Jan 17 2017 igonzalezsosa@suse.com
- Do not retry to download release notes if a previous attempt
  failed (bsc#1015794)
- 3.2.15
* Mon Jan 16 2017 jreidinger@suse.com
- add ability to roles to enable list of services when selected
  (FATE#321754)
* Mon Jan 16 2017 mfilka@suse.com
- fate#321739
  - Made user's interaction possible in case of error in read-only
    proposal.
- 3.2.14
* Thu Jan  5 2017 schubi@suse.de
- AutoYaST after second stage: Initialize tty1 in order to remove
  old YaST output and to show the cursor again.
  (bnc#1018037)
- 3.2.13
* Wed Dec 14 2016 jreidinger@suse.com
  Port changes from CASP1.0:
- Change layout of new installation dialog according to UX team
  suggestion (FATE#321754)
- Set root subvolume read-only if configured (Fate##321755)
- Document new control.xml parameter root_subvolume_read_only
- Add new installation dialog with keyboard layout and root
  password (FATE#321754)
- Added worker role dialog (Fate#321754)
- implement support for running additional dialogs for specific
  roles (FATE#321754)
- Added description for readonly_timezone and
  clone_install_recommended_default flag in control-file
  documentation. (Fate#321754, Fate#321764)
- 3.2.12
* Wed Dec  7 2016 igonzalezsosa@suse.com
- Do not crash when the proposal screen is configured through
  an AutoYaST profile and tabs are not being used (bsc#1013976)
- 3.2.11
* Tue Nov 22 2016 jreidinger@suse.com
- fix missing icon next to SSH Key Import in autoyast
  (bsc#988377)
* Fri Nov 18 2016 jreidinger@suse.com
- add missing file causing crash (introduced with generic fix of
  bsc#1003682)
  (invisible in master since autotools support is dropped there)
- 3.2.10
* Thu Nov 17 2016 shundhammer@suse.de
- Documentation for new storage related parameters in control.xml
  (Fate#321736)
* Mon Nov 14 2016 jreidinger@suse.com
- The user has to confirm when the configuration proposal contains
  a non-blocking error (generic fix for bsc#1003682)
- 3.2.9
* Fri Nov 11 2016 schubi@suse.de
- Fixed bug: AutoYaST hangs while running second stage.
  Removed network.service in the Before section of
  YaST2-Firstboot.service. (bnc#1007752)
- 3.2.8
* Fri Nov 11 2016 jreidinger@suse.com
- Do not crash if importing ssh config from system which
  /etc/os-release does not contain pretty name (bsc#1009492)
- 3.2.7
* Mon Oct 31 2016 lslezak@suse.cz
- Added support for read-only proposal modules (fate#321739)
- 3.2.6
* Thu Oct 27 2016 shundhammer@suse.de
- Documentation for subvolumes in control.xml (fate#321737)
* Thu Oct 20 2016 jreidinger@suse.com
- more robust password filtering in y2start.log
  (bsc#798966)
- 3.2.5
* Thu Oct 13 2016 igonzalezsosa@suse.com
- Set libyui-ncurses environment before starting the installer
  (related to bsc#780621)
- 3.2.4
* Thu Oct 13 2016 igonzalezsosa@suse.com
- Bump version number to release fixes for bnc#999895,
  bsc#988700 and bnc#999953.
- 3.2.3
* Thu Oct  6 2016 schubi@suse.de
- AutoYaST upgrade: Do not override the Report module settings in
  the AutoYaST upgrade mode, keep the previous settings
  (bnc#999895).
* Thu Sep 29 2016 igonzalezsosa@suse.com
- Translate description of Snapper snapshots (bsc#988700)
- 3.2.2
* Wed Sep 21 2016 schubi@suse.de
- Fixed crash if one defined proposal module has not been found on
  system while switching back from "Expert" proposal.
  (bnc#999953)
- 3.2.1
* Wed Sep 14 2016 jreidinger@suse.com
- reduce time needed for building this package
- 3.2.0
* Tue Sep 13 2016 jreidinger@suse.com
- fix skipping of proposal returning empty hash otherwise it
  creates non sense proposal entry in UI (bnc#994127)
- 3.1.215
* Tue Aug 30 2016 lslezak@suse.cz
- Display a warning popup when the installer self-update uses
  the fallback URL instead of the selected SMT or the default SCC
  server (bsc#996179)
- Do not contact the registration server in self-update when
  network is not running, skip self-update completely
- 3.1.214
* Thu Aug 25 2016 lslezak@suse.cz
- Move the installer self update step earlier in the workflow
  so the user entered values are not lost after restart and avoid
  repeating some steps again (bsc#985055)
- This also fixes losing some values due to restaring YaST (bsc#993690),
  (bsc#992608)
- Improved the self update URL handling - the boot parameter has
  the highest priority, always ask user when a SLP service is found,
  in AutoYaST mode SLP needs to be enabled in the profile
- Display progress when downloading and applying the updates
- 3.1.213
* Thu Aug 25 2016 cwh@suse.com
- Replace unicode bullet char by asterisk for ncurses (bsc#995082)
- 3.1.212
* Thu Aug 25 2016 jreidinger@suse.com
- fix writing proposals (bnc#994127)
- 3.1.211
* Wed Aug 17 2016 jreidinger@suse.com
- filter out same repositories from extraurls if they differ only
  in trailing slash (bnc#970488)
- 3.1.210
* Tue Aug 16 2016 kanderssen@suse.com
- SSH Importer: Width fix to avoid cut of CheckBoxFrame Label
  (fate##319624)
- 3.1.209
* Tue Aug 16 2016 locilka@suse.com
- Fixed testsuite for inst_complex_welcome after implementing lazy
  loading in ProductLicense in yast2-packager (bsc#993285)
- 3.1.208
* Fri Aug  5 2016 igonzalezsosa@suse.com
- Fix the registration screen initialization when SCC server
  is used during self-update (FATE#319716)
- 3.1.207
* Thu Aug  4 2016 igonzalezsosa@suse.com
- Retrieve the self-update URL from the registration
  server (SCC/SMT) (FATE#319716)
- 3.1.206
* Wed Aug  3 2016 locilka@suse.com
- UI, UX and internal handling for the Welcome screen optimized to
  prevent from not showing that the license needs to be accepted
  (bsc#980374).
- 3.1.205
* Fri Jul 29 2016 ancor@suse.com
- If the user has skipped multipath activation, don't ask again
  after installer self-update (bsc#989770)
- 3.1.204
* Fri Jul 22 2016 igonzalezsosa@suse.com
- Don't halt the installation if installer updates server
  cannot be reached when using AutoYaST (bsc#988949)
- 3.1.203
* Thu Jul 21 2016 jreidinger@suse.com
- simplify and speed up inst_finish client (bnc#986649)
- add test suite for inst_finish client
- 3.1.202
* Mon Jul 18 2016 lslezak@suse.cz
- Run extra inst-sys cleanup to free more memory on systems with
  low memory (bsc#974601)
- 3.1.201
* Thu Jul 14 2016 lslezak@suse.cz
- Properly adjust the OOM killer (oom_score_adj has a different
  range than the original oom_adj) (bsc#974601)
- 3.1.200
* Tue Jul 12 2016 schubi@suse.de
- Added AutoYaST schema file "ssh_import".
  (fate#319624)
- 3.1.199
* Mon Jun 27 2016 jreidinger@suse.com
- Make writing of bootloader settings the last step so that other
  installation steps (kdump, cio-ignore) do not have to waste time
  repeating it
  (bnc#986649)
- 3.1.198
* Thu Jun 23 2016 lslezak@suse.cz
- Display more information in the error popup when downloading
  the optional installer updates fails (bsc#986091)
- 3.1.197
* Thu Jun 16 2016 igonzalezsosa@suse.com
- Avoid restarting YaST when self-update repository exists but
  is empty (bsc#985113)
- 3.1.196
* Wed Jun 15 2016 snwint@suse.de
- call set_videomode to adjust video mode (bsc#974821)
- 3.1.195
* Tue Jun 14 2016 igonzalezsosa@suse.com
- Fix architecture detection during self-update (bsc#984656)
- 3.1.194
* Thu Jun  2 2016 schubi@suse.de
- Adapt AutoYaST to support import of SSH server keys/configuration
  (fate#319624)
- 3.1.193
* Thu Jun  2 2016 igonzalezsosa@suse.com
- Drop yast2-installation-devel-doc package (fate#320356)
- 3.1.192
* Wed Jun  1 2016 igonzalezsosa@suse.com
- When importing SSH keys/configuration, only regular files
  will be considered (bsc#982522)
- Force YaST2-Firstboot.service to run after
  YaST2-Second-Stage.service (bsc#980365)
- 3.1.191
* Mon May 30 2016 lslezak@suse.cz
- Move the debugger invocation code to yast2-ruby-bindings package
  to use the same implementation at run time (FATE#318421)
- 3.1.190
* Thu May 26 2016 kanderssen@suse.com
- System Role: centered dialog (ncurses).
* Wed May 25 2016 kanderssen@suse.com
- More visual improvements in the SSH keys importing proposal
  summary based on blog entry feedback. (Fate#319624)
- 3.1.189
* Wed May 25 2016 lslezak@suse.cz
- Start the Ruby debugger at the beginning of installation
  when Y2DEBUGGER is set (FATE#318421)
- 3.1.188
* Tue May 17 2016 ancor@suse.com
- Visual improvement in the SSH keys importing proposal summary
* Mon May 16 2016 ancor@suse.com
- The user is now informed about SSH keys to be reused (copied
  from a previous system) during system installation.
- The user can select a different partition (or none) to read the
  keys from and whether to also copy config files.
- SSH import functionality not longer depending from
  "copy_to_system" feature.
- Fate#319624
- 3.1.187
* Mon May 16 2016 lslezak@suse.cz
- SSH installation: handle closing the initial installation screen
  by the window manager close button (bsc#979499)
- 3.1.186
* Mon May  9 2016 schubi@suse.de
- Do not copy licenses from inst-sys to target system.
  Showing EULA location in the installed system.
  (fate#219341)
- 3.1.185
* Fri May  6 2016 jsrain@suse.cz
- get more texts for roles dialog from control file, allow
  a general label (bsc#974625)
- 3.1.184
* Thu May  5 2016 ancor@suse.com
- Always read the lists of local users in the previous system to
  have them available during user importing (part of fate#319624)
- 3.1.183
* Wed Apr 20 2016 knut.anderssen@suse.com
- Disk Activation step will be skipped in case of installer update
  success (bsc#974409)
- License agreement will be remembered in case of going back after
  a installer update.
- 3.1.182
* Tue Apr 19 2016 igonzalezsosa@suse.com
- Fix handling of license acceptance in welcome screen
  (bsc#975774)
- 3.1.181
* Fri Apr 15 2016 lslezak@suse.cz
- Run the automatic installer self update also in the AutoYaST
  mode, read the optional custom URL from the profile ("general" ->
  "self_update_url" node) (FATE#319716)
- 3.1.180
* Wed Apr 13 2016 mfilka@suse.com
- bsc#956473
  - improved formatting of network interfaces listing
- 3.1.179
* Tue Apr 12 2016 jreidinger@suse.com
- do not install perl-Bootloader-YAML on target system as it is no
  longer needed (FATE#317701)
- 3.1.178
* Mon Apr  4 2016 igonzalezsosa@suse.com
- Automatic update during installation will use Zypper repositories
  instead of Driver Update Disks (FATE#319716).
- 3.1.177
* Wed Mar 23 2016 cwh@suse.com
- Moved proc_modules.scr to yast2.rpm to avoid that yast-sound
  depends on yast-installation (bsc#972310)
- 3.1.176
* Tue Mar 15 2016 knut.anderssen@suse.com
- Added automatic update during installation (FATE#319716)
- 3.1.175
* Mon Mar 14 2016 mvidner@suse.com
- System Role: align labels (FATE#317481).
- System Role: pop-up if changing the role to a different one.
- 3.1.174
* Mon Mar 14 2016 igonzalezsosa@suse.com
- Moved Yast::Transfer::FileFromUrl here from yast2-update
  (FATE#319716).
- 3.1.173
* Fri Mar  4 2016 mvidner@suse.com
- Added a System Role step in the installation (FATE#317481).
- 3.1.172
* Mon Feb 29 2016 mfilka@suse.com
- bsc#956473
  - network interfaces listing shows all IPv4 / IPv6 addresses per
    device
- 3.1.171
* Fri Feb 26 2016 ancor@suse.com
- Ensure plymouth does not interfere with X11 when executing
  yast2-firstboot (bsc#966874)
- 3.1.170
* Sun Feb 21 2016 mfilka@suse.com
- bnc#960703
  - network service setup moved into yast2-network package.
- 3.1.169
* Wed Feb 17 2016 cwh@suse.com
- Remove autoyast clone button (fate#317970)
- 3.1.168
* Tue Dec 22 2015 schubi@suse.de
- Removing network dependencies in the service files in order to
  prevent booting cycles in Tumbleweed. (bnc#954908)
- 3.1.167
* Mon Dec 21 2015 jsrain@suse.cz
- fixed function name to check zKVM hypervisor (bsc#956736)
- 3.1.166
* Fri Dec 11 2015 jsrain@suse.cz
- don't enforce the disk activation dialog on zKVM (bsc#956736)
- 3.1.165
* Wed Dec  2 2015 mvidner@suse.com
- Ensure second stage and YaST-Firstboot don't get killed by
  getty when running over 2nd or 3rd serial console (bsc#935965)
- 3.1.164
* Thu Nov 26 2015 jreidinger@suse.com
- Do not crash in proposal client if zfcp proposal reports itself
  as unavailable (bnc#956745)
* Wed Nov 25 2015 lslezak@suse.cz
- Save the software selection for using it later in AutoYaST
  when deploying installation images (bsc#956325, bsc#910728)
- 3.1.163
* Fri Nov  6 2015 ancor@suse.com
- Ensure second stage and YaST-Firstboot don't get killed by
  getty when running over serial console (bsc#935965)
- 3.1.162
* Fri Oct  9 2015 ancor@suse.com
- Language selection screen fixed to immediately apply the keyboard
  layout after changing it automatically (bsc#947969).
- 3.1.161
* Thu Oct  1 2015 ancor@suse.com
- Simplified second stage systemd unit to avoid dependencies cycles
  (bnc#947521 and bnc#931643). Logic moved to YaST startup scripts.
- 3.1.160
* Fri Sep  4 2015 jsrain@suse.cz
- fix bug preventing to finish proposal in some sutuations
  (bsc#944334)
- 3.1.159
* Thu Sep  3 2015 locilka@suse.com
- Fixed setting language / languages in the installation welcome
  screen (bsc#943746, bsc#944035)
- 3.1.158
* Wed Sep  2 2015 igonzalezsosa@suse.com
- Move #second_stage_required? method to InstFunctions module
  to be used by AutoYaST (bnc#892091)
- 3.1.157
* Tue Aug 25 2015 schubi@suse.de
- fixed cio_ignore testcase
  This testcase is for bnc#941406
- 3.1.156
* Thu Aug 13 2015 schubi@suse.de
- AutoYaST S390: handling cio_ignore
  Entry <general><cio_ignore> in order to set it
  (values: true/false). If it is not set cio_ignore is true.
  So it is backward compatible.
  (bnc#941406)
- cio_ignore does not make sense for KVM or z/VM. So checking
  for KVM and z/VM and evtl. disabling cio_ignore (fate#317861).
- 3.1.155
* Tue Aug 11 2015 schubi@suse.de
- AutoYaST second stage: YaST2-Second-Stage.service
  Continue installation even if plymouth has returned an error.
  (bnc#940878)
- 3.1.154
* Fri Aug  7 2015 igonzalezsosa@suse.com
- Fix release notes loading when network is not working (bsc#940648)
- 3.1.153
* Wed Aug  5 2015 jsrain@suse.cz
- store cio_ignore settings before installing bootloader
  (bsc#933177)
- 3.1.152
* Fri Jul 24 2015 jsrain@suse.cz
- avoid duplicating release notes for products (bsc#935599)
- 3.1.151
* Tue Jul 21 2015 mvidner@suse.com
- Moved client code to lib/installation/clients to enable test
  coverage measurements.
- 3.1.150
* Wed Jul  1 2015 shundhammer@suse.de
- Cleanup for snapshots made during installation (bnc#935923)
- 3.1.149
* Wed Jul  1 2015 locilka@suse.com
- Fixed handling user request to change an installation proposal
  (bsc#936448)
- 3.1.148
* Mon Jun 29 2015 lslezak@suse.cz
- fixed menu button label in the proposal (bsc#936427)
- 3.1.147
* Mon Jun 29 2015 jreidinger@suse.com
- add ability to hide export button (fate#315161)
- 3.1.146
* Wed Jun 17 2015 locilka@suse.com
- Implemented triggers for installation proposal (FATE#317488).
  Any *_proposal client can define 'trigger' in 'MakeProposal'
  that defines in which circumstances it should be called again
  after all proposals have been called, e.g., if partitioning or
  software selection changes.
- 3.1.145
* Tue Jun  2 2015 jreidinger@suse.com
- fix crash in Upgrade when creating post upgrade snapshot
  (fate#317973)
- 3.1.144
* Thu May 28 2015 igonzalezsosa@suse.com
- add a client to create a snapshot after installation/upgrade
  (fate#317973)
- 3.1.143
* Wed May 20 2015 lslezak@suse.cz
- set Xvnc server resolution to 96 dpi to fix broken layout in VNC
  installations (defaults to 75 dpi) (bsc#919456)
- 3.1.142
* Fri Apr 24 2015 ancor@suse.com
- Fixed an error preventing the VNC connection during second
  installation stage of AutoYaST when using VNC=1 (bnc#923901)
- 3.1.141
* Mon Apr 20 2015 schubi@suse.de
- Fixed differnt bugs in proposal overview with multiple tabs.
- Checking if plymouth is available while starting second
  installation stage for AutoYaST.
- 3.1.140
* Thu Apr 16 2015 locilka@suse.com
- Always enable systemd startup services for Second Stage and
  Firstboot (bsc#924278)
- 3.1.139
* Thu Apr  2 2015 jreidinger@suse.com
- avoid endless loop when confirm update in proposal runner
  (FATE#315161)
- 3.1.138
* Wed Apr  1 2015 jreidinger@suse.com
- fix method missing error in proposal_runner (FATE#315161)
- 3.1.137
* Wed Apr  1 2015 jreidinger@suse.com
- fix dependencies in proposal_store (FATE#315161)
- 3.1.136
* Fri Mar 27 2015 jreidinger@suse.com
- allow proposal runner dialog to use different proposal store
  (FATE#315161)
- 3.1.135
* Tue Feb 17 2015 aschnell@suse.de
- get list of mounts from /proc/mounts in umount_finish (for
  fate#318392)
- 3.1.134
* Mon Feb 16 2015 cwh@suse.com
- Delete or copy install.inf as applicable (bnc#897066)
- 3.1.133
* Wed Feb 11 2015 lslezak@suse.cz
- removed redundant initialization label (bnc#878538)
- 3.1.132
* Fri Feb  6 2015 ancor@suse.com
- The unit tests are now compatible with RSpec 3 (bnc#916364)
- 3.1.131
* Wed Feb  4 2015 lslezak@suse.cz
- support custom display number in "display_ip" boot option
  (bnc#913888)
- 3.1.130
* Tue Feb  3 2015 schubi@suse.de
- AutoYaST: If the system starts in multi-user mode plymouth will
  be quit while installation in order to ensure that installation
  will be finished on console 1 and the login prompt will be
  shown.
  (bnc#903682,889757,897956)
* Thu Jan 29 2015 jsrain@suse.cz
- allow keyboard layout testing in language dialog (bsc#889549)
- 3.1.129
* Tue Jan 27 2015 jsuchome@suse.cz
- explicitely set language packages for installation during the
  live install (bnc#904103)
- 3.1.128
* Mon Jan 26 2015 jreidinger@suse.com
- fix typo causing error in installation ( catched by openQA )
* Mon Jan 26 2015 jreidinger@suse.com
- Properly install new Proposal* libs to fix installation
* Tue Jan 13 2015 jreidinger@suse.com
- Refactored inst_proposal into Installation::ProposalRunner and
  Installation::ProposalStore.
- 3.1.127
* Tue Jan 13 2015 jsrain@suse.cz
- fixed progress bar during (live) image installation (bsc#854378)
* Wed Jan  7 2015 jreidinger@suse.com
- do not stuck during copy of logs files (bnc#897091)
- 3.1.126
* Thu Dec 18 2014 lslezak@suse.cz
- Fix bashisms and shebangs in scripts (by "Ledest")
- 3.1.125
* Wed Dec 10 2014 aschnell@suse.de
- drop check for Gtk since Gtk UI of YaST is no longer supported
  (bsc#908607)
- 3.1.124
* Thu Dec  4 2014 jreidinger@suse.com
- remove X-KDE-Library from desktop file (bnc#899104)
* Wed Nov 26 2014 ancor@suse.com
- Added more debug information in order to track bnc#897091
- 3.1.122
* Fri Nov 14 2014 ancor@suse.com
- Merging changes from 3.1.116.1 (SLE12 maintenance branch)
- Fixed the "previously used repositories" step to work properly
  when reached using the back button (bnc#889791)
- 3.1.121
* Tue Nov  4 2014 jreidinger@suse.com
- Improve dialog asking if system should be cloned (bnc#900028)
- 3.1.120
* Mon Nov  3 2014 schubi@suse.de
- AutoYaST Second Stage: Fixed a crash in package management when
  running in Qt UI with libproxy1-config-kde4 package installed.
  (bnc#866692)
- 3.1.119
* Fri Oct 31 2014 jreidinger@suse.com
- do not write obsolete /etc/syconfig/boot RUN_PARALLEL key
  (bnc#896207)
- 3.1.118
* Thu Oct 30 2014 lslezak@suse.cz
- properly setup locale in installation start script to display
  texts and labels correctly in a texmode installation and also
  to translate all buttons in graphical mode (removed "testutf8"
  calls, it has been dropped, always set UTF-8 locale) (bnc#902411)
- 3.1.117
* Wed Sep 17 2014 lslezak@suse.cz
- additionaly return file system type in ".run.df" agent result,
  (to use it in the disk usage calculation bnc#896176)
- 3.1.116
* Thu Sep  4 2014 mvidner@suse.com
- Use a more flexible rubygem requirement syntax (bnc#895069)
- 3.1.115
* Thu Aug 28 2014 ancor@suse.com
- Enabled remote access on systems installed using VNC (bnc#893501)
- 3.1.114
* Thu Aug 28 2014 locilka@suse.com
- Setting data for &product; macro (used in helps) as soon as
  the base-product repository is initialized (bnc#886608)
- 3.1.113
* Wed Aug 27 2014 locilka@suse.com
- Fixed [Abort] button handling in Disks Activation dialog
  (bnc#893281)
- 3.1.112
* Wed Aug 27 2014 schubi@suse.de
- Autoyast: Second stage will not be called at all. This bug has
  been generated due the fix in bnc#886464.
- 3.1.111
* Mon Aug 25 2014 schubi@suse.de
- Autoyast
  - - Disabling second installation stage via autoyast
    configuration "second_stage".
  - - Centralized minimal configuration and disabling more
    configuration steps like X11, user, default_desktop,...
  - - bnc#886464 and bnc#892091
- 3.1.110
* Mon Aug 18 2014 jreidinger@suse.com
- workaround problem with missing capabilities in image deployment
  (bnc#889489)
- 3.1.109
* Thu Aug  7 2014 snwint@suse.de
- use oom_score_adj instead of oom_adj (bnc #890432)
- 3.1.108
* Thu Aug  7 2014 jreidinger@suse.com
- update ca certificates after upgrade (bnc#889616)
- 3.1.107
* Mon Jul 28 2014 lslezak@suse.cz
- use short product name for the default base product release notes
  (read from the installation medium) (bnc#885247)
- display at least an empty dialog when downloading release notes
  to hide the previous dialog in the installation workflow
  (bnc#889196)
- 3.1.106
* Thu Jul 24 2014 lslezak@suse.cz
- do not repeat release notes downloading on network time out
  (bnc#885486)
- 3.1.105
* Thu Jul 24 2014 aschnell@suse.de
- do not log sensitive information in y2start.log (bnc#888645)
- 3.1.104
* Tue Jul 22 2014 snwint@suse.de
- linuxrc already provides proxy settings in URL form - so use it
- 3.1.103
* Mon Jul 21 2014 schubi@suse.de
- taking display-manager.service instead of xdm.service in the
  second boot stage (bnc#886654, 884447)
- Workaround of bug in plymouth --> using deactivate option
  in second boot stage in order to start ncurses yast correctly
  (bnc#886488)
- 3.1.102
* Wed Jul 16 2014 jsrain@suse.cz
- retranslate release notes button when going back in workflow
  (bnc#886660)
- 3.1.101
* Tue Jul 15 2014 locilka@suse.com
- Asking user for confirmation while aborting the installation in
  disk activation dialog (bnc#886662)
- 3.1.100
* Fri Jul  4 2014 jreidinger@suse.com
- Copy multipath blacklist to target system (bnc#885628)
- 3.1.99
* Thu Jul  3 2014 jreidinger@suse.com
- remove useless steps from system analysis because it confuses
  users (bnc#885609)
- 3.1.98
* Mon Jun 30 2014 jreidinger@suse.cz
- restore: use restore script instead of manual unpacking tarball
  to also remove newly generated content when rollbacking
  (bnc#882039)
- 3.1.97
* Mon Jun 23 2014 locilka@suse.com
- Changed /bin/rm path to /usr/bin/rm path (bnc#882453)
- 3.1.96
* Mon Jun 23 2014 jreidinger@suse.com
- directly export autoyast profile to target file (bnc#881108)
- 3.1.95
* Thu Jun 19 2014 lslezak@suse.cz
- removed random_finish client, haveged service is by default
  enabled, no need for explicit enabling by Yast
  (gh#yast/yast-installation#214)
- 3.1.94
* Wed Jun 18 2014 lslezak@suse.cz
- make sure the CIO ignore config file ends with a new line
  (bnc#883198)
- 3.1.93
* Tue Jun 17 2014 lslezak@suse.cz
- inst_upgrade_urls.rb: set the future target distribution to not
  ignore the SCC online repositories in libzypp (bnc#881320)
- 3.1.92
* Mon Jun 16 2014 jreidinger@suse.com
- write list of active devices for cio_ignore ( partially written
  by Ihno )
- 3.1.91
* Thu Jun 12 2014 jreidinger@suse.com
- restore backup if yast failed during installation/upgrade
  (bnc#882039)
- 3.1.90
* Thu Jun 12 2014 lslezak@suse.cz
- properly enable the add-on module in the installation workflow
- 3.1.89
* Tue Jun  3 2014 lslezak@suse.cz
- inst_upgrade_urls.rb client:
  - remove old repositories (repo files) to avoid loading old
    SLE11 repositories when refreshing a registered service
    (bnc#880971)
  - remove old services to get rid of the old NCC service
  (Note: everything is backed up into /var/adm/backup/upgrade/zypp
  directory)
- 3.1.88
* Thu May 29 2014 lslezak@suse.cz
- better error message for accepting the license (bnc#875183)
- 3.1.87
* Wed May 28 2014 aschnell@suse.de
- close port 6000 during installation (bnc#879262)
- 3.1.86
* Wed May 21 2014 jreidinger@suse.com
- do not call reipl multiple times (patch by Ihno)
- 3.1.85
* Fri May 16 2014 jsrain@suse.cz
- reduced time-out for downloading release notes when behind
  firewall (bnc#878265)
- 3.1.84
* Fri May 16 2014 mvidner@suse.com
- Fixed "undefined method" if an add-on has empty release notes URL
  (bnc#877705)
- 3.1.83
* Fri May 16 2014 jsrain@suse.cz
- adjusted wording when deploying image to disk (bnc#877666)
- 3.1.82
* Wed May 14 2014 jreidinger@suse.com
- Use new bootloader API to set kernel parameters (bnc#869608)
- 3.1.81
* Tue May 13 2014 jreidinger@suse.com
- Fix haveged path to kill it properly (patch by Ihno) (bnc#876876)
- 3.1.80
* Tue May 13 2014 gs@suse.de
- enable services for FCoE by calling fcoe-client finish script
  (bnc#877352)
- 3.1.79
* Fri May  9 2014 jreidinger@suse.com
- ensure maximum size of prep partition for ppc64 (bnc#867345)
  ( part of patch made by dinaar@suse.com )
- 3.1.78
* Fri May  9 2014 jsrain@suse.cz
- adjusted downloading release notes to work also for extensions
  (bnc#876700)
- 3.1.77
* Wed Apr 30 2014 jreidinger@suse.com
- use correct keywords for cio ignore kernel params (bnc#874902)
- move cio_ignore step after bootloader step to have sections
  generated (bnc#873996)
- 3.1.76
* Fri Apr 25 2014 mfilka@suse.com
- bnc#872086
  - always copy network configuration. Even if network is not
    running during installation
- 3.1.75
* Fri Apr 25 2014 jsrain@suse.cz
- enhanced handling of release notes from media (contrary to those
  downloaded on-line) (bnc#874996)
- 3.1.74
* Thu Apr 24 2014 locilka@suse.com
- Changed inst_system_analysis to read Product information
  (that uses libzypp) after initializing libzypp (bnc#873877)
- 3.1.73
* Wed Apr 23 2014 jsrain@suse.cz
- enable top bar with logo during installation (bnc#868722)
- 3.1.72
* Tue Apr 15 2014 locilka@suse.com
- Switched from the old to the new network setup client for remote
  repositories (bnc#869640)
- 3.1.71
* Tue Apr 15 2014 jreidinger@suse.com
- fix crash from last fix and adapt it to cooperate nice with
  autoinstallation (bnc#873458)
- 3.1.70
* Mon Apr 14 2014 jreidinger@suse.com
- return error message if base product not found and continue in
  installation(bnc#873458)
- 3.1.69
* Mon Apr 14 2014 locilka@suse.com
- removed loading 'pciehp' Kernel module (added for SLE 11 by FATE
  [#311991]) - it is now built-in Kernel (bnc#865834)
- 3.1.68
* Fri Apr 11 2014 jsrain@suse.cz
- added missing files to package (bnc#872925)
- 3.1.67
* Thu Apr 10 2014 mvidner@suse.com
- Put wizard title on the left instead of on top (bnc#868859)
- 3.1.66
* Thu Apr 10 2014 jsrain@suse.cz
- added handling of release notes for slide show (bnc#871158)
- 3.1.65
* Wed Apr  9 2014 snwint@suse.de
- save a copy of pbl.log
- 3.1.64
* Fri Apr  4 2014 snwint@suse.de
- remove LIBGL_ALWAYS_INDIRECT (bnc #869172)
- 3.1.63
* Thu Apr  3 2014 jreidinger@suse.com
- do not write network configuration from upgrade to system
  (bnc#871178)
- 3.1.62
* Wed Apr  2 2014 jreidinger@suse.com
- remove ssh_service_finish as it is handle in
  firewall_stage1_finish due to split of ssh port open and sshd
  enablement (bnc#865056)
- 3.1.61
* Sun Mar 30 2014 mfilka@suse.com
- bnc#869719
  - fixed parameters forcing manual network configuration on user's
    request at disks activation screen
- 3.1.60
* Mon Mar 24 2014 jreidinger@suse.com
- change cio_ignore kernel parameter according to kernel changes
  (bnc#869463)
- 3.1.59
* Mon Mar 24 2014 jreidinger@suse.com
- avoid constant redefinition warning(BNC#869202)
- 3.1.58
* Wed Mar 19 2014 lslezak@suse.cz
- skip "Installation Options" dialog when online repository option
  should not be displayed (part of bnc#868942)
- 3.1.57
* Fri Mar 14 2014 snwint@suse.de
- set LIBGL_ALWAYS_INDIRECT in ssh mode (bnc #868175)
- enable yast theme in ssh mode
- 3.1.56
* Fri Mar 14 2014 jsrain@suse.cz
- download on-line version of release notes (fate#314695)
- 3.1.55
* Thu Mar 13 2014 jreidinger@suse.com
- add kernel parameters for s390 when cio_ignore enabled to never
  blacklist console or ipl devices (fate#315318)
- 3.1.54
* Wed Mar 12 2014 mfilka@suse.com
- bnc#858523
  - dropped disabling network configuration code. yast2-network is
    in charge of it now.
- 3.1.53
* Mon Mar 10 2014 jsrain@suse.cz
- don't hide ReleaseNotes button going back fron inst proposal
  (bnc#867389)
- 3.1.52
* Fri Mar  7 2014 lslezak@suse.cz
- run scc_finish client if present (FATE#312012)
- 3.1.51
* Thu Mar  6 2014 jreidinger@suse.com
- fix malformed string exception if cio ignore is disabled
  (bnc#866995)
- 3.1.50
* Tue Mar  4 2014 jreidinger@suse.com
- call proper bash agent otherwise cio ignore feature do not work
  (bnc#866614)
- 3.1.49
* Mon Mar  3 2014 jreidinger@suse.com
- do not crash if there is no general section in autoyast profile
  (BNC#866529)
- 3.1.48
* Thu Feb 27 2014 aschnell@suse.de
- reset proposal after rescanning storage (bnc#865579)
- 3.1.47
* Thu Feb 27 2014 jreidinger@suse.com
- revert back complete skip of probing due to disks with activation
  (BNC#865579)
- 3.1.46
* Thu Feb 27 2014 jreidinger@suse.com
- Do not rerun system probing as it is already done (BNC#865579)
- 3.1.45
* Wed Feb 26 2014 jreidinger@suse.com
- implement cio ignore feature during installation for s390x
  (FATE#315586)
- 3.1.44
* Tue Feb 25 2014 locilka@suse.com
- Removed an icon from License Agreement dialog (bnc#865575)
- 3.1.43
* Tue Feb 25 2014 locilka@suse.com
- Adapted ignored_features to handle possibly missing Cmdline entry
  from Linuxrc (bnc#861465)
- 3.1.42
* Tue Feb 25 2014 locilka@suse.cz
- Removed hard-coded color and RichText formatting from
  installation confirmation dialog (#bnc#865371)
- 3.1.41
* Fri Feb 21 2014 snwint@suse.de
- Make vnc use real yast theme (bnc #855246) and make vnc screen size configurable.
- 3.1.40
* Fri Feb 21 2014 mvidner@suse.com
- ssh installation: fix network start after reboot (bnc#850446)
- 3.1.39
* Wed Feb 19 2014 locilka@suse.com
- Prevent from re-defining CopyFilesFinishClient class (bnc#864631)
- 3.1.38
* Wed Feb 19 2014 locilka@suse.com
- Writing bootloader as late as possible, several configs need to
  be written and coppied to the installed system first (bnc#860089)
- 3.1.37
* Tue Feb 18 2014 locilka@suse.com
- Copying all udev rules from inst-sys to installed system
  (bnc#860089)
- 3.1.36
* Mon Feb 17 2014 jreidinger@suse.com
- fix detection if ssh daemon run otherwise ssh installation do not
  reboot after first stage(BNC#864260)
- 3.1.35
* Wed Feb 12 2014 jreidinger@suse.com
- fix namespace collision that cause error in installation
- 3.1.34
* Tue Feb 11 2014 jreidinger@suse.com
- keep proper installation mode after cloning(BNC#861520)
- 3.1.33
* Tue Feb 11 2014 jreidinger@suse.com
- fix dependencies to properly require new ruby bindings
- 3.1.32
* Mon Feb 10 2014 jsrain@suse.cz
- removed unused release_notes_popup.rb
- Remove initialisation of Report in autoinst mode from
  inst_system_analysis. Not needed any more since autoyast Profile
  is now processed before inst_system_analysis gets called
  (bnc#862829).
- 3.1.31
* Fri Feb  7 2014 jreidinger@suse.com
- Implement minimal installation feature (FATE#313149)
- 3.1.30
* Mon Feb  3 2014 jreidinger@suse.com
- fix false positive errors in log for easier debugging in future
- 3.1.29
* Fri Jan 31 2014 lslezak@suse.cz
- inst_inc_all.rb - added missing import (bnc#860263)
- 3.1.28
* Thu Jan 30 2014 jreidinger@suse.com
- Remove write to non-existing /etc/sysconfig/suseconfig
  (FATE#100011)
- 3.1.27
* Thu Jan 30 2014 aschnell@suse.de
- fixed DASD detection (bnc#860398)
- 3.1.26
* Tue Jan 28 2014 jreidinger@suse.com
- Fix exporting configuration in first stage (FATE#308539)
- 3.1.25
* Mon Jan 27 2014 mfilka@suse.com
- fate#316768, bnc#854500
  - enable network service according product feature
- 3.1.24
* Fri Jan 24 2014 lslezak@suse.cz
- removed inst_scc.rb client (moved to yast2-registration)
- 3.1.23
* Tue Jan 21 2014 jreidinger@suse.com
- Remove icons from system analysis according to Ken's comments
  (fate#314695)
- 3.1.22
* Tue Jan 21 2014 jreidinger@suse.com
- Remove "Change..." button in non-textual installation
- Add "Export Configuration" button in non-textual installation
  (FATE#308539)
- Add "Export Configuration" menu item in textual installation
  (FATE#308539)
- 3.1.21
* Tue Jan 21 2014 jsrain@suse.cz
- adjusted UI according to Ken's comments (fate#314695)
- 3.1.20
* Mon Jan 13 2014 jreidinger@suse.com
- add clone proposal and finish client (FATE#308539)
- 3.1.19
* Wed Jan  8 2014 jsrain@suse.cz
- added capability to install OEM images (fate#316326)
- added handling Release Notes button (fate#314695)
* Fri Dec 20 2013 vmoravec@suse.com
- Add abort and fail hooks for installation
- 3.1.18
* Thu Dec 12 2013 lslezak@suse.cz
- control files have been moved to a separate package/git repo
  (https://github.com/yast/yast-installation-control)
- 3.1.17
* Wed Dec 11 2013 lslezak@suse.cz
- fixed Makefile.am (added missing inst_scc.rb)
- 3.1.16
* Tue Dec 10 2013 vmoravec@suse.com
- Show hook summary only if some hooks failed
- 3.1.15
* Thu Dec  5 2013 jreidinger@suse.com
- fix opening zfcp client in disk activation on s390
- 3.1.14
* Thu Dec  5 2013 lslezak@suse.cz
- added a new client for SCC registration (first iteration, UI
  only, does not work yet)
* Wed Dec  4 2013 jreidinger@suse.com
- fix failure in remote disks activation client
- 3.1.13
* Wed Dec  4 2013 lslezak@suse.cz
- removed "trang" dependency (requires complete Java stack, convert
  the file directly in the source repository)
- 3.1.12
* Tue Dec  3 2013 jreidinger@suse.com
- remove server base scenario and media check clients from SLE
  installation (FATE#314695)
- add storage proposal dialog to SLE installation (FATE#314695)
- 3.1.11
* Tue Dec  3 2013 vmoravec@suse.com
- Show popup window with used hooks before installation finished
- 3.1.10
* Mon Dec  2 2013 jreidinger@suse.com
- Add direct link to network communication from remote disks
  activation (FATE#314695, part of NI requirements)
- 3.1.9
* Thu Nov 28 2013 vmoravec@suse.com
- Add hooks to main installation client
- 3.1.8
* Wed Nov 20 2013 lslezak@suse.cz
- removed support for automatic 2nd stage (the 2nd stage has been
  dropped completely) (FATE#314695)
- 3.1.7
* Tue Nov 19 2013 locilka@suse.com
- Proposing separate /home partition on SLES and SLES for VMware
  (FATE#316624)
* Mon Nov 18 2013 lslezak@suse.cz
- move some steps from removed 2nd stage to the 1st stage
- "inst_mode" client: removed installation/update switch,
  renamed to "inst_installation_options"
- 3.1.6
* Tue Nov 12 2013 lslezak@suse.cz
- control file cleanup:
  * remove the 2nd stage in installation (FATE#314695)
  * removed autoconfiguration support in the 2nd stage (the 2nd
    stage has been removed completely)
  * repair mode removed (not supported) (FATE#308679)
* Mon Nov 11 2013 vmoravec@suse.com
- 3.1.5
- replace runlevel entries in control files with default_target
  entries
- replace dependency on yast2-runlevel with yast2-services-manager
* Thu Nov  7 2013 mfilka@suse.com
- bnc#849391
  - removed explicit start of second phase of SuSEfirewall2
    initialization. Not needed when systemd is in use.
- 3.1.4
* Thu Oct 31 2013 lslezak@suse.cz
- install "perl-Bootloader-YAML" package
- removed "Use Automatic Configuration" option from the
  installation mode dialog (the 2nd stage has been removed)
- 3.1.3
* Tue Oct 29 2013 lslezak@suse.cz
- install only "perl-YAML-LibYAML" and "perl-bootloader" packages
  to the target system
- updated scr_switch_debugger.rb client
* Sat Oct 26 2013 jsrain@suse.cz
- show release notes button (fate#314695)
* Fri Oct 25 2013 aschnell@suse.de
- removed long obsolete EVMS entries from control file (see
  fate#305007)
* Wed Oct 23 2013 lslezak@suse.cz
- removed autorepeat workaround for bnc#346186, not needed anymore,
  xset might not be installed (bnc#846768)
- 3.1.2
* Tue Oct 22 2013 locilka@suse.com
- Extended support for ignored_features: They can be also mentioned
  in PTOptions and thus not appended to Kernel command line
  (FATE#314982)
* Tue Oct 15 2013 locilka@suse.com
- Added support for ignore[d][_]feature[s] (FATE#314982) allowing
  to skip some unwanted features of the installer
- 3.1.1
* Thu Oct 10 2013 locilka@suse.com
- Dropped modem and DSL detection (and configuration) from
  installation proposal (FATE#316263, FATE#316264)
* Fri Sep 27 2013 lslezak@suse.cz
- do not use *.spec.in template, use *.spec file with RPM macros
  instead
- 3.1.0
* Fri Sep 27 2013 jsuchome@suse.cz
- yast2-mouse was dropped, do not call its components (bnc#841960)
- 3.0.7
* Thu Sep 26 2013 jsuchome@suse.cz
- fix console status after the installation (bnc#750326)
- 3.0.6
* Tue Sep  3 2013 jsuchome@suse.cz
- do not mention xorg-x11 in the control files (bnc#837450)
- remove obsoleted part of X11 related code
- 3.0.5
* Fri Aug  9 2013 mfilka@suse.com
- bnc#798620
  - removed proposed hotfix for the bug. The hotfix could block
    starting firewall under some circunstances.
  - (re)starting firewall is handled in yast2.rpm since 3.0.2
- 3.0.4
* Wed Aug  7 2013 jsuchome@suse.cz
- use pure ruby solution when sorting proposal items
* Tue Aug  6 2013 jsuchome@suse.cz
- use pure ruby solution when sorting destkop items, so major desktop
  (with same order number) won't get resorted
- 3.0.3
* Mon Aug  5 2013 jsuchome@suse.cz
- check the product profiles during system analysis and
  copy them to installed system (backport of fate#310730)
- 3.0.2
* Sun Aug  4 2013 lslezak@suse.cz
- removed empty agents/Makefile.am and unused testsuite/Makefile.am
- removed obsolete BuildRequires: doxygen perl-XML-Writer sgml-skel
  yast2-testsuite yast2-storage yast2-pkg-bindings yast2-packager
* Fri Aug  2 2013 jsuchome@suse.cz
- remove trang from BuildRequires: rng can be created during
  packaging, not needed during build
* Thu Aug  1 2013 jsuchome@suse.cz
- correctly write supporturl (port of bnc#520169)
- limit the number of the searched disks to 8 of each kind to
  shorten time needed for finding SSH keys (port of fate#305873)
- 3.0.1
* Wed Jul 31 2013 yast-devel@opensuse.org
- converted from YCP to Ruby by YCP Killer
  (https://github.com/yast/ycp-killer)
- version 3.0.0
* Mon Jul 29 2013 fehr@suse.de
- ignore SIGHUP in YaST2.Second-Stage to make autoyast installs
  with serial console succeed again (bnc#825728, bnc#823224)
* Thu Jul 11 2013 aschnell@suse.de
- fixed sshd check (bnc#825160)
- 2.24.10
* Thu Jul  4 2013 jsuchome@suse.cz
- show release notes of newest product first (bnc#827590)
- 2.24.9
* Tue Jun 25 2013 jsuchome@suse.cz
- adapt control.xml to offical Factory one:
  added e17 desktop, enabled online repositories
- 2.24.8
* Fri Jun 21 2013 jsuchome@suse.cz
- only show desktops for which their defined patterns are known
  (needed when desktop defined in control file is only available
  via some optional installation source - fate#315061)
- 2.24.7
* Wed Jun 19 2013 aschnell@suse.de
- make check for sshd more robust (bnc#825160)
- 2.24.6
* Thu Jun  6 2013 mfilka@suse.com
- bnc#774301
  - fixed udev events handling in kernel_finish
- 2.24.5
* Wed Jun  5 2013 lslezak@suse.cz
- use WFM::ClientExists() call instead of checking *.ycp file
  presence (works also with non-YCP clients and checks also e.g.
  /y2update/clients path)
* Mon May 27 2013 locilka@suse.com
- Using unique IDs while calling rpmcopy_secondstage to prevent
  from disabling this step in AutoYaST or Upgrade while it should
  be disabled only in Installation (bnc#813072).
* Mon May 13 2013 jsuchome@suse.cz
- startup scripts: if RC_LANG is not set, use en_US as default
  (bnc#815265)
- 2.24.4
* Fri May  3 2013 aschnell@suse.de
- call unicode_start/stop and initviocons only on consoles
  (bnc#800790)
- fixed check for missing initviocons
- 2.24.3
* Mon Apr 22 2013 jsuchome@suse.cz
- show dialog for all available disk controlers (bnc#807026)
- 2.24.2
* Wed Apr 17 2013 jsuchome@suse.cz
- force disk activation when Storage reports no disk was found
  (bnc#810823)
- 2.24.1
* Fri Mar 29 2013 jsuchome@suse.cz
- always return boolean from DeployTarImage (bnc#804293)
- make the "Check drivers" error message depend on control.xml
  variable (fate#312875, bnc#805251)
- 2.24.0
* Wed Mar 13 2013 mfilka@suse.com
- NetworkManager is enabled and active after second stage (bnc#808039)
- 2.23.13
* Mon Mar  4 2013 aschnell@suse.de
- deactivate RAID before going back to "Disk Activation" during
  installation (bnc#806454)
* Thu Feb 14 2013 fehr@suse.de
- fix got_kernel_param in misc.sh to not match substrings (so far
  kernel parameters like systemd.log_level=debug activated Y2DEBUG)
- 2.23.12
* Wed Jan 23 2013 jsuchome@suse.cz
- prevent systemctl hang in 2nd stage (from fcrozat@suse.com,
  bnc#798620)
- 2.23.11
* Sun Jan 20 2013 lslezak@suse.cz
- start the add-on module also when "addon" boot parameter is
  present (fate#314318)
- 2.23.10
* Mon Jan 14 2013 locilka@suse.com
- Adding repositories that cannot be (re)added as enabled in
  a disabled state (bnc#779396).
- 2.23.9
* Fri Jan 11 2013 jsuchome@suse.cz
- adapted to changes in Storage.ycp API (bnc#797245)
- 2.23.8
* Mon Jan  7 2013 jsuchome@suse.cz
- set new keyboard layout right after selecting (bnc#796589)
- added SYSTEMCTL_OPTIONS to Firstboot/Second Stage services
  (bnc#791076)
- 2.23.7
* Fri Dec 21 2012 jsuchome@suse.cz
- show the info about possibility to download drivers
  from drivers.suse.com (fate#312875)
- added KVM installation scenario (bnc#795067)
- 2.23.6
* Fri Dec 14 2012 jsuchome@suse.cz
- disable USB sources after installation (bnc#793709)
- 2.23.5
* Tue Dec  4 2012 jsuchome@suse.cz
- allow using local repositories during update (bnc#779397)
- 2.23.4
* Mon Nov  5 2012 jsuchome@suse.cz
- fixed installation of systemd units (crrodriguez)
- 2.23.3
* Wed Oct 31 2012 jsuchome@suse.cz
- removed fonts_finish, its only action was to call obsolete
  SuSEconfig script
- removed inst_suseconfig client (fate#100011)
- 2.23.2
* Fri Oct 26 2012 jsuchome@suse.cz
- do not allow to go next without desktop selected (bnc#786507)
- 2.23.1
* Wed Oct 24 2012 jsuchome@suse.cz
- removed suseconfig step from installation sequence (fate#100011)
- 2.23.0
* Wed Jul 11 2012 jsuchome@suse.cz
- create simpler and non translated aliases for update sources
  (bnc#768624)
- 2.22.10
* Thu Jun 28 2012 jsuchome@suse.cz
- set TERM=linux for 2nd stage services, to keep ncurses nice
  (bnc#768356)
- 2.22.9
* Mon Jun 25 2012 jsuchome@suse.cz
- ensure Plymouth is hiddent before 2nd start, to prevent system
  freeze (bnc#768185)
- ensure 2nd stage is started before SuSEfirewall2_init (bnc#733361)
- 2.22.8
* Tue Jun 19 2012 aschnell@suse.de
- kill console before reboot (bnc#759627)
  (otherwise systemd will not proceed with system shutdown)
* Wed Jun  6 2012 jsuchome@suse.cz
- require yast2-proxy for 2nd stage (bnc#764951)
- show a message if network config has failed (bnc#765129)
- 2.22.7
* Tue Apr 17 2012 jsuchome@suse.cz
- enhanced image installation help text (bnc#732914)
* Tue Apr  3 2012 aschnell@suse.de
- adapted to move of testX (see bnc#749184)
- 2.22.6
* Wed Mar 14 2012 aschnell@suse.de
- create link yast.ssh for 2nd stage ssh installation (bnc#745340)
- 2.22.5
* Wed Feb 15 2012 gs@suse.de
- Improve layout of the release notes dialog (bnc #550610)
- 2.22.4
* Thu Feb  9 2012 jsuchome@suse.cz
- adapt the style only for ssh installation, not vnc (bnc#742777)
- 2.22.3
* Tue Feb  7 2012 tgoettlicher@suse.de
- Fixed bnc #742777: ssh installation needs to much bandwidth
- 2.22.2
* Fri Jan 13 2012 jsuchome@suse.cz
- confirmed license
- 2.22.1
* Mon Jan  9 2012 locilka@suse.cz
- save ecdsa keys as well (bnc#726468) (added where missing)
* Mon Jan  9 2012 locilka@suse.cz
- Added ntp-client into list of cloned modules in control file
  (bnc #738019).
* Wed Jan  4 2012 locilka@suse.cz
- Reading the current random/poolsize from /proc to store the exact
  number of bytes (bnc#692799).
* Tue Jan  3 2012 locilka@suse.cz
- Modified saving state of the current randomness (bnc#692799).
* Thu Dec  8 2011 locilka@suse.cz
- Fixed saving state of the current randomness (bnc#692799).
* Fri Nov 25 2011 jsuchome@suse.cz
- ask for Abort confirmation in Update URLs step (bnc#728907)
* Wed Nov 16 2011 jsuchome@suse.cz
- merged texts from proofreading
- 2.22.0
* Thu Nov 10 2011 fcrozat@suse.com
- Disable routing initscript commands through systemd, prevent
  lockups.
* Thu Nov  3 2011 aschnell@suse.de
- use same code to display ip addresses during vnc and ssh
  installation (bnc#727802)
- 2.21.28
* Wed Nov  2 2011 fcrozat@suse.com
- Ensure network is not started by systemd before Firstboot /
  SecondStage (bnc#726823)
- 2.21.27
* Mon Oct 31 2011 jsuchome@suse.cz
- control files: save ecdsa keys (bnc#726468)
- 2.21.26
* Wed Oct 19 2011 locilka@suse.cz
- Creating /etc/mtab linking to /proc/self/mounts in umount_finish
  (bnc#725166)
- 2.21.25
* Fri Oct 14 2011 fcrozat@suse.com
- Fix text mode handled in systemd (bnc#724115)
- 2.21.24
* Tue Oct 11 2011 jsuchome@suse.cz
- compress the log file from 1st stage of installation (bnc#716938)
- 2.21.23
* Fri Oct  7 2011 fcrozat@suse.com
- Use latest macros for systemd
- Drop workaround for bnc#719221, systemd is fixed now.
- 2.21.22
* Fri Oct  7 2011 jsrain@suse.cz
- change the URL for congratulation dialog (bnc#720481)
* Mon Sep 26 2011 jsuchome@suse.cz
- control.openSUSE: use lightdm as default DM for Xfce
- 2.21.21
* Fri Sep 23 2011 jsuchome@suse.cz
- updated systemd service files (bnc#719221)
- 2.21.20
* Fri Sep 23 2011 jsuchome@suse.cz
- unmount previously mounted /run (bnc#717321)
- 2.21.19
* Thu Sep 15 2011 lslezak@suse.cz
- improved package update check - display only the repositories
  with an update available, display package updates in details
- 2.21.18
* Tue Sep  6 2011 jsuchome@suse.cz
- enable system cloning only when autoyast2 is installed
  (bnc#692790)
- 2.21.17
* Wed Aug 31 2011 jsuchome@suse.cz
- fix build for older distributions
- 2.21.16
* Mon Aug 29 2011 jsuchome@suse.cz
- added systemd .service files for second stage and firstboot
  (from fcrozat@suse.com, bnc#713760)
- 2.21.15
* Fri Aug 12 2011 jsuchome@suse.cz
- expect there might me extra checks for disk controllers with
  s390 (bnc#706911)
- adapted help text and label in installation mode selection
  (bnc#711160)
- 2.21.14
* Fri Aug  5 2011 lslezak@suse.cz
- upgrade_urls.ycp - do not display reading and writing progress,
  it is pretty quick and just causes screen flickering
  (the write progress is displayed only when there is an enabled
  repo to add, refreshing it can take long time) (bnc#692614)
- 2.21.13
* Fri Aug  5 2011 tgoettlicher@suse.de
- fixed .desktop file (bnc #681249)
* Thu Aug  4 2011 lslezak@suse.cz
- 2.21.12
* Thu Aug  4 2011 mvidner@suse.cz
- Copy network interface naming rules early to get them to initrd (bnc#666079).
* Thu Aug  4 2011 lslezak@suse.cz
- extraurls: check whether there is an update candidate in the
  added extra repositories - openSUSE DVD does not contain all
  packages, packages from OSS repository which are not on DVD
  medium were not upgraded and were left in the old version even
  after adding new OSS repository with updated version (bnc#693230)
* Wed Aug  3 2011 lslezak@suse.cz
- cleanup: removed obsoleted SourceManager::SyncAddedAndDeleted()
  call (zmd sync has been removed)
- 2.21.11
* Wed Aug  3 2011 lslezak@suse.cz
- use term "Software manager" instead of "Package manager"
  (bnc#585679)
- 2.21.10
* Tue Aug  2 2011 locilka@suse.cz
- Preserving the /dev/urandom state from inst-sys after the
  installation (bnc#692799)
- Automatically enabling haveged service if installed (bnc#692799)
- 2.21.9
* Mon Aug  1 2011 locilka@suse.cz
- Added control.SLES-for-VMware into the SVN
* Fri Jul 22 2011 locilka@suse.cz
- Removed obsoleted X-KDE-SubstituteUID from deploy_image.desktop
  (bnc#540627)
- 2.21.8
* Tue Jul 12 2011 jsuchome@suse.cz
- Show Xen Virtualization Host Server Installation scenario
  only for x86_64 architecture (bnc#702103)
- 2.21.7
* Thu Jun 30 2011 jsuchome@suse.cz
- fixed typos (bnc#703119)
- 2.21.6
* Wed Jun  1 2011 locilka@suse.cz
- always loading 'pciehp' kernel module on Dell hardware
  (FATE #311991)
- fixed control file validation
- stricter btrfs_increase_percentage definition in all control
  files (only 'integer' is allowed)
* Wed Jun  1 2011 fehr@suse.de
- add btrfs_increase_percentage to to category "partitioning" in
  config.xml files
- 2.21.5
* Thu May 19 2011 jsuchome@suse.cz
- enable YaST restart in the 1st stage (bnc#694299)
- 2.21.4
* Wed Apr 27 2011 jsuchome@suse.cz
- added option to configure FCoE Interfaces when started with
  WithFCoE=1 argument (fate#307445)
- 2.21.3
* Wed Apr 27 2011 jsuchome@suse.cz
- Copy /media.1/build to the installed system (fate#311377)
- 2.21.2
* Fri Mar 25 2011 jsuchome@suse.cz
- show the 'before-reboot' message in RichText, so possible command
  can be copy-pasted (bnc#383519)
- 2.21.1
* Thu Mar 24 2011 jsuchome@suse.cz
- do not start automatic configuration for autoYaST (bnc#679435)
- 2.21.0
* Mon Feb 28 2011 locilka@suse.cz
- Handling disabled installation steps also in Live Installation
  mode (BNC #675516)
- 2.20.6
* Thu Feb 17 2011 aschnell@suse.de
- fixed braille support during installation (bnc #672086)
- 2.20.5
* Tue Feb  8 2011 locilka@suse.cz
- Adapted openSUSE control file to the current naming schema of
  desktops (BNC #667408)
* Thu Jan 20 2011 jsrain@suse.cz
- fix initialization of AutoUpgrade for 2nd stage
- 2.20.4
* Wed Jan 19 2011 jsrain@suse.cz
- adaptations for unattended migration (fate#310481)
- don't delete /etc/mtab if it is a symlink (bnc#665437)
- 2.20.3
* Wed Jan 19 2011 jsrain@suse.cz
- fixed progress during live installation (bnc#665413)
- 2.20.2
* Fri Jan  7 2011 jsrain@suse.cz
- update XFCE desktop definition
* Thu Jan  6 2011 locilka@suse.cz
- Using wider space for licence displayed in non-textual interface
  (BNC #607135).
- Fixed DUD deployment (BNC #626337)
* Tue Nov 16 2010 jsrain@suse.cz
- fixed behavior of window closing in installation proposal
  (bnc#636980)
- use df for estimating partition size for live installer
  (bnc#555288)
- 2.20.1
* Thu Sep 30 2010 lslezak@suse.cz
- don't use spaces in repo alias (bnc#596950)
- inst_addon_update_sources.ycp - removed obsoleted ZMD sync call
- 2.20.0
* Wed Jun  2 2010 jsrain@suse.cz
- removed link to repairing the system
- 2.19.20
* Wed May 12 2010 ug@suse.de
- fixed the cloning at the end of a manual
  installation (bnc#605132)
- 2.19.7
* Mon Apr 19 2010 aschnell@suse.de
- allow btrfs as root fs
- 2.19.6
* Thu Apr 15 2010 locilka@suse.cz
- Script copy_files_finish copies files with --dereference to
  prevent from copying symlinks instead of the files content
  (BNC #596938).
* Fri Apr  9 2010 aschnell@suse.de
- disable Qt/Gtk frontend if testX is unavailable (bnc #585432)
- 2.19.5
* Tue Apr  6 2010 locilka@suse.cz
- Searching for LiveCD license in /usr/share/doc/licenses and /
  directories (BNC #594042).
* Fri Mar 26 2010 ug@suse.de
- fixed a broken yast2-installation.spec.in
- fixed broken schema validation files for control.xml files
- 2.19.4
* Wed Mar 24 2010 lslezak@suse.cz
- inst_suseconfig.ycp - do not reset UI product name
  (&product; macro) (bnc#539906)
* Thu Mar 18 2010 locilka@suse.cz
- Previously used repositories switched from enabled/disabled mode
  to removed/enabled/disabled mode (BNC #588659).
* Fri Mar 12 2010 kmachalkova@suse.cz
- Port from SLE11 SP1: process files in _datadir/autoinstall/modules
  with %%suse_update_desktop_file. This passes their strings into
  translation (bnc#549944)
* Fri Mar 12 2010 locilka@suse.cz
- Unique identification in inst_upgrade_urls switched from URL to
  ALIAS (BNC #587517).
- In case of re-adding CD/DVD media, user is asked to insert
  correct media before adding it (BNC #587517).
- Only upgrade packages if upgrading from SLES 11, otherwise use
  patterns for upgrade (BNC #587544).
* Tue Mar  9 2010 locilka@suse.cz
- Fixed calling update.post from DUD (BNC #586609).
* Tue Mar  2 2010 locilka@suse.cz
- CIM service is proposed as disabled by default (BNC #584524).
* Mon Feb 22 2010 locilka@suse.cz
- Documented YaST RELAX NG schema (FATE #305551).
- Correctly re-added unique_id to RNC - AC steps and proposals
  (BNC #582094).
* Wed Feb 17 2010 ug@suse.de
- clone checkbox at the end of the installation is always
  enabled now and can install the autoyast2 package if needed
  (bnc#547486)
* Mon Feb 15 2010 ug@suse.de
- UI for autoinstallation images added to deploy_image_auto
* Tue Feb  9 2010 locilka@suse.cz
- Steps 'user' and 'auth' enabled again in Live mode (BNC #547931).
* Tue Feb  9 2010 locilka@suse.cz
- Fixed license agreement check box visibility (BNC #571846).
- 2.19.3
* Tue Feb  2 2010 locilka@suse.cz
- Added LXDE to openSUSE control file (FATE #307729).
* Mon Feb  1 2010 locilka@suse.cz
- Fixed 'going back' from services proposal BNC #572734.
* Fri Jan 22 2010 aschnell@suse.de
- fixed message during ssh installation (bnc #518616)
* Fri Jan 15 2010 aschnell@suse.de
- updated control.rnc
- 2.19.2
* Thu Jan  7 2010 jsuchome@suse.cz
- inst_complex_welcome adapted to Language::SwitchToEnglishIfNeeded
  (bnc#479529)
- 2.19.1
* Fri Dec 11 2009 locilka@suse.cz
- Adapted for new API to ProductLicense (FATE #306295).
* Wed Dec  9 2009 locilka@suse.cz
- Package kde4-kdm has been renamed to kdm (SLES, SLED control
  files) (bnc #561627).
* Wed Dec  9 2009 kmachalkova@suse.cz
- Un-check automatic configuration box when user selects update
  (bnc#537625)
* Wed Dec  9 2009 locilka@suse.cz
- Enabled CIM by default (SLES and SLED) (FATE #305583)
- Adapted RNC for control files
* Wed Dec  9 2009 jsrain@suse.cz
- dereference hardlinks when deploying live CD so that it can
  be also deployed on multiple separate partitions (bnc#549158)
* Mon Nov 30 2009 locilka@suse.cz
- Repositories added by inst_addon_update_sources use
  Pkg::RepositoryAdd that does not need access to network
  (bnc #557723)
* Tue Nov 24 2009 kmachalkova@suse.cz
  Cumulative patch with SLE11 SP1 features:
- In TUI (ncurses), use plain text (.txt) file with release notes,
  if found (FaTE#306167)
- Set /etc/sysconfig/boot:RUN_PARALLEL according to corresponding
  value in control file (FaTE#307555)
- 2.19.0
* Thu Nov 19 2009 locilka@suse.cz
- Added control file configuration option require_registration
  (FATE #305578).
* Wed Nov  4 2009 mzugec@suse.cz
- lan module in 1st stage (FaTE#303069)
- 2.18.34
* Fri Oct 23 2009 jsuchome@suse.cz
- during update, do not save timezone and console settings
  (bnc#547587)
- 2.18.33
* Fri Oct 16 2009 locilka@suse.cz
- Fixed handling repositories during upgrade (bnc #543468).
- 2.18.32
* Wed Oct  7 2009 jsuchome@suse.cz
- set the time after chroot (bnc#538357)
- 2.18.31
* Wed Oct  7 2009 jsuchome@suse.cz
- correctly set the keyboard layout in 2nd stage (bnc#542009)
- 2.18.30
* Thu Oct  1 2009 locilka@suse.cz
- Adjusting understandable name for update URLs added during second
  stage of installation (bnc #542792).
- 2.18.29
* Tue Sep 29 2009 kmachalkova@suse.cz
- Correct HTML format tags in helptext (bnc#540784)
- Set firewall status according to user's choice also in non-automatic
  2nd stage (missing call for AdjustDisabledSubProposals) (bnc#534862)
- 2.18.28
* Thu Sep 24 2009 kmachalkova@suse.cz
- Enable SSH service after reboot if this is SSH or VNC installation
  (new ssh_service_finish client) (bnc#535206)
- 2.18.27
* Mon Sep 14 2009 jsrain@suse.cz
- enhanced display of release notes (fate#306237)
- 2.18.26
* Wed Sep  9 2009 jsrain@suse.cz
- better error handling for image installation (bnc#533601)
- 2.18.25
* Fri Sep  4 2009 kmachalkova@suse.cz
- Introducing unique IDs to unambiguously identify AC steps and
  sub-proposals
- Writing disabled AC steps and subproposals at the end of 1st
  stage, reading them back at the end of 2nd stage
- Filtering out disabled AC steps from AC workflow (FaTE #303859 and
  bnc#534862)
- Require new yast2 base
- 2.18.24
* Fri Sep  4 2009 locilka@suse.cz
- Dropped unnecessary fallback text from the fallback control file
  (BNC #536288).
* Wed Aug 26 2009 locilka@suse.cz
- Do not copy xorg.conf to installed system anymore (bnc #441404).
- 2.18.23
* Fri Aug 21 2009 aschnell@suse.de
- do not disable qt/gtk frontends if xorg.conf is missing (bnc
  [#533159])
- 2.18.22
* Fri Aug 14 2009 kmachalkova@suse.cz
- Simple network (firewall) configuration in 1st stage (FaTE #303859)
* Mon Aug 10 2009 locilka@suse.cz
- added calling bootloader client bootloader_preupdate to control
  file to fix multiple grub entries (bnc #414490, bnc #477778).
* Thu Jul 30 2009 jdsn@suse.de
- disable yast2-x11 during installation (bnc#441404)
- 2.18.21
* Thu Jul 30 2009 jsuchome@suse.cz
- adapted to changes in yast2-country: no saving of xorg.conf
  (bnc#441404)
- 2.18.20
* Wed Jun 24 2009 locilka@suse.cz
- Fixed Welcome dialog layout to have more license content visible
  and to align language and keyboard widgets with it.
- Not offering installation images if there are none (bnc #492745).
- 2.18.19
* Mon Jun 22 2009 coolo@novell.com
- fix build with automake 1.11
- 2.18.18
* Thu Jun 11 2009 jsrain@suse.cz
- adapted for unified progress during live installation
  (bnc#435680)
- 2.18.17
* Mon Jun  8 2009 aschnell@suse.de
- use minimalistic xorg.conf during installation (bnc #510015)
- 2.18.16
* Wed May 20 2009 aschnell@suse.de
- moved .proc.mounts agent from yast2-installation to yast2 (bnc
  [#504429])
* Mon May 18 2009 juhliarik@suse.cz
- added kdump support for autoyast installation (FATE#305588)
* Thu May 14 2009 locilka@suse.cz
- Installation/Upgrade newly require some packages essential for
  them to succeed (bnc #469730).
* Mon Apr 27 2009 locilka@suse.cz
- Using a new yast-spanner (old yast icon) for Repair.
- 2.18.14
* Mon Apr 20 2009 locilka@suse.cz
- Fixed Vendor module to use zypp history file instead of using
  y2logRPM (bnc #456446).
- 2.18.13
* Thu Apr 16 2009 locilka@suse.cz
- Added documentation for installation images.
* Fri Apr 10 2009 locilka@suse.cz
- KDE 3.x dropped from openSUSE control file (bnc #493547).
* Tue Apr  7 2009 ug@suse.de
- changed the error message of missing hard disks during
  autoinstallation. Might confuse s390/iSCSI users. (bnc#476147)
* Mon Mar 30 2009 locilka@suse.cz
- Fixing reevaluation of packages to remove, install and/or upgrade
  after images are deployed during first stage (bnc #489448).
- 2.18.12
* Fri Mar 27 2009 locilka@suse.cz
- Added new globals->ac_redraw_and_ignore control file item
  (openSUSE and SLED) that ignores if AC UI is missing and just
  redraws it. An error is still reported in case of missing Wizard
  widget (bnc #487565).
* Thu Mar 19 2009 locilka@suse.cz
- Continuing on Repair integration.
- Handling missing FLAGS in the content file.
- 2.18.11
* Wed Mar 18 2009 locilka@suse.cz
- Location /etc/modprobe.d/blacklist has been renamed to
  /etc/modprobe.d/50-blacklist.conf (bnc #485980).
- Unified inst_mode handling, especially correct handling of
  Automatic Configuration together with switching to Update mode
  (originally reported as bnc #469273).
- Repair workflow unified with the rest of installation.
- 2.18.10
* Mon Mar 16 2009 locilka@suse.cz
- Fixed help for "License Translations..." button (bnc #481113).
* Tue Mar 10 2009 locilka@suse.cz
- Obsolete 'tar --preserve' replaced with
  'tar --preserve-permissions --preserve-order' (bnc #483791).
- Added recovery support for AC (dialogs) possibly called by AC
  scripts (bnc #483211).
* Thu Feb 26 2009 ug@suse.de
- RPMs via driverupdate were not possible
* Tue Feb 24 2009 locilka@suse.cz
- Added support for .xz images deployment (bnc #476079).
- Added support for `reboot_same_step (bnc #475650).
- 2.18.9
* Mon Feb 23 2009 locilka@suse.cz
- Offering to configure network if remote repositories are used
  during upgrade (inst_upgrade_urls). Setup can be safely skipped
  and comes from the Online Repositories (bnc #478024).
- 2.18.8
* Fri Feb 20 2009 locilka@suse.cz
- save network configuration also for IPv6 only (bnc#477917)
- 2.18.7
* Tue Feb 17 2009 locilka@suse.cz
- Writing additional-control-files index file after removing and
  recreating the directory where it is stored (bnc #475516).
- 2.18.6
* Mon Feb  9 2009 locilka@suse.cz
- Enabling online update in (SLED) Automatic Configuration
  (bnc #449128).
* Fri Feb  6 2009 locilka@suse.cz
- InstError has been moved to yast2-2.18.6
- 2.18.5
* Thu Feb  5 2009 locilka@suse.cz
- InstError extended and documented.
* Mon Feb  2 2009 locilka@suse.cz
- Erasing all old additional control files in the final step of
  upgrade before rebooting to the second stage (bnc #471454).
- InstError can now save YaST logs on user request.
- 2.18.4
* Wed Jan 28 2009 locilka@suse.cz
- Added new InstError module for unified reporting of errors
  during installation.
- Better SlideShow support in inst_finish.
- Reporting more errors in inst_finish.
- 2.18.3
* Tue Jan 27 2009 locilka@suse.cz
- Added test for checking free space when SCR switch fails
  (bnc #460477).
* Mon Jan 26 2009 locilka@suse.cz
- Disabling [Back] buttons in the very first interactive dialogs
  in second stage, SLES and SLED control files (bnc #468677).
* Thu Jan 22 2009 locilka@suse.cz
- Dropping mode_proposal client - not in use anymore.
- 2.18.2
* Wed Jan 21 2009 locilka@suse.cz
- Removing dependency on yast2-runlevel (duplicate code in runlevel
  proposal).
- Removing dependency on yast2-mouse by moving the mouse-related
  scripts to yast2-mouse-2.18.0.
- Removing dependency on yast2-bootloader.
- inst_finish script newly uses the SlideShow module.
* Tue Jan 20 2009 locilka@suse.cz
- Possibility to move the base installation window has been
  disabled (bnc #466827)
- 2.18.1
* Tue Jan 13 2009 locilka@suse.cz
- Adapted the inst_proposal to better reflect the current situation
  'analyzing...' vs. 'adapting the proposal...' (bnc #463567).
* Fri Dec 19 2008 locilka@suse.cz
- Pattern WBEM added into two server scenarios (bnc #458332).
* Thu Dec 18 2008 locilka@suse.cz
- Updated control file documentation (bnc #438678).
* Wed Dec 17 2008 locilka@suse.cz
- Added yet another xset call (bnc #455771 comment #40)
* Tue Dec 16 2008 aschnell@suse.de
- adapted to storage API changes
- 2.18.0
* Tue Dec 16 2008 locilka@suse.cz
- Removed SLED control file labels that should be hidden
  (bnc #459080).
- Using a better help text for inst_new_desktop (bnc #432912).
* Mon Dec 15 2008 locilka@suse.cz
- Removed all (inst_)do_rezise calls from all control files on
  aschnell's request.
* Fri Dec 12 2008 aschnell@suse.de
- require initviocons (bnc #173426)
- 2.17.47
* Tue Dec  9 2008 locilka@suse.cz
- Updated control.rnc
- 2.17.46
* Mon Dec  8 2008 locilka@suse.cz
- Updated control.rnc
- Added two more control-file examples.
- Checking all control files during build.
- Adjusted control-file examples (all bnc #438678).
- Checking the process exit status returned after deploying an
  image (bnc #456337).
- 2.17.45
* Fri Dec  5 2008 locilka@suse.cz
- New control.rnc/rng for control file validation (bnc #455994).
- Added build-time control file validation.
- 2.17.44
* Wed Dec  3 2008 locilka@suse.cz
- inst_extrasources moved before inst_ask_online_update to register
  the online update repository before checking for patches
  (bnc #450229).
* Mon Dec  1 2008 locilka@suse.cz
- Fixed proposing the online update depending on the fact whether
  network is running (bnc #450229).
- 2.17.43
* Fri Nov 28 2008 locilka@suse.cz
- Updated labels of Installation Scenarios for SLES (bnc #428202).
* Fri Nov 28 2008 locilka@suse.cz
- Fixed behavior of inst_new_desktop when user switched to another
  language later (bnc #449818).
- 2.17.42
* Thu Nov 27 2008 locilka@suse.cz
- Using yast-live-install-finish icon when finishing LiveCD
  installation/inst_finish (bnc #438154).
- Fixed ImageInstallation SlideShow - download progress is shown
  only when downloading the images, not the other helper files
  (bnc #449792).
- Adjusting ImageInstallation-related SlideShow only if
  ImageInstallation is in use (bnc #439104).
* Thu Nov 27 2008 ug@suse.de
- the real fix for bnc#442691
  deploy_image_auto doesn't use the boolean variable
  image_installation
- 2.17.41
* Tue Nov 25 2008 locilka@suse.cz
- Handling new feature of licenses ProductLicense::AcceptanceNeeded
  (bnc #448598).
- 2.17.40
* Mon Nov 24 2008 locilka@suse.cz
- Completely initializing the target and sources before checking
  for available patches and offering online update (bnc #447080).
- 2.17.39
* Thu Nov 20 2008 locilka@suse.cz
- Pkg::SourceStartManager in inst_ask_online_update to replace
  obsolete Pkg::PkgEstablish (bnc #447080).
- Reading all supported desktops to define the order of desktops
  in desktop_finish (bnc #446640).
- Added shadow desktops to SLES and SLED desktop files to have
  a fallback if user selects some other desktop than the default
  one (bnc #446640).
- 2.17.38
* Wed Nov 19 2008 locilka@suse.cz
- Added pciutils to Requires, lspci was called but not required
  (bnc #446533).
- 2.17.37
* Wed Nov 19 2008 locilka@suse.cz
- Added inst_fallback_controlfile client reporting about using
  a fallback control file.
- Calling inst_fallback_controlfile in the fallback control file
  (both bnc #440982).
- 2.17.36
* Fri Nov 14 2008 aschnell@suse.de
- don't start iscsid in second stage start scripts (bnc #444976)
- 2.17.35
* Thu Nov 13 2008 locilka@suse.cz
- Flushing the cache before calling a set_polkit_default_privs that
  uses the written data (bnc #440182).
- 2.17.34
* Thu Nov 13 2008 locilka@suse.cz
- Handling errors while deploying images, installation will abort
  (bnc #444209).
- 2.17.33
* Thu Nov 13 2008 ug@suse.de
- checkboxes in the congratulations dialog did not work anymore
  (bnc#444214)
* Tue Nov 11 2008 ug@suse.de
- fix for image deployment during autoinstallation
* Tue Nov 11 2008 juhliarik@suse.cz
- changed order of yast modules in Expert tab for installation
  (bnc #441434)
* Tue Nov 11 2008 jsrain@suse.cz
- fixed switching to a tab with an error in the proposal
  (bnc #441434)
- 2.17.32
* Tue Nov 11 2008 aschnell@suse.de
- use accelerated xserver during installation for certain Intel
  cards (bnc #442413)
- 2.17.31
* Fri Nov  7 2008 locilka@suse.cz
- Fixed deploy_image_auto to handle AutoYaST settings correctly
  (bnc #442691).
- Removing the congrats dialog content before cloning, storing
  the sources, finishing (bnc #441452).
- Using Pkg::SourceProvideDigestedFile function when deploying
  images and in release_notes_popup (bnc #409927).
- 2.17.30
* Thu Nov  6 2008 locilka@suse.cz
- Fixed progress (SlideShow) information about images being
  deployed (bnc #442286).
- Changing inst_deploy_images to use PackagesUI for opening a
  package selector while debugging mode is turned on (bnc #435479).
* Thu Nov  6 2008 jsuchome@suse.cz
- S09-cleanup: check for additional services requiring restart
  (bnc#395402)
* Wed Nov  5 2008 locilka@suse.cz
- Calling set_polkit_default_privs without checking for it using
  FileUtils, checking by 'test -x' instead (bnc #440182).
- 2.17.29
* Wed Nov  5 2008 locilka@suse.cz
- Added yast2-storage >= 2.17.47 because of the previous fix
  implementation.
- 2.17.28
* Tue Nov  4 2008 aschnell@suse.de
- improved warning about partitioning (fate #302857)
- 2.17.27
* Mon Nov  3 2008 locilka@suse.cz
- Writing 'SecondStageRequired' 0/1 to /etc/install.inf even while
  rebooting during second stage (bnc #432005).
- 2.17.26
* Mon Nov  3 2008 aschnell@suse.de
- better reboot message during ssh installation (bnc #439572 and
  bnc #432005)
- 2.17.25
* Fri Oct 31 2008 locilka@suse.cz
- Fixed checking whether running the second stage is required.
- Added writing 'SecondStageRequired' 0/1 to /etc/install.inf
  (both bnc #439572)
- 2.17.24
* Thu Oct 30 2008 locilka@suse.cz
- Saving sources at the end of inst_extrasources if some were
  added (bnc #440184).
- 2.17.23
* Mon Oct 27 2008 locilka@suse.cz
- Added lnussel's patch to run set_polkit_default_privs at
  desktop_finish script (bnc #438698).
- Bigger license window (bnc #438100).
- Calling inst_prepareprogress also during Upgrade, all control
  files changed (bnc #438848).
- Disabling users and auth in LiveCD second stage (bnc #435965).
- Removing label for user_non_interactive (bnc #401319).
- Desktop 'startkde4' replaced with 'startkde' (bnc #438212).
- Added 'kdump' to 'clone_modules' (SLES) (bnc #436365).
- 2.17.22
* Tue Oct 21 2008 locilka@suse.cz
- Added handling for globals->debug_deploying (bnc #436842).
* Mon Oct 20 2008 locilka@suse.cz
- Fixed a typo (bnc #436471).
* Fri Oct 17 2008 locilka@suse.cz
- Adapted SLES and SLED control files to write default desktop
  settings (bnc #436094).
- Added software->display_support_status flag to SLES/SLED
  (bnc #435479).
* Tue Oct 14 2008 locilka@suse.cz
- Changed YaST icons while probing the system (bnc #404809).
- Enhanced scr_switch_debugger - Sending USR1 signal to the new SCR
  (bnc #433057).
- 2.17.21
* Mon Oct 13 2008 locilka@suse.cz
- Enabled going_back in Add-Ons during installation (bnc #434735).
* Mon Oct 13 2008 mzugec@suse.de
- configure supportconfig in installation (fate#305180)
- 2.17.20
* Mon Oct 13 2008 locilka@suse.cz
- Fixed install/update confirmation dialog (bnc #433249).
- Fixed text in openSUSE control file (bnc #432911).
- Fixed typo (bnc #433794).
* Fri Oct 10 2008 locilka@suse.cz
- Enhanced scr_switch_debugger (bnc #433057).
- Enabling key-repeating if not running in XEN (bnc #433338).
* Thu Oct  9 2008 locilka@suse.cz
- Loading the Target while initializing libzypp in
  inst_upgrade_urls (bnc #429080).
- Running a simple SCR Test after chrooting to the installed system
  in scr_switch_finish, full-test is called in case of simple test
  failure (bnc #433057).
- Added more checking around 'searching for files' (bnc #427879).
* Wed Oct  8 2008 aschnell@suse.de
- removed cp of proc/mounts to /etc/mtab (bnc #425464)
- 2.17.19
* Mon Oct  6 2008 locilka@suse.cz
- Do not display any system type for SLES/SLED in installation
  overview (bnc #431336).
- Clients inst_new_desktop and inst_scenarios converted to use
  PackagesProposal API instead of using Pkg calls directly (bnc
  [#432572])
- Dropping obsolete inst_software_selection client instead of
  convwerting it - not in use anymore (bnc #432572).
- Always change initial proposal [Next] button to [Install],
  resp. [Update] (bnc #431567).
- Removing desktop definitions and default_desktop from SLED
  control file, the required patterns are selected by PATTERNS
  in content file already (bnc #431902).
- Adding lnussel's patch for desktop_finish to write
  POLKIT_DEFAULT_PRIVS if defined in globals->polkit_default_privs
  (bnc #431158).
- Adding polkit_default_privs="restrictive" for SLES (bnc #431158).
- 2.17.18
* Fri Oct  3 2008 locilka@suse.cz
- Enabling some steps in second stage even if Automatic
  Configuration is in use.
- Feature added into openSUSE and SLED control files
  (both bnc #428190).
* Thu Oct  2 2008 mzugec@suse.de
- changed Release Notes into Support group (bnc#430005)
* Thu Oct  2 2008 locilka@suse.cz
- Adjusted presentation_order for SLES and SLED installation
  proposals - software has to be proposed as almost the last one
  (bnc #431580).
* Thu Oct  2 2008 locilka@suse.cz
- Added 'default_ntp_setup' into control files (SLES/D: false,
  openSUSE: true) (bnc #431259).
* Thu Oct  2 2008 locilka@suse.cz
- Using two default desktops, one for inst_scenarios, another
  one (default) while inst_scenarios not used (bnc #431251,
  bnc #431503).
- Switching scenario_virtual_machine and
  scenario_virtualization_host in SLES control file (bnc #431251).
- 2.17.17
* Wed Oct  1 2008 mzugec@suse.de
- use rpcbind instead of portmap for nfs installation (bnc#423026)
- 2.17.16
* Wed Oct  1 2008 jsuchome@suse.cz
- if nn_NO language is selected, use nb_NO in YaST (bnc#426124)
* Wed Oct  1 2008 locilka@suse.cz
- Changing pattern "Documentation" to "documentation" (bnc #431218)
* Tue Sep 30 2008 locilka@suse.cz
- Replacing "networkmanager" proposal call with "general"
  (bnc #430704).
* Mon Sep 29 2008 locilka@suse.cz
- Server scenarios work for i386, x86_64 archs only (bnc #430612).
* Mon Sep 29 2008 kukuk@suse.de
- Replaced Minimal+Xen with Dom0.
- Removed xen_server from virtualization machine (bnc #429061).
- Added "XEN" suffix to Virtualization Host.
* Mon Sep 29 2008 locilka@suse.cz
- Adding inst_lilo_convert to the update workflow (bnc #430579).
* Fri Sep 26 2008 locilka@suse.cz
- Optimizing server_selections dialog layout (bnc #429977).
- Better text for installation initialization (bnc #428103).
- Better protection from removing the initial repository
  (bnc #429920).
- 2.17.15
* Thu Sep 25 2008 juhliarik@suse.cz
- added calling kdump_finish to inst_finish.ycp (bnc #427732)
* Tue Sep 23 2008 locilka@suse.cz
- Buggy SCR Agent run.get.suseconfig.modules replaced with
  .target.dir (bnc #429146).
- Added functionality to recover from failed read of previously
  used repositories in inst_upgrade_urls (bnc #429059).
- 2.17.14
* Mon Sep 22 2008 locilka@suse.cz
- Fixed checking whether directory is mounted already (bnc #428368)
* Mon Sep 22 2008 locilka@suse.cz
- KDE 3.5 moved to 'Others', removed KDE 3.5 description text.
- GNOME 2.22 changed to 2.24.
- Fixed Installation Mode dialog to show icons again (bnc #427344).
- 2.17.13
* Mon Sep 22 2008 locilka@suse.cz
- Changing /sbin/udevtrigger & /sbin/udevsettle to /sbin/udevadm
  trigger & settle (bnc #427705).
- 2.17.12
* Thu Sep 18 2008 locilka@suse.cz
- Definition of supported desktops added into SLES and SLED control
  files, added also default_desktop definition (bnc #427061).
- Added control file documentation for supported_desktops section.
* Fri Sep 12 2008 locilka@suse.cz
- Disabling inst_suse_register in openSUSE control file
  (FATE #303458).
* Fri Sep 12 2008 locilka@suse.cz
- Do not remove installation repository with the same URL as URL
  just being removed by inst_upgrade_urls (bnc #400823).
- 2.17.11
* Thu Sep 11 2008 ug@suse.de
- deploy_image.desktop added (Fate #301321)
- deploy_image.rnc added
* Thu Sep 11 2008 locilka@suse.cz
- Calling new client reipl_finish from yast2_inf_finish on s390
  (FATE #304960).
* Wed Sep 10 2008 locilka@suse.cz
- Fixing control files to call 'inst_proposal' instead of
  'proposal' (bnc #425198).
* Wed Sep 10 2008 locilka@suse.cz
- Desktop selection dialog definitions have been moved to control
  file (bnc #424678).
- 2.17.10
* Tue Sep  9 2008 locilka@suse.cz
- Replacing usage of barexml with anyxml SCR  agent (bnc #424263).
* Mon Sep  8 2008 locilka@suse.cz
- merged texts from proofread
* Mon Sep  8 2008 locilka@suse.cz
- Added new AutoYaST client deploy_images_auto to support
  installation from images also in AutoYaST (FATE #301321).
- 2.17.9
* Fri Sep  5 2008 locilka@suse.cz
- Some inst_finish steps are called in live installer only.
- Client vm_finish called only if yast2-vm is installed.
- Using WFM::ClientExists (new in yast2-core-2.17.10).
- Adjusted RPM dependencies.
- 2.17.8
* Thu Sep  4 2008 sschober@suse.de
- cloning section in control.xml changed.
* Wed Sep  3 2008 aschnell@suse.de
- adapted size values in control files to stricter parser in
  storage
* Tue Sep  2 2008 locilka@suse.cz
- Using new <execute/> tag in control file to explicitly define
  a client to be called instead of guessing it from <name/> tag
  (openSUSE, SLED control files) (bnc #401319).
- Updated control files to call inst_prepareprogress to
  "Provide consistent progress during installation" (FATE #303860).
- All 'inst_proposal' calls changed to use the new 'execute'
  feature to have unique 'name's (needed for merging add-on control
  files).
- Adjusted RPM dependencies (FATE #303860).
- 2.17.7
* Tue Sep  2 2008 visnov@suse.cz
- Use unified progressbar during installation (FATE #303860)
* Thu Aug 28 2008 locilka@suse.cz
- Using new ButtonBox widget.
- Adjusted RPM dependencies.
* Thu Aug 21 2008 jsuchome@suse.cz
- check for command line mode in inst_suseconfig (bnc#419132)
* Tue Aug 19 2008 jsrain@suse.cz
- properly detect firstboot and do not destroy xorg.conf
  (bnc#354738)
- 2.17.6
* Fri Aug 15 2008 locilka@suse.cz
- Added new globals->write_hostname_to_hosts control file option
  to configure the default for 127.0.0.2 issue (FATE #303875).
- 2.17.5
* Thu Aug 14 2008 locilka@suse.cz
- Added documentation for add_on_products and its new format
  add_on_products.xml (FATE #303675).
- Fixed SCR Switch Debugger to show "Report Error" only once.
* Wed Aug 13 2008 locilka@suse.cz
- Dropped some obsolete documentation.
- Started installation-features documentation (FATE #303675).
- Fixed building documentation for proposal-API.
* Tue Aug 12 2008 locilka@suse.cz
- Added documentation and example for list of files to be copied
  from the previous installation.
- 2.17.4
* Mon Aug 11 2008 locilka@suse.cz
- List of files to be copied from the previous installation moved
  to control file, added new API to define own list (module
  SystemFilesCopy) (FATE #305019).
- Adapted control files.
* Mon Aug 11 2008 locilka@suse.cz
- Fixed WFM::Execute to use .local instead of .target in
  copy_files_finish script.
* Thu Aug  7 2008 locilka@suse.cz
- Added new client inst_scenarios to offer main scenarios of the
  newly installed system.
- Configuration for inst_scenarios is defined in control file (Only
  SLES so far), client added into SLES workflow.
- Extended control file documentation (All FATE #304373).
- 2.17.3
* Wed Aug  6 2008 locilka@suse.cz
- New control file entry globals->enable_kdump (default value)
  (FATE #303893).
- Adjusted control file documentation.
* Tue Aug  5 2008 locilka@suse.cz
- Calling reiplauto client in SLES control file before reboot
  (FATE #304940).
- Running SCR Switch Debugger unconditionally if switching to
  installed system fails (bnc #411832).
* Mon Aug  4 2008 aschnell@suse.de
- improved text during ssh installation (bnc #411079)
* Mon Aug  4 2008 locilka@suse.cz
- Added kdump proposal to SLES control file (FATE #303893).
* Thu Jul 24 2008 locilka@suse.cz
- Using button label "License Translations..." in complex welcome
  dialog (bnc #400616).
- SLES and SLED control files adapted to features added in 11.0.
- Added Automatic Configuration support into SLED (FATE #303396).
* Tue Jul 15 2008 aschnell@suse.de
- fixed vnc connect message during installation (bnc #395834)
- 2.17.2
* Tue Jul 15 2008 locilka@suse.cz
- Not only DPMS->off, but also screen-saver->off (FATE #304395).
- Added new control file feature globals->rle_offer_rulevel_4
  plus control file documentation (FATE #303798).
* Mon Jul 14 2008 locilka@suse.cz
- Base-product license directory moved to control file
  (base_product_license_directory) (FATE #304865).
- Copying licenses to the system in copy_files_finish.
- Reading the license directory in inst_license.
- Icons for AC steps defined in control file.
- Adjusting DPMS 'off' when installation starts, DPMS 'on' when
  finishes (FATE #304395).
- Icons for inst_finish.
- 2.17.1
* Fri Jul 11 2008 locilka@suse.cz
- Added documentation for AC Setup and for texts in control file.
* Thu Jul 10 2008 locilka@suse.cz
- Settings for Automatic Configuration moved to control file
  because of code reuse for different AC in first boot
  (FATE #303939).
* Thu Jul 10 2008 locilka@suse.cz
- Only directories in release-notes directory are considered to be
  real release notes (bnc #407922).
- 2.17.0
* Wed Jul  9 2008 mvidner@suse.cz
- Fixed building in a prefix (/etc).
* Wed Jul  9 2008 locilka@suse.cz
- Initializing the 'use_automatic_configuration' in first-stage
  installation worker (bnc #404122).
- Adjusted dependency on autoyast2-installation bacause of new
  function AutoinstConfig::getProposalList().
* Thu Jun 26 2008 locilka@suse.cz
- Fixed help text for deploying images (bnc #391086).
- Fixed 'Do not panic!' text (bnc #388251).
* Wed Jun 25 2008 ug@suse.de
- proposal selection possible via autoyast profile (fate#302946)
* Tue Jun 17 2008 lslezak@suse.cz
- use Pkg::SourceSaveAll() instead of Pkg::SourceFinishAll()
  (bnc#395738)
* Fri Jun 13 2008 locilka@suse.cz
- Removing Pkg//Source and Target finish from inst_inc_all that
  had been saving sources also in case of aborting the installation
  and moving it to inst_congratulate and umount_finish
  (bnc #398315).
- Freeing internal variables in ImageInstallation module after
  images are deployed (bnc #395030).
* Thu Jun 12 2008 locilka@suse.cz
- Special mounts (such as /proc) are never remounted read-only
  in umount_finish anymore (bnc #395034)
- Added progress for adding / removing repositories in
  inst_upgrade_urls client (bnc #399223)
* Wed Jun  4 2008 locilka@suse.cz
- Copying /license.tar.gz to /etc/YaST2/license/ (bnc #396444).
- Initial mouse probing has been disabled (bnc #395426).
* Tue Jun  3 2008 locilka@suse.cz
- Umounting temporary directory in inst_pre_install (if already
  mounted) before new mount is called.
- Always use --numeric-owner (always use numbers for user/group
  names) when deploying images (bnc #396689).
* Mon Jun  2 2008 locilka@suse.cz
- Return `next when going back to the automatic configuration
  dialog instead of returning `auto that would finish YaST and
  never start it again (bnc #395098).
- 2.16.49
* Wed May 28 2008 ug@suse.de
- timeout in case of hardware probing problems
  when autoyast is in use (especially for harddisk Reports)
  bnc#395099
- 2.16.48
* Mon May 19 2008 locilka@suse.cz
- Creating SuSEConfig hook file at installation_settings_finish
  in case of update. The file has to be created to force the
  SuSEConfig run on first boot (bnc #390930).
- Workaround for as-big-dialog-as-possible in License Agreement
  dialog (bnc #385257).
- Adding FACTORY repositories with priority 120, update source with
  priority 20 (bnc #392039).
- 2.16.47
* Fri May 16 2008 jsrain@suse.cz
- added categories Settings and System into desktop file
  (bnc #382778)
* Thu May 15 2008 locilka@suse.cz
- Changed dialog content for starting the installation
  (bnc #390614).
- Fixed sorting of repositories offered during upgrade to sort by
  repository name (bnc #390612).
- 2.16.46
* Thu May 15 2008 jsuchome@suse.cz
- sort keyboard list according to translated items (bnc #390610)
* Wed May 14 2008 kmachalkova@suse.cz
- inst_hostname client added to automatic configuration scripts -
  needed to generate random hostname and 127.0.0.2 line in
  /etc/hosts (bnc #383336)
* Wed May 14 2008 jsrain@suse.cz
- use process agent instead of background agent when installing
  live image (bnc #384960)
- 2.16.45
* Mon May 12 2008 locilka@suse.cz
- Added help to "Image Deployment" (bnc #388665).
* Tue May  6 2008 locilka@suse.cz
- When reusing the old repositories during upgrade, copying also
  'autorefresh' and 'alias' (bnc #387261).
- Added software->dropped_packages into the control file to replace
  'delete old packages' (bnc #300540).
- 2.16.44
* Mon May  5 2008 locilka@suse.cz
- Typofix (bnc #386606).
* Fri May  2 2008 mzugec@suse.cz
- Don't stop network (by killing dhcpcd) at the end of 1.st stage
  (bnc #386588)
* Wed Apr 30 2008 locilka@suse.cz
- Adding name and alias tags to extrasources (irc #yast/today).
- 2.16.43
* Wed Apr 30 2008 locilka@suse.cz
- Making automatic installation more robust (bnc #384972).
- 2.16.42
* Tue Apr 29 2008 locilka@suse.cz
- Disabling Progress when calling inst_finish scripts.
* Mon Apr 28 2008 locilka@suse.cz
- Handling KDE3 vs KDE4 in default logon and window managers
  (bnc #381821).
- Optional and extra URLs moved to control file as well as default
  update repository (bnc #381360).
- Added possibility to abort installation during image deployment
  (bnc #382326).
- Progress for inst_proposal.
- 2.16.41
* Fri Apr 25 2008 locilka@suse.cz
- New desktop selection dialog (bnc #379157).
- 2.16.40
* Thu Apr 24 2008 locilka@suse.cz
- New  better shiny unified progress for image deployment.
- Showing also the just-handled image name (bnc #381188).
- 2.16.39
* Wed Apr 23 2008 locilka@suse.cz
- Enabling inst_suseconfig in Automatic configuration (bnc #381751)
- Fixed run_df agent to ignore read errors on rootfs (bnc #382733)
* Tue Apr 22 2008 locilka@suse.cz
- Adjusting automatic configuration UI to use two progress bars
  instead of one.
* Tue Apr 22 2008 locilka@suse.cz
- Fixed filtering-out already registered repos (bnc #379051).
- Client inst_prepare_image moved to installation proposal make
  disabling 'installation from images' easy (bnc #381234).
- 2.16.38
* Mon Apr 21 2008 locilka@suse.cz
- Calling 'xset r off' & 'xset m 1' (bnc #376945).
- Better help for Automatic configuration (bnc #381904).
* Mon Apr 21 2008 locilka@suse.cz
- Using new DefaultDesktop::SelectedDesktops for writing the
  display manager configuration.
* Fri Apr 18 2008 locilka@suse.cz
- Calling 'xset -r off' at the beginning of installation (both
  first and second stage) in X on XEN (bnc #376945).
* Fri Apr 18 2008 juhliarik@suse.cz
- Added text for using kexec (yast_inf_finish.ycp)
* Thu Apr 17 2008 locilka@suse.cz
- Added more debugging messages into ImageInstallation module.
* Thu Apr 17 2008 locilka@suse.cz
- Added image-downloading progress (reusing existent progress bar).
- 2.16.37
* Wed Apr 16 2008 locilka@suse.cz
- Running runlevel proposal after software proposal (bnc #380141).
- Using new possibility to disable and then reenable package
  callbacks (system_analysis, deploy_images).
* Tue Apr 15 2008 locilka@suse.cz
- ImageInstallation tries to find details-<arch>.xml, then
  details.xml to provide useful progress while deploying images.
- 2.16.36
* Tue Apr 15 2008 mvidner@suse.cz
- Enable printing the last few debugging log messages in the crash
  handler, even if Y2DEBUG is not set (fate#302166).
- 2.16.35
* Mon Apr 14 2008 locilka@suse.cz
- Fixed typo in inst_network_check (bnc #379491).
- Fixed help for inst_mode (bnc #374360).
* Mon Apr 14 2008 locilka@suse.cz
- Modifying SystemFilesCopy::CopyFilesToSystem to newly accept
  a parameter which defines where to extract cached files
  (fate #302980).
- Caching system files in the System Analysis dialog.
- Some better texts (bnc #377959).
- Better text for Software Selection dialog (bnc #379157).
- 2.16.34
* Fri Apr 11 2008 locilka@suse.cz
- Changing Accept buttons to Install, Update and OK (FATE #120373).
* Fri Apr 11 2008 locilka@suse.cz
- Added another per-image progress into the Installation images
  deployment (it requires details.xml).
- 2.16.33
* Fri Apr 11 2008 juhliarik@suse.cz
- Added loading kernel via kexec (fate #303395)
* Thu Apr 10 2008 locilka@suse.cz
- Filtering installation imagesets using the default architecture.
- Installation from images sets the download area (SourceManager).
- Removing image after it is deployed.
- Preparing image installation dialog for two progress-bars.
- 2.16.32
* Wed Apr  9 2008 jsrain@suse.cz
- handle compressed logs properly at the end of first stage
  installation (fate #300637)
- 2.16.31
* Tue Apr  8 2008 locilka@suse.cz
- Adjusted control file to sort installation overview via
  presentation_order and propose it via the real appearance.
- Fixed selecting the right imageset - the rule is currently that
  all patterns in imageset must be selected for installation
  (bnc #378032).
* Mon Apr  7 2008 locilka@suse.cz
- Added new control file entry kexec_reboot that defines whether
  kexec should be used instead of reboot at the end of the first
  stage installation (FATE #303395).
* Fri Apr  4 2008 locilka@suse.cz
- Improved user-feedback during automatic configuration.
- 2.16.30
* Fri Apr  4 2008 jsrain@suse.cz
- added restart handling for live installation
* Thu Apr  3 2008 locilka@suse.cz
- Removed Winkeys support during installation (bnc 376248).
- Fixed the decision-making process which images fits the best.
- Added new control file entries to adjust the Community
  Repositories and Add-Ons during installation.
- Cosmetic changes when initializing the wizard steps according to
  control file.
- Fixed untarring bzip2 or gzip-based images.
- Changed instalation from images to count the best image-set
  from patterns (list of patterns in image-set) in images.xml.
- 2.16.29
* Tue Apr  1 2008 locilka@suse.cz
- Automatic configuration can be newly defined by control file. Two
  new variables have been added enable_autoconfiguration and
  autoconfiguration_default.
- New functionality to select the best-matching image for image
  installation if more than one fit.
- 2.16.28
* Tue Apr  1 2008 jsrain@suse.cz
- added live installation workflow to default control file
- updated inst_finish clients handling for live installation
* Tue Apr  1 2008 jsrain@suse.cz
- merged texts from proofread
* Mon Mar 31 2008 locilka@suse.cz
- There are currently two possible patterns/desktops that can use
  kdm: kde4-kdm and kdebase3-kdm (bnc #372506).
* Fri Mar 28 2008 locilka@suse.cz
- Automatic configuration has been moved from the end of the first
  stage to the second stage. It's non-interactive (FATE #303396).
- Fixed installation from images (FATE #303554).
- ImageInstallation can newly handle .lzma images.
- 2.16.27
* Thu Mar 27 2008 locilka@suse.cz
- Fixed ZMD service handling, the correct name is novell-zmd
  (bnc #356655).
* Wed Mar 26 2008 locilka@suse.cz
- Added new entry to control file root_password_as_first_user to
  make it configurable (bnc #359115 comment #14).
- Control file modified to call installation-from-images clients.
* Tue Mar 25 2008 locilka@suse.cz
- Using Image-Installation clients (done by jsrain).
- Store/Restore resolvable-state functions added into
  ImageInstallation module.
* Fri Mar 21 2008 locilka@suse.cz
- Dropping keep_installed_patches support from control file as it
  is currently handled by libzypp itself (bnc #349533).
* Thu Mar 20 2008 locilka@suse.cz
- Added system_settings_finish call to the inst_finish
  (bnc #340733).
* Wed Mar 19 2008 locilka@suse.cz
- Agent anyxml has been renamed to barexml as it can't really read
  all possible XML files (bnc #366867)
* Wed Mar 19 2008 locilka@suse.cz
- When checking whether to run the second stage, considering also
  autoinstallation, not only installation (bnc #372322).
- 2.16.26
* Tue Mar 18 2008 locilka@suse.cz
- Fixed writing disabled modules and proposals during the
  inst_finish run (bnc #364066).
- Calling pre_umount_finish also in AutoYaST (bnc #372322).
- 2.16.25
* Mon Mar 17 2008 jsrain@suse.cz
- added 'StartupNotify=true' to the desktop file (bnc #304964)
* Mon Mar 17 2008 locilka@suse.cz
- Automatic configuration is now disabled for mode update.
- The whole second stage in now disabled for mode update.
- Added help text for "Use Automatic Configuration" check-box.
- 2.16.24
* Fri Mar 14 2008 locilka@suse.cz
- Added possibility to run automatic configuration instead of the
  whole second stage installation (fate #303396).
- Adjusted RPM dependencies.
- Creating and removing the file runme_at_boot is currently handled
  by YaST (YCP) installation scripts.
- Added new client inst_rpmcopy_secondstage that calls inst_rpmcopy
  because of DisabledModules disabling both first and second stage
  occurency of that script.
- Changed control file to call the new script in second stage.
- 2.16.23
* Mon Mar 10 2008 locilka@suse.cz
- Disabling the window menu in IceWM preferences to make the
  inst-sys 600 kB smaller (*.mo files). Thanks to mmarek.
* Fri Mar  7 2008 jsuchome@suse.cz
- control.openSUSE.xml: country_simple is for keyboard and language,
  not for timezone
- added 1st stage step for root password dialog (fate#302980)
- 2.16.22
* Thu Mar  6 2008 aschnell@suse.de
- call rcnetwork with option onboot during start of second stage
  (bnc #363423)
- 2.16.21
* Wed Mar  5 2008 locilka@suse.cz
- Remember (first stage) and restore (second stage) DisabledModules
  (bnc #364066).
- 2.16.20
* Wed Mar  5 2008 locilka@suse.cz
- Using client country_simple instead of timezone and language in
  the installation overview (FATE #302980).
- Using new users client in that overview too (FATE #302980).
- Do not remove already registered installation repositories during
  upgrade if they match the old repositories on system
  (bnc #360109).
* Mon Mar  3 2008 coolo@suse.de
- trying to change defaults for running gdb (arvin's patch)
* Mon Mar  3 2008 locilka@suse.cz
- Requiring the latest Language::Set functionality by RPM deps.
* Tue Feb 26 2008 jsuchome@suse.cz
- functionality of integrate_translation_extension.ycp moved into
  Language::Set, inst_complex_welcome adapted (F#302955)
* Fri Feb 22 2008 locilka@suse.cz
- "iscsi-client" added into modules to clone (bnc #363229 c#1).
- Removing focus from release notes content to make the default
  button focussed instead (bnc #363976).
* Thu Feb 21 2008 coolo@suse.de
- don't repeat the header
* Wed Feb 20 2008 locilka@suse.cz
- Showing release notes in tabs only if more than one product is
  installed (bnc #359137).
- Added better text for the complex welcome dialog (bnc #359528).
- Adjusted RPM dependencies (new Language API, see below).
- 2.16.19
* Wed Feb 20 2008 jsuchome@suse.cz
- inst_complex_welcome: save keyboard settings (bnc #360559),
  use the API from Language.ycp for generating items
* Fri Feb 15 2008 jsrain@suse.cz
- updated image-based installatoin not to use any hardcoded
  image names
* Thu Feb 14 2008 locilka@suse.cz
- Function FileSystemCopy from live-installer has been moved
  to ImageInstallation module (installation).
- Adjusted RPM dependencies (Installation module in yast2).
* Wed Feb 13 2008 jsrain@suse.cz
- added handling of update initiated from running system
* Tue Feb 12 2008 locilka@suse.cz
- Added new update_wizard_steps YCP client for easy updating or
  redrawing installation wizard steps from other modules.
* Mon Feb 11 2008 locilka@suse.cz
- Installation clients 'auth', 'user', and 'root' have been
  disabled by default. First-stage users will enable them only
  if needed.
* Fri Feb  8 2008 aschnell@suse.de
- during installation allow yast to be started from gdb with
  Y2GDB=1 on kernel command line (fate #302346)
* Fri Feb  8 2008 locilka@suse.cz
- Umount(s) used with -l and -f params.
* Thu Feb  7 2008 locilka@suse.cz
- Functionality that integrates the just-selected language
  translation has been moved to integrate_translation_extension
  client to make it available for other modules.
- New label for "Show in Fullscreen" button to better match what
  it really does (bnc #359527).
- Module InstExtensionImage moved to yast2.
- Added new disintegrate_all_extensions client that is called at
  the end of the initial installation to umount and remove all
  integrated inst-sys extensions.
- 2.16.18
* Wed Feb  6 2008 locilka@suse.cz
- Better /lbin/wget handling in InstExtensionImage.
- Speed-up inst_complex_welcome optimalizations (e.g., skipping
  downloading extension already by Linuxrc)
* Tue Feb  5 2008 locilka@suse.cz
- Squashfs image needs to be mounted using '-o loop'.
- Displaying busy cursor when downloading the extension.
- 2.16.17
* Mon Feb  4 2008 locilka@suse.cz
- Modular inst-sys used for localizations (FATE #302955).
- Tabs have been removed from installation proposal.
- 2.16.16
* Fri Feb  1 2008 locilka@suse.cz
- Added new InstExtensionImage module for integration of modular
  inst-sys images on-the-fly (FATE #302955).
* Thu Jan 31 2008 aschnell@suse.de
- reflect init-script rename from suse-blinux to sbl
- 2.16.15
* Thu Jan 31 2008 jsuchome@suse.cz
- call users_finish.ycp from inst_finish.ycp (FATE #302980)
* Thu Jan 31 2008 locilka@suse.cz
- Fixed inst_restore_settings client: NetworkDevices are now
  NetworkInterfaces.
- 2.16.14
* Thu Jan 31 2008 locilka@suse.cz
- Added docu. for *_finish scripts (needed for FATE #302980).
- Welcome dialog can newly show the license according to the just
  selected language and also show other lozalizations if needed.
- 2.16.13
* Wed Jan 30 2008 aschnell@suse.de
- Use icewm instead of fvwm during installation (bnc #357240)
- 2.16.12
* Wed Jan 30 2008 fehr@suse.de
- Add installation step for disk partitioning between time zone
  and software selection
- put user config after disk partitioning
* Wed Jan 30 2008 locilka@suse.cz
- Added -noreset option to the VNC startup script (bnc #351338).
- Added inst_user_first.ycp call to the control file right before
  the installation proposal.
- Fixed visibility of ZMD Turnoff checkbox (bnc #356655).
* Tue Jan 29 2008 locilka@suse.cz
- New desktop selection dialog without system task combo-boxes.
  System selection with icons (bnc #356926).
- More UI checking in dialogs.
- Unified DefaultDesktop module and software/desktop selection
  dialog in installation.
* Mon Jan 28 2008 aschnell@suse.de
- support Qt and Gtk frontend in startup scripts
- hack for key-autorepeat during installation (bnc #346186)
- 2.16.11
* Fri Jan 25 2008 locilka@suse.cz
- Reduced Wizard redrawing in the installation workflow.
* Thu Jan 24 2008 aschnell@suse.de
- start service brld before suse-blinux (bug #354769)
- 2.16.10
* Mon Jan 21 2008 kmachalkova@suse.cz
- Re-enabled thread support for ncurses UI in YaST2.call
  (bug #164999, FaTE #301899)
* Mon Jan 21 2008 locilka@suse.cz
- Release Notes UI facelifting.
- Splitting Welcome script dialog single-loop into functions.
* Wed Jan 16 2008 locilka@suse.cz
- Calling SetPackageLocale and SetTextLocale in the initial
  installation dialog (selecting language) (#354133).
* Mon Jan 14 2008 locilka@suse.cz
- Added new Language/Keyboard/License dialog (FATE #302957).
- Updated control files.
- 2.16.9
* Thu Jan 10 2008 locilka@suse.cz
- Extended system type and software selection dialog. Added base
  pattern (selected desktop) description, helps, default status
  for secondary selections, ...
- Added possibility to control visibility of Online Repositories
  via the installation control file (hidden by default).
- Added more control-file documentation.
* Tue Dec 18 2007 locilka@suse.cz
- Added new desktop and software selection dialog.
- 2.16.8
* Mon Dec 17 2007 locilka@suse.cz
- Hidden Mouse-probing busy popup.
- New YCP module InstData stores the installation data that should
  be shared among the installation clients.
- Installation repository initialization moved to the unified
  progress when probing the system.
- System analysis has been split into two scripts: inst_mode and
  inst_system_analysis to make the maintenance easier (also in
  control file).
- 2.16.7
* Thu Dec 13 2007 locilka@suse.cz
- Added a possibility to stop and disable the ZMD service in the
  last (congratulate) dialog of installation (FATE #302495).
- Adjusted the SLES control file: module arguments
  'show_zmd_turnoff_checkbox' and 'zmd_turnoff_default_state'.
* Mon Dec 10 2007 locilka@suse.cz
- Removed dependency on yast2-country, added dependency on
  yast2-country-data.
* Wed Dec  5 2007 mzugec@suse.cz
- description says network cards are wireless (#346133)
* Mon Dec  3 2007 locilka@suse.cz
- Installation Mode dialog adapted to new bright and better mod_UI.
- Using informative icon in some inst_network_check script.
- 2.16.6
* Mon Dec  3 2007 locilka@suse.cz
- Installation Mode dialog adapted to new mod-UI and to new
  Image-Dimming support in UI.
* Thu Nov 29 2007 locilka@suse.cz
- Using Progress::NewProgressIcons to show icons during the network
  setup in first stage and during system probing.
* Tue Nov 27 2007 sh@suse.de
- Use string ID "contents" rather than YCPSymbol `contents
  for Wizard ReplacePoint
- 2.16.5
* Fri Nov 23 2007 locilka@suse.cz
- Using translations for inst_finish steps (#343783).
- 2.16.4
* Tue Nov 20 2007 locilka@suse.cz
- Shutting down all dhcpcd clients when reconfiguring network in
  the first stage and when finishing the installation (#308577).
- 'Copy 70-persistent-cd.rules' functionality has been moved here
  from yast2-network (#328126).
* Mon Nov 19 2007 locilka@suse.cz
- Fixed busy texts for restarting YaST vs. finishing the instal.
- Unified used terminology (repositories) (FATE #302970).
* Tue Nov 13 2007 locilka@suse.cz
- Script copy_files_finish.ycp cleaned up.
* Fri Nov  9 2007 locilka@suse.cz
- Boot Installed System option has been removed (#327505).
- Installation Mode dialog has been redesigned using
  self-descriptive icons for all options.
- Return value from inst_repair is evaluated, error is reported in
  case of failure.
- 2.16.3
* Fri Nov  2 2007 locilka@suse.cz
- Adjusted RPM dependencies (Internet module has been moved from
  yast2-network to yast2).
* Tue Oct 30 2007 locilka@suse.cz
- Modules Hotplug and HwStatus moved to yast2.rpm to remove
  dependency of storage on installation.
- 2.16.2
* Wed Oct 24 2007 locilka@suse.cz
- Changes in StorageDevice module API (#335582).
- 2.16.1
* Mon Oct 15 2007 locilka@suse.cz
- Abort the installation instead of halting the system in case of
  declining the license when installing from LiveCD (#330730).
* Thu Oct 11 2007 jsrain@suse.cz
- show release notes properly in live installation (#332862)
* Wed Oct  3 2007 locilka@suse.cz
- Added "Network Type" information to the First Stage Network Setup
- 2.16.0
* Wed Oct  3 2007 mvidner@suse.cz
- Do not try to package COPYRIGHT.english, it is gone from
  devtools (#299144).
* Tue Oct  2 2007 ug@suse.de
- typo fixed (#328172)
* Mon Sep 24 2007 locilka@suse.cz
- Changed default delete_old_packages back to 'true' after finding
  and fixing all remaining issues with 'false' (changed by coolo)
- Added new option 'online_repos_preselected' into the control file
  to make default status of Online Repositories easily configurable
  (#327791).
- Initializing the default behavior of Online Repositories in
  inst_features according to the control file (#327791).
- 2.15.54
* Fri Sep 21 2007 locilka@suse.cz
- Start dhcpcd using WFM instead of SCR (#326342).
- 2.15.53
* Fri Sep 21 2007 locilka@suse.cz
- When normal umount at the end of the installation fails, try
  at least: sync, remount read-only, umount --force.
- Report all services running in the installation directory
  (both #326478).
- 2.15.52
* Thu Sep 20 2007 locilka@suse.cz
- Changed inst_upgrade_urls to add sources not enabled during the
  upgrade in a disabled state instead of ignoring them (#326342).
- 2.15.51
* Tue Sep 18 2007 locilka@suse.cz
- Fixed tar syntax: --ignore-failed-read param. position (#326055).
- 2.15.50
* Thu Sep 13 2007 locilka@suse.cz
- Fixed inst_upgrade_urls to re-register sources with their
  repository names taken from the upgraded system (#310209).
- 2.15.49
* Tue Sep 11 2007 aschnell@suse.de
- don't swapoff after 1st stage installation (bug #308121)
- 2.15.48
* Tue Sep 11 2007 locilka@suse.cz
- Calling ntp-client_finish instead of ntp_client_finish in the
  inst_finish script (#309430).
* Wed Sep  5 2007 locilka@suse.cz
- Reinitializing variable for skipping add-on-related clients with
  its default value in inst_system_analysis (#305554).
- 2.15.47
* Wed Sep  5 2007 jsrain@suse.cz
- removed inst_fam.ycp (also from control files) (#307378)
* Mon Sep  3 2007 locilka@suse.cz
- Creating symlinks to .curlrc and .wgetrc files from the root.
- Adjusting RPM dependencies (yast2-core, new builtin 'setenv').
- Adjusting ENV variables with proxy settings (all three #305163).
- Writing also proxy setting into Install.inf (#298001#c5).
- 2.15.46
* Fri Aug 31 2007 locilka@suse.cz
- Calling ntp_client_finish client at the end of the installation
  (#299238#c9).
- 2.15.45
* Fri Aug 24 2007 locilka@suse.cz
- Changing forgotten "catalogs" to "initializing..." (#302384).
- 2.15.44
* Tue Aug 21 2007 locilka@suse.cz
- Fixed evaluating of "enabled" tag in map of repositories in
  inst_upgrade_urls (#300901).
- Added ssh_host_dsa_key ssh_host_dsa_key.pub ssh_host_rsa_key
  ssh_host_rsa_key.pub to be optionally copied as well as the SSH1
  keys (#298798).
- Allowing to abort the "System Probing" dialog (#298049).
- 2.15.43
* Wed Aug 15 2007 mzugec@suse.cz
- mark string for translation (#300268)
* Fri Aug 10 2007 locilka@suse.cz
- Using "Online Repositories" for Internet/Web-based/Additional/...
  repositories downloaded from web during the first stage
  installation (#296407).
- 2.15.42
* Wed Aug  8 2007 jsrain@suse.cz
- show reboot message within live installation without timeout
  (#297691)
- 2.15.41
* Mon Aug  6 2007 locilka@suse.cz
- Renamed product/default repositories check-box to "Add Internet
  Repositories Before Installation" (#297580).
- Added help for that check-box (#296810).
- First stage network setup dialog - changes in dialog alignment
  (#295043).
- Initialize mouse after installation steps are displayed (#296406)
- 2.15.40
* Thu Aug  2 2007 jsrain@suse.cz
- do not show "Clone" check box in live installation
- 2.15.39
* Wed Aug  1 2007 locilka@suse.cz
- Changing remote repositories link to http://download.opensuse.org
  (#297628)
* Wed Aug  1 2007 mvidner@suse.cz
- Removed Provides/Obsoletes for ancient yast package names,
  with the devel-doc subpackage they broke yast2-schema build.
- 2.15.38
* Tue Jul 31 2007 lslezak@suse.cz
- inst_extrasources - register the extra repositories in content
  file automatically without asking user (#290040), do not download
  metadata from the extra sources (offline registration) (#290040,
  [#288640])
* Mon Jul 30 2007 locilka@suse.cz
- Added inst_upgrade_urls client which offers URLs used on the
  system to be used during the upgrade as well (FATE #301785).
- Calling the client from control file.
- Adjusted RPM dependencies (.anyxml SCR agent).
- 2.15.37
* Sun Jul 29 2007 locilka@suse.cz
- Fixed curl parameters for network test in first stage (#295484).
* Thu Jul 26 2007 mzugec@suse.cz
- set variables VNC and USE_SSH in S07-medium (#294485)
- 2.15.36
* Wed Jul 25 2007 mvidner@suse.cz
- startup scripts: Call initviocons only if it exists (#173426).
- 2.15.35
* Wed Jul 25 2007 locilka@suse.cz
- Renamed yast2-installation-doc to yast2-installation-devel-doc
  (FATE #302461).
- Removed ping-based internet test from the First-stage network
  setup test.
- Sped up internet test by adding timeouts and by downloading only
  the page header.
- Added help texts to the network setup dialogs.
* Tue Jul 24 2007 locilka@suse.cz
- Control file: Unified wizard step names with dialogs, removed
  Clean Up step part of the Online Update is now Registration
  (#293095).
- Call inst_network_check (and setup) only in Add-On products
  and/or Additional Product Sources were requested to be used
  (#293808).
* Tue Jul 24 2007 locilka@suse.cz
- Splitting auto-generated documentation into separate package
  yast2-installation-doc (FATE #302461).
- 2.15.34
* Thu Jul 19 2007 locilka@suse.cz
- If network setup in the first-stage installation is cancelled,
  return to the previous dialog (network check).
- Several minor updates of the network setup workflow (#292379).
- 2.15.33
* Wed Jul 18 2007 locilka@suse.cz
- New progress and help messages when initializing the second
  stage (#292617).
- More debugging in switch_scr_finish.
* Thu Jul 12 2007 locilka@suse.cz
- Client inst_productsources.ycp moved to yast2-packager.
- Changed link to list of servers in control file.
- Adjusted RPM dependencies.
- Installation sources are now Repositories.
- 2.15.32
* Wed Jul 11 2007 locilka@suse.cz
- Changed default delete_old_packages to 'false'.
* Wed Jul  4 2007 locilka@suse.cz
- Fixed workflow when user selects to Boot the installed system and
  then cancels that decision.
- 2.15.31
* Mon Jul  2 2007 locilka@suse.cz
- Applied patch from sassmann@novell.com for PS3 support with
  576x384 resolution (#273147).
* Fri Jun 29 2007 locilka@suse.cz
- Extended "Suggested Installation Sources" to support two levels
  of linking. First link contains list of links to be downloaded
  in order to get lists of suggested repositories.
* Thu Jun 28 2007 jsrain@suse.cz
- updated for live CD installation
* Thu Jun 21 2007 adrian@suse.de
- fix changelog entry order
* Thu Jun 21 2007 locilka@suse.cz
- Added handling for "Suggested Installation Sources" during the
  first stage installation, initial evrsion (FATE #300898).
- Enhanced SCR-Switch installation-debugger.
- Added case-insensitive filter into the "Suggested Installation
  Sources" dialog.
* Wed Jun 20 2007 locilka@suse.cz
- Fixed inst_license to really halt the system when license is
  declined (#282958).
- Fixed writing proxy settings during First-Stage Installation,
  Network Setup. Wrong Proxy::Import keys were used).
- Pre-selecting first connected network card in Network Card dialog
  in First-Stage Installation, Network Setup to avoid confusions.
- Fixed canceled Network Setup not to abort the entire
  installation.
* Fri Jun 15 2007 locilka@suse.cz
- Fixing inst_addon_update_sources to initialize the target
  and sources before using Pkg:: builtins (#270899#c29).
* Thu Jun 14 2007 locilka@suse.cz
- Enhanced network-test in the fist stage installation, three
  different servers are tested with 'ping' instead of only one.
- Current network settings are logged in case of failed network
  test (both #283841).
- Enhanced network-test in the fist stage installation, three
  different web-servers are tested with curl instead of only one.
* Wed Jun 13 2007 locilka@suse.cz
- Implemented new feature that saves the content defined in control
  file from the installation system to the just installed system.
  Function, that does it, is SaveInstSysContent in SystemFilesCopy
  module (FATE #301937).
- Added new entry into the control file that defines what and where
  to save it, initially /root/ -> /root/inst-sys/.
- Adjusted control-file documentation.
- Fixed inst_restore_settings to start SuSEfirewall2_setup if it is
  enabled in the system init scripts to prevent from having
  half-started firewall after YOU kernel-update (#282871).
* Mon Jun 11 2007 locilka@suse.cz
- Added lost fix from Andreas Schwab for startup scripts. The patch
  fixes evaluation of bash expressions.
- 2.15.30
* Mon Jun 11 2007 locilka@suse.cz
- Adjusted SCR for install.inf to provide read/write access.
- Writing install.inf for save_network script at the end of
  the initial stage.
- Changed internal data structure for NetworkSetup in the initial
  stage.
- Added Internet test to the end of the NetworkSetup in the initial
  stage.
- 2.15.29
* Fri Jun  8 2007 locilka@suse.cz
- Added initial implementation of possibility to setup network
  in the first stage installation. New YCP clients have beed added:
  inst_network_check and inst_network_setup. Scripts are called
  from inst_system_analysis before sources are initialized
  (FATE #301967).
* Thu Jun  7 2007 locilka@suse.cz
- A new label "Writing YaST Configuration..." used in case of
  restarting system or installation.
* Fri Jun  1 2007 mzugec@suse.cz
- use shared isNetworkRunning() function in network_finish
- 2.15.28
* Wed May 30 2007 mzugec@suse.cz
- fixed spec requirements
* Mon May 28 2007 mzugec@suse.cz
- removed netsetup item from control files
* Mon May 28 2007 mzugec@suse.cz
- removed inst_netsetup item from control files
* Sun May 27 2007 mzugec@suse.de
- installation network changes:
  http://lists.opensuse.org/yast-devel/2007-05/msg00025.html
- 2.15.27
* Tue May 22 2007 ug@suse.de
- reactivate hardware detection during autoinstall
- 2.15.26
* Mon May 21 2007 locilka@suse.cz
- Fixed release-notes desktop file.
- 2.15.25
* Thu May 17 2007 locilka@suse.cz
- Progress dialog for initializing installation sources.
- 2.15.24
* Tue May 15 2007 locilka@suse.cz
- Changed control file in partitioning/evms_config section from
  'true' to 'false' (#274702).
* Fri May 11 2007 locilka@suse.cz
- Removing directories '/var/lib/zypp/cache' and '/var/lib/zypp/db'
  if they exist at the beginning of the installation (#267763).
- 2.15.23
* Thu May 10 2007 locilka@suse.cz
- Merged hardware probing (inst_startup) and system probing
  (inst_system_analysis) into one script to have only one progress
  dialog instead of two (#271291).
- openSUSE control file clean-up: The default value for enable_next
  and enable_back is 'yes'. Only few steps do not allow to go back
  (#270893).
- 2.15.22
* Wed May  9 2007 locilka@suse.cz
- Safe qouting of bash command in desktop_finish.
- CommandLine for inst_release_notes (#269914).
* Mon May  7 2007 ms@suse.de
- don't clobber existing /root/.vnc/passwd file (#271734)
* Wed Apr 18 2007 locilka@suse.cz
- Root password dialog has been moved to be the first dialog of the
  second stage installation workflow (FATE #301924).
- "Root Password" step is now called "root Password" (#249706).
- Created new 'Check Installation' entry to the 'Configuration'
  part of the workflow. This section contains setting up network
  if needed, initializing target if needed, and installing
  remaining software (needed by FATE #301924).
- Added new client inst_initialization that creates initialization
  progress UI instead of blank screen.
- 2.15.20
* Tue Apr 17 2007 locilka@suse.cz
- Fixed Add-On template to use generic 'control' textdomain
- 2.15.19
* Fri Apr 13 2007 locilka@suse.cz
- Replacing networkmanager_proposal with general_proposal (network)
  that includes also IPv6 settings (#263337, #260261).
* Thu Apr 12 2007 locilka@suse.cz
- Initialize the target and sources before adding extra sources.
  They needn't be initialized after YaST is restarted during the
  online update (#263289).
* Wed Apr 11 2007 locilka@suse.cz
- Release Notes dialog is using a [Close] button if not running in
  installation (#262440).
* Fri Apr  6 2007 locilka@suse.cz
- In case of reboot during installation, network services status
  is stored to a reboot_network_settings file and their status
  is restored again when starting the installation after reboot.
  Restoring the status uses Progress library for user feedback
  (#258742).
- Adjusted RPM dependencies.
- 2.15.18
* Thu Apr  5 2007 locilka@suse.cz
- Using function PackagesUI::ConfirmLicenses() instead of
  maintaining own code with almost the same functionality (#256627)
- Adjusted RPM dependencies
- Unified inst_startup UI to use the Progress library instead of
  sequence of busy pop-ups.
- Unified inst_system_analysis UI to use the Progress library
  instead of empty dialog.
- 2.15.17
* Wed Apr  4 2007 locilka@suse.cz
- Removed IPv6 proposal from installation control file. IPv6
  proposal has been merged into Network Mode proposal (#260261).
* Wed Mar 28 2007 locilka@suse.cz
- Adjusted to use WorkflowManager instead AddOnProduct module
  in some cases to make Pattern-based installation and
  configuration workflow (FATE #129).
- Adjusted RPM dependencies and BuildRequires.
- 2.15.16
* Tue Mar 27 2007 ms@suse.de
- fixed X11 preparation by checking /etc/reconfig_system (#252763)
* Wed Mar 21 2007 locilka@suse.cz
- Handling CloneSystem functionality when the client for cloning is
  not installed (checkbox is disabled).
* Mon Mar 19 2007 locilka@suse.cz
- Creating an empty /etc/sysconfig/displaymanager in desktop_finish
  if the sysconfing doesn't exist (minimal installation).
- Handling missing .proc.parport.devices agent (RPM recommends
  yast2-printer for that).
* Tue Mar 13 2007 locilka@suse.cz
- Reboot in case of the declined license during the initial
  installation (#252132).
* Mon Mar 12 2007 locilka@suse.cz
- Modules 'Product' and 'Installation' (installation settings) were
  moved from 'yast2-installation' to 'yast2' to minimize
  cross-package dependencies.
- Adjusted package dependencies.
- 2.15.15
* Fri Mar  9 2007 locilka@suse.cz
- Module InstShowInfo has been moved from yast2-installation to
  yast2-packager because this module is used by Add-Ons and
  installation sources only.
- Adjusted RPM Requires (yast2-packager >= 2.15.22).
- 2.15.14
* Thu Mar  8 2007 locilka@suse.cz
- Module GetInstArgs moved from yast2-installation to yast2, many
  clients required yast2-installation only because of this module.
* Thu Mar  8 2007 locilka@suse.cz
- Tag 'PATTERNS' in product content file is depracated by
  'REQUIRES' and/or 'RECOMMENDS' tag (#252122).
* Tue Mar  6 2007 kmachalkova@suse.cz
- Do not export LINES and COLUMNS variables, so that terminal
  resize event is handled correctly (#184179)
* Tue Mar  6 2007 locilka@suse.cz
- AddOnProduct and ProductLicense finally moved to yast2-packager
  from yast2-installation to avoid build cycles.
- 2.15.13
* Mon Mar  5 2007 locilka@suse.cz
- Moving AddOnProduct module back to yast2-installation because
  this module is needed in the second-stage installation.
- AddOnProduct-related testsuites moved back to yast2-installation.
- 2.15.12
* Mon Mar  5 2007 locilka@suse.cz
- Adding new installation client mouse_finish which is called
  before SCR is switched. This removes the dependency of
  yast2-installation on yast2-mouse.
- 2.15.11
* Fri Mar  2 2007 locilka@suse.cz
- Providing feedback (busy message) in inst_restore_settings.
  Starting network by calling 'network start' with timeout.
- Adding yast2-bootloader into required packages because it is
  needed after the SCR is switched into the installed system just
  before reboot (#249679).
- Added more logging into inst_system_analysis (booting installed
  system).
- 2.15.10
* Wed Feb 28 2007 jsrain@suse.cz
- added more logging to umount_finish (#247594)
* Mon Feb 26 2007 jsrain@suse.cz
- updated popup in case of license is not accepted (#162499)
* Thu Feb 22 2007 locilka@suse.cz
- Splitting installation_worker (main installation script) into
  inst_worker_initial and inst_worker_continue.
- Testsuites related to Add-Ons moved to yast2-add-on package.
- 2.15.9
* Wed Feb 21 2007 locilka@suse.cz
- Added documentation for silently_downgrade_packages and
  keep_installed_patches control file entries (plus their reverse
  lists) (FATE #301990, Bugzilla #238488).
* Mon Feb 19 2007 locilka@suse.cz
- More concrete fix of bug #160301: Displaying information about
  how to continue the second stage installation if SSH is the only
  installation method. This informational pop-up has disabled
  time-out (#245742).
- Moving parts of installation_worker script to includes based on
  in which installation stage they are used.
* Fri Feb 16 2007 locilka@suse.cz
- Add-Ons moved to a new package yast2-add-on-2.15.0 (#238673)
* Thu Feb 15 2007 locilka@suse.cz
- New entries silently_downgrade_packages, plus reverse list, and
  keep_installed_patches, plus reverse list, were added into SLES
  and SLED control files (FATE #301990, Bugzilla #238488).
* Mon Feb 12 2007 locilka@suse.cz
- Making release_notes modular.
- Rewriting RPM dependencies (#238679).
- Moving parts of installation_worker client into functions.
- Moving Mouse-init functions into inst_init_mouse client.
- Moving Storage-related functions (autoinstall) into
  inst_check_autoinst_mode client.
- Moving vendor client and desktop file to the yast2-update to
  minimize yast2-installation dependencies.
- Remove obsolete /proc/bus/usb mounting (#244950).
* Wed Feb  7 2007 locilka@suse.cz
- Correct Installation::destdir quoting in .local or .target bash
  commands.
- 2.15.8
* Tue Feb  6 2007 locilka@suse.cz
- Hide &product; in inst_suseconfig call to remove dependency on
  Product.ycp and not to be so ugly (#241553).
* Mon Feb  5 2007 locilka@suse.cz
- Store Add-Ons at the end of first stage installation and restore
  them before AutoYaST cloning at the end of the second stage
  installation (bugzilla #187558).
- Set license content before it is displayed for the first time,
  select license language before it is displayed (#220847).
- 2.15.7
* Fri Feb  2 2007 locilka@suse.cz
- Removing dependency on yast2-slp package.
- Moving all SLP-related functionality to yast2-packager-2.15.7.
- Handling not installed yast2-slp package in Add-Ons (#238680).
* Thu Feb  1 2007 locilka@suse.cz
- When an Add-On product is added and removed later, correctly
  remove also cached control file of that Add-On (#238307).
- 2.15.6
* Wed Jan 31 2007 locilka@suse.cz
- Rereading all SCR Agents in case of installation workflow changed
  by Add-On product (#239055).
- Calling PackageLock::Check before Pkg calls (#238556).
* Sun Jan 28 2007 locilka@suse.cz
- Removed tv and bluetooth hardware proposals from SLES control
  file. There are no such modules in that product (#238759).
* Mon Jan 22 2007 locilka@suse.cz
- Correct handling of CD/DVD Add-Ons in installation (#237264).
- Fixed switching between Installation Settings tabs in case of
  error in proposal. Every time, only the more-detailed tab is
  selected (#237291).
- Appropriate buttons for Add-Ons dialog for both dialog in
  installation workflow and installation proposal (#237297).
- 2.15.5
* Fri Jan 19 2007 locilka@suse.cz
- Fixed cancelling of entering a new Add-On (#236315).
- Added zFCP and DASD to installation/update proposal on S/390
  (jsrain) (#160399)
- 2.15.4
* Wed Jan 17 2007 locilka@suse.cz
- Changed control file documentation for Flexible Partitioning
  (bugzilla #229651 comment #15).
- Changed option <clone_module> "lan" to "networking" (#235457).
* Fri Jan 12 2007 ms@suse.de
- fixed TERM type setup in case of ssh based installations.
  if the installation is ssh based, TERM is not allowed to
  be overwritten by the value of install.inf. The TERM value
  of install.inf points to the console and not to the remote
  terminal type (#234032)
* Fri Jan 12 2007 locilka@suse.cz
- control file variable for monthly suse_register run (F#301822)
  (change made by jdsn)
* Thu Jan 11 2007 locilka@suse.cz
- Changed SLD and SLE control files to reflect demands described in
  bugzilla bug #233156:
  * Old packages are removed by default, only for upgrading from
    SLD 10 or SLE 10, packages are not removed by default.
  * New packages are selected for installation by default, only for
    upgrading from SLD 10 or SLE 10, packages are only updated.
  * Upgrading to new SLE 10 from is only supported from SLES9 and
    SLE 10, upgrading from another product will display warning.
* Sat Jan  6 2007 ms@suse.de
- fixed usage of fbiterm (#225229)
* Thu Jan  4 2007 locilka@suse.cz
- Added documentation for new features in control file:
  * boolean delete_old_packages and list of products for which this
    rule is inverted.
  * boolean only_update_selected and list of products for which
    this rule is inverted.
  * list of products supported for upgrade
  (All described in FATE #301844)
* Tue Jan  2 2007 locilka@suse.cz
- Allowing to add the very same product that has been already
  installed or selected for installation in case the url is
  different than any of the current urls. There can be more sources
  for the product because product urls can be removed and added
  also by inst_source module (#227605).
- Consistent spelling of "Add-On" and "add-on" (#229934).
- 2.15.3
* Tue Dec 12 2006 locilka@suse.cz
- Consistent spelling of 'AutoYaST' (#221275).
* Mon Dec 11 2006 locilka@suse.cz
- Handling new flag REGISTERPRODUCT from add-on product content
  file. This flag demands running the registration client after
  an add-on product is installed (on a running system) and demands
  running the registration client even if it is disabled in
  the base-product's control file (during installation)
  (FATE #301312).
- 2.15.2
* Thu Dec  7 2006 locilka@suse.cz
- Release Notes dialog in the second stage installation now offers
  to select a different language for release notes than the default
  one (#224875).
* Thu Dec  7 2006 locilka@suse.cz
- Reworked adding and removing Add-Ons during the first stage
  installation. If some Add-Ons are added or removed, the entire
  workflow is created from scratch (#221377).
- Using a separate temporary directory for Add-On licenses not to
  be confused by the previous Add-On.
- Fixed Second Stage Installation script to handle rebooting
  after kernel-patch correctly (#224251).
- Fixed Add-On handling when cancelling adding an Add-On product,
  before that return value from the previous adding was evaluated.
- Fixing some texts (#223880)
- 2.15.1
* Mon Dec  4 2006 locilka@suse.cz
- Adding support for own help texts for particular submodules in
  installation proposal (FATE #301151). Use key "help" in
  "MakeProposal"'s function result.
- Adding root_password_ca_check item into the globals of control
  file set to true for SLES and false otherwise (FATE #300438).
- A better fix for disabling [Back] button in License Agreement
  dialog when the previous (Language) dialog has been skipped
  (223258).
- 2.15.0
* Mon Dec  4 2006 lslezak@suse.cz
- "en_EN" -> "en_GB" in list of the preferred languages for EULA
* Thu Nov 23 2006 locilka@suse.cz
- Disabling [Back] button in License Agreement dialog when the
  previous (Language) dialog has been skipped (223258).
- 2.14.15
* Wed Nov 22 2006 ms@suse.de
- added hostname/IP information to Xvnc setup (#223266)
- fixed call of initvicons, deactivate s390 exception (#192052)
- 2.14.14
* Tue Nov 21 2006 locilka@suse.cz
- Reporting the failed or aborted installation only when it has
  been really aborted or when it really failed. YaST or system
  restarts on purpose (online update) are now handled correctly -
  there is no question whether user wants to continue with
  the installation (#222896).
- 2.14.13
* Mon Nov 20 2006 locilka@suse.cz
- Wider list of extra-sources 56->76 characters (#221984).
- Adding modules listed in Linuxrc entry brokenmodules into the
  /etc/modprobe.d/blacklist file (#221815).
- 2.14.12
* Mon Nov 20 2006 ms@suse.de
- fixed framebuffer color depth setup (#221139)
- 2.14.11
* Mon Nov 20 2006 locilka@suse.cz
- Show update-confirmation dialog in Mode::update() only (#221571).
- Pressing [Abort] button in the Add-On dialog during installation
  now opens-up a correct pop-up dialog with correct text (#218677).
* Wed Nov 15 2006 ms@suse.de
- fixed i810 based installation (#220403)
- 2.14.10
* Wed Nov 15 2006 locilka@suse.cz
- Defining the minimal size for release_notes pop-up to have the
  minimal size 76x22 or 3/4x2/3 in text mode and 100x30 in graphic
  mode (#221222).
* Wed Nov 15 2006 locilka@suse.cz
- Restoring the [ Next ] button in the inst_congratlate client when
  the [ Back ] button is pressed (#221190).
* Tue Nov 14 2006 locilka@suse.cz
- Changes in openSUSE control file (#219878):
  * limit_try_home: 5 GB -> 7 GB
  * root_base_size: 3 GB -> 5 GB
* Thu Nov  9 2006 locilka@suse.cz
- Always run the fonts_finish's Write() function. Skip running
  "SuSEconfig --module fonts" if script SuSEconfig.fonts does not
  exist (#216079).
- 2.14.9
* Thu Nov  9 2006 locilka@suse.cz
- Added confirmation dialog into the update workflow on the running
  system before the update really proceeds (#219097).
- confirmInstallation function moved from inst_doit to misc to make
  confirmation dialog possible (#219097).
- Set Product Name only when any Product Name found (#218720).
- 2.14.8
* Fri Nov  3 2006 locilka@suse.cz
- Preselecting already installed languages in the Language Add-On
  script (FATE #301239) (#217052).
- 2.14.7
* Fri Nov  3 2006 locilka@suse.cz
- Changed text of question asking whether the second stage
  installation should start again (FATE #300422) in case of
  previous failure or user-abort (#215697).
* Wed Nov  1 2006 locilka@suse.cz
- "Installation->Other->Boot Installed System->Cancel" now doesn't
  abort the installation but returns to the Installation Mode
  dialog (#216887).
- Correct handling of pressing Cancel or Abort buttons in pop-up
  windows in Add-On installation (#216910).
* Mon Oct 30 2006 lslezak@suse.cz
- updated inst_extrasources client to not download files from the
  installation sources (#213031)
- requires yast2-pkg-bindings >= 2.13.101
- 2.14.6
* Mon Oct 30 2006 locilka@suse.cz
- Moving ProductFeatures::Save() from inst_kickoff client to
  save_config_finish - client that is called after the SCR is
  switched to the running system (#209119).
- Calling Storage::RemoveDmMapsTo (device) in after the disks are
  probed in inst_system_analysis (#208222).
- Fixed including packager.
* Thu Oct 26 2006 locilka@suse.cz
- Enabling back button in the License Agreement dialog (#215236).
- Adding add-on.rnc for AutoYaST profile validation (#215248).
- Providing an easier switch to disable IPv6 by a new ipv6 client
  in the network proposal (FATE #300604) (mzugec).
- 2.14.5
* Wed Oct 25 2006 locilka@suse.cz
- Adding more debugging messages in order to fix random crashing
  of the second stage installation (#214886).
* Tue Oct 24 2006 locilka@suse.cz
- Renamed control file control.PROF.xml to control.openSUSE.xml
* Tue Oct 24 2006 ms@suse.de
- fixed nic detection (#213870)
* Mon Oct 23 2006 locilka@suse.cz
- Added special installation client for Language Add-Ons
  inst_language_add-on and it's XML workflow
  add-on-template_installation.xml for calling this client after
  the Add-On Product is added by the add-on client (FATE #301239).
- Adding add-on client to list of clients that are enabled for
  AutoYaST cloning (bugzilla #198927).
- Added summary of the Release Notes client for the Control Center
  (bugzilla #213878).
- 2.14.4
* Wed Oct 18 2006 locilka@suse.cz
- Added a life-belt into the second stage installation. It can be
  restarted under these circumstances:
  1.) User aborts the installation
  2.) Installation process is killed during the installation
  3.) Computer is restarted during the installation (reset)
  The very next time the system is restarted. YaST starts and
  informs user that the previous installation was aborted/failed.
  Then users are asked whether they want to rerun the second stage
  installation (FATE #300422).
- Fixed setting own Y2MAXLOGSIZE up in order to save memory
  requirements during the first stage installation.
- 2.14.3
* Mon Oct 16 2006 locilka@suse.cz
- Timeout license in AutoYaST after 2 seconds (#206706).
  This solution doesn't break ncurses.
- 2.14.2
* Mon Oct 16 2006 fehr@suse.de
- added new configurable values for LVM/EVMS based proposals
  (feature 300169)
- change evms_config to true
* Mon Oct 16 2006 ms@suse.de
- disable oom-killing for X-Server process (#211860)
* Thu Oct 12 2006 locilka@suse.cz
- Handle Installation::destdir in *.bash properly (#211576).
- 2.14.1
* Mon Oct  9 2006 locilka@suse.cz
- Merged SLES10 SP1 branch to openSUSE 10.2.
- 2.14.0
* Mon Oct  9 2006 locilka@suse.cz
- Remove old eula.txt and then copy new one if exists (#208908).
- Using the fullscreen mode again, background images temporarily
  removed from the RPM build (#208307).
- The default "Other Option" is Repair, not Boot (#208841).
- Removed some unneeded imports from inst_clients.
- 2.13.159
* Mon Oct  2 2006 locilka@suse.cz
- Merged proofread texts
- 2.13.158
* Mon Oct  2 2006 lslezak@suse.cz
- inst_extrasources.ycp - fixed name of the text domain
- 2.13.157
* Wed Sep 27 2006 lslezak@suse.cz
- new inst_extrasources.ycp client - add extra installation sources
  during installation (in 2nd stage, after online update)
  (fate #100168, #300910)
- 2.13.156
* Wed Sep 27 2006 locilka@suse.cz
- YCP modules that originated at yast2-packager were moved back.
- Usage of dgettext replaced with standard gettext strings.
- Removed yast2-slp and yast2-firewall from build-requirements.
- 2.13.155
* Mon Sep 25 2006 locilka@suse.cz
- New icon for Hardware Proposal.
- Root Password dialog moved before Hostname and Domain Name
  (#208032).
* Mon Sep 25 2006 locilka@suse.cz
- A bit rewritten code for language selected for second stage of
  update (FATE #300572). Mode::Set is now called before Mode::Get.
- New installation images from jimmac (#203510).
- Timeout and accept the license dialog when installing using
  AutoYaST. By defualt, it's 8 seconds (#206706).
- New busy message when finishing the installation (closing
  sources, etc.).
- 2.13.154
* Mon Sep 25 2006 jsrain@suse.cz
- check properly for existing files in /proc (#205408)
* Fri Sep 22 2006 jsuchome@suse.cz
- Remember the selected language for update and use it also in the
  second stage (FATE #300572).
- 2.13.153
* Fri Sep 22 2006 lslezak@suse.cz
- x11_finish.ycp - removed workaround for #201121
* Fri Sep 22 2006 locilka@suse.cz
- Fixed starting Installation in window: Exception for PPC, 832x624
  still runs in fullscreen. Fixed using a fallback image when
  the current resolution is not supported (#207321).
- Fixed counting offset for installation in window. Exceptions are
  now handled correctly (#207310).
- Changed fallback background image - a pure black suits better.
- Visual speeding-up initializing the installation - adding
  a wrapper installation.ycp around installation_worker.ycp client
  to provide UI ASAP.
* Thu Sep 21 2006 ms@suse.de
- added patch from Olaf Hering to remove the DefaultColorDepth
  for special fb devices which are not VESA VGA (#207338)
* Tue Sep 19 2006 locilka@suse.cz
- Removed Installation background 1600x800 px.
- Added installation background 1280x800 px.
* Mon Sep 18 2006 locilka@suse.cz
- Icon for release notes (inst_release_notes).
- List of available SLP sources based on Product Name (SLP label),
  also with filter when more than 15 sources are listed
  (FATE #300619).
- Added background images for installation (thanks to jimmac)
  [1024x768, 1280x1024, 1400x1050, 1600x800, 1600x1200] (Bugzilla
  [#203510]).
- Replacing "Product %%1" with "%%1" for list of selected Add-On
  products - the column is already called "Product".
- 2.13.152
* Thu Sep 14 2006 locilka@suse.cz
- Finally! Corrected path for importing user-related data to the
  just installed system (FATE #120103, comments #17, #18).
* Wed Sep 13 2006 ro@suse.de
- added yast2-core-devel to BuildRequires
* Wed Sep 13 2006 locilka@suse.cz
- Calling languages.ycp client has been changed to a function call
  Language::GetLanguagesMap (#204791).
- Added new Requirement: yast2-country >= 2.13.35
- Calling copy_systemfiles_finish from inst_finish (FATE #300421).
- New icon for Finishing Basic Installation dialog.
- Calling new pre_umount_finish client before umount_finish,
  umount_finish closes SCR (#205389).
- Correctly quote files that are added into the temporary archive
  (FATE #300421).
- Removing the leading slashes from filenames when archiving them.
- Reporting error (into log) if save_hw_status_finish.ycp goes
  wrong (partly fixed #205408).
- 2.13.151
* Tue Sep 12 2006 locilka@suse.cz
- Found a better place for calling 'inst_pre_install' client, by
  now it is really called...
- Enhanced logging.
- Disabling the License Language combo-box in case of less than
  two languages in it (#203543).
* Tue Sep 12 2006 locilka@suse.cz
- Fixed displaying license: Language name should always be either
  shown or the license is disabled as invalid; If there are both
  license.en.txt and license.txt, one of them is hidden because
  they have the very same content; An installation language is also
  pre-selected as a language for a license (if such exists).
- Fixed initializing the known languages via WFM::call("languages")
  (#204791).
- Another icon for Installation Mode dialog, it was the same as for
  Initialization and Analyzing the Computer dialogs.
- 2.13.150
* Mon Sep 11 2006 locilka@suse.cz
- Added 'inst_pre_install' and 'copy_systemfiles_finish' clients,
  and module 'SystemFilesCopy' as a solution for FATE requests
  [#300421] and #120103, which means that SSH keys are, by now,
  copied from another already installed system (if such exists).
  If there are more installed systems, the best ones are selected
  considering the newest access-time.
- More verbose dialog when initializing the installation (+icon).
* Thu Sep  7 2006 locilka@suse.cz
- Added dialog content and help into the initial dialog of add-on
  client. Progress will be even better.
- Temporarily disabled buttons that don't work there.
- Added more "busy messages" into the add-on dialogs.
- Added new functionality for filtering services in SLP services
  table. Allowed characters are "a-zA-Z0-9 .*-".
* Wed Sep  6 2006 mvidner@suse.cz
- To allow adding unsigned sources, temporarily "rug set-pref
  security-level none" when syncing in inst_source (#190403).
- 2.13.149
* Wed Sep  6 2006 locilka@suse.cz
- No such headline "Mode" in the Installation Settings dialog.
  Help fixed (#203811).
- Added help into the Add-On Product Installation dialog.
- Add and Delete buttons in the same dialog were moved to the left
  side according the YaST style guide.
- Disabling Delete button in case of no Products listed
  (all filed as bug #203809).
- Used a correct (another) icon in License Agreement dialog
  (#203808).
* Mon Sep  4 2006 locilka@suse.cz
- Running Installation in Wizard Window (#203510).
- Needed binaries in inst-sys: xquery and fvwm-root.
- Initially, a plain colored image is used as a background.
- 2.13.148
* Mon Sep  4 2006 ms@suse.de
- fixed -fp setup of Xvnc (#203531)
* Fri Sep  1 2006 locilka@suse.cz
- Fixed Installation Mode dialog to redraw itself only when needed.
* Wed Aug 23 2006 locilka@suse.cz
- Added a new debugger tool scr_switch_debugger.ycp that is called
  when switching to the installed system in switch_scr_finish.ycp
  fails (#201058).
- Additionally, YaST logs from installed system are stored under
  the /var/log/YaST2/InstalledSystemLogs/ directory.
- 2.13.147
* Wed Aug 23 2006 jsrain@suse.cz
- use version specific Xvnc parameters
- 2.13.146
* Wed Aug 23 2006 jsrain@suse.cz
- temporary fix to copy /etc/X11/xorg.conf to the system during
  installation (#201121)
- 2.13.145
* Tue Aug 22 2006 mvidner@suse.cz
- test_proposal and test_inst_client: also call
  Mode::SetMode ("installation");
* Tue Aug 22 2006 locilka@suse.cz
- New Installation Mode dialog (#156529)
- 2.13.144
* Tue Aug 22 2006 jsrain@suse.cz
- weaken dependency on suseRegister (#183656)
* Fri Aug 18 2006 jsrain@suse.cz
- fixed building documentation
- 2.13.143
* Thu Aug 10 2006 jsrain@suse.cz
- fixed congratulation text for openSUSE (#198252)
- 2.13.142
* Wed Aug  9 2006 jsrain@suse.cz
- read info about products from package manager without parsing all
  metadata and reading RPM database (#66046)
- added unzip to Requires (#195911)
* Tue Aug  8 2006 jsrain@suse.cz
- fixed 'Requires'
- 2.13.141
* Fri Aug  4 2006 jsrain@suse.cz
- updated for X.Org 7
- 2.13.140
* Fri Aug  4 2006 jsrain@suse.cz
- moved SLP source scanning to SourceManager.ycp
* Wed Aug  2 2006 mvidner@suse.cz
- Added a configure-time check for fvwm directory
* Fri Jul 28 2006 jsrain@suse.cz
- offer to eject the CD drive when asking for add-on CD (#181992)
* Thu Jul 27 2006 jsrain@suse.cz
- added support for merging multiple proposal items as one proposal
  item (eg. to group langage and keyboard)
- 2.13.139
* Wed Jul 26 2006 jsrain@suse.cz
- get version from installed product proper way (#157924)
* Tue Jul 25 2006 jsrain@suse.cz
- beep before rebooting the machine during installation (#144614)
* Mon Jul 24 2006 jsrain@suse.cz
- fixed error reporting when creating a source (#159695)
- abort installation if package manager initialization fails
  (#167674)
- report proper message if no catalog found via SLP and firewall
  is running (#156444)
* Tue Jul 18 2006 jsrain@suse.cz
- fixed displaying catalog selection dialog if multiple catalogs
  found on add-on media (#192761)
* Tue Jul 18 2006 jsrain@suse.cz
- fixed vendor URL in congratulate dialog (#187358)
- 2.13.138
* Mon Jul 17 2006 jsrain@suse.cz
- check if there are any patches available before offering online
  update (jsuchome)
- merged inst_default_desktop.ycp to desktop_finish.ycp
* Sun Jul 16 2006 olh@suse.de
- introduce a Linuxrc::display_ip and use it instead of Arch::s390
- 2.13.137
* Fri Jul 14 2006 jsrain@suse.cz
- adapted to changes in yast2-packager
- use only one implementation of product license handling (#191523)
- 2.13.136
* Fri Jul 14 2006 olh@suse.de
- move /tmp/vncserver.log to /var/log/YaST2/vncserver.log
* Mon Jul 10 2006 jsrain@suse.cz
- correctly import add-on product control file even if no
  additional YaST modules are present on the media (#185768)
- 2.13.135
* Mon Jul 10 2006 mvidner@suse.cz
- When running Novell Customer Center Configuration the second time,
  do not add duplicate update sources for graphic card drivers
  (#188572).
- 2.13.134
* Fri Jun 30 2006 ug@suse.de
- during autoinstall, timeout early warning popups
* Tue Jun 27 2006 mvidner@suse.cz
- Don't show the URL passwords in registration success popup (#186978).
- Include the password in URLs passed to ZMD (#186842).
- Don't log the URL passwords.
- 2.13.133
* Mon Jun 26 2006 jsrain@suse.cz
- preselect patterns according to selected desktop (#183944)
* Wed Jun 21 2006 jsrain@suse.cz
- display the source URL dialog if adding add-on product update
  source fails in order to allow to enter password (#186804)
* Tue Jun 20 2006 mvidner@suse.cz
- When registration succeeds, display only the actually added sources
  (#180820#c26).
* Tue Jun 20 2006 jsrain@suse.cz
- translate the congratulate string (#186567)
* Mon Jun 19 2006 jsrain@suse.cz
- report an error when failed to register the update source for
  an add-on product (#185846)
- 2.13.132
* Mon Jun 19 2006 jsrain@suse.cz
- ask about accepting license of add-on product added via the
  /add_on_product file (#186148)
- 2.13.131
* Thu Jun 15 2006 mvidner@suse.cz
- Do not complain if ZMD cannot be stopped (#166900).
- When syncing the _original_ installation sources to ZMD,
  temporarily turn off signature checking because the user has
  already decided to trust the sources (#182747).
- SourceManager: factored out the rug pathname.
- 2.13.130
* Thu Jun 15 2006 jsrain@suse.cz
- set installation server as host name (not IP address) if it is
  defined as host name during installation (#178933)
- 2.13.129
* Thu Jun 15 2006 visnov@suse.cz
- fix the please-wait string
* Wed Jun 14 2006 jdsn@suse.de
- added a please-wait string in registration (already translated)
- 2.13.128
* Mon Jun 12 2006 mvidner@suse.cz
- Fillup /etc/sysconfig/security:CHECK_SIGNATURES and initialize it
  based on an install time kernel parameter.
- 2.13.127
* Mon Jun 12 2006 jdsn@suse.de
- run pango module creation as root (#165891)
- fixed SLE desktop file of suse_register for autoyast (mc, ug)
- 2.13.126
* Fri Jun  9 2006 locilka@suse.cz
- Identify the downloaded release notes by the product name during
  the internet test. Changes were made in the module Product
  (#180581).
- 2.13.125
* Thu Jun  8 2006 jdsn@suse.de
- create pango modules for registration browser (#165891)
- sync zypp update sources in autoyast mode as well (#181183)
- 2.13.124
* Wed Jun  7 2006 jsrain@suse.cz
- avoid adding update source of an add-on product twice during
  installation (#182434)
- 2.13.123
* Tue Jun  6 2006 mvidner@suse.cz
- Moved SourceManager + deps from yast2-packager to yast2-installation
  to avoid circular BuildRequires.
- 2.13.122
* Tue Jun  6 2006 mvidner@suse.cz
- Call suse_register with --nozypp meaning that we will tell rug
  ourselves which zypp/yum sources it should add. This enables
  rejecting broken or untrusted sources (#180820).
- Moved the major part of Register::add_update_sources to
  SourceManager::AddUpdateSources.
- 2.13.121
* Tue Jun  6 2006 jsrain@suse.cz
- sync add-on product source to ZMD (#181743)
- 2.13.120
* Thu Jun  1 2006 mvidner@suse.cz
- Do log Report::{Message,Warning,Error} messages by default (#180862).
- 2.13.119
* Thu Jun  1 2006 jsrain@suse.cz
- honor UPDATEURLS if installing add-on product in running system
  (#180417)
- 2.13.118
* Wed May 31 2006 jsrain@suse.cz
- avoid calling Pkg::SourceStartCache during 1st stage of the
  installation (#178007)
- 2.13.117
* Tue May 30 2006 jdsn@suse.de
- set correct title of installation step Customer Center (#179921)
- 2.13.116
* Fri May 26 2006 jsrain@suse.cz
- fixed behavior if SLP source detection fails (#179036)
- 2.13.115
* Thu May 25 2006 jsrain@suse.cz
- added possibility to specify add-on product URL as command-line
  parameter of add-on.ycp (to run add-on product workflow via
  autorun.sh)
- 2.13.114
* Wed May 24 2006 jsrain@suse.cz
- properly integrate YCP code for add-on product installation in
  running system (if YCP code present) (#178311)
- 2.13.113
* Tue May 23 2006 jdsn@suse.de
- gray out checkboxes in inst_suse_register when skipping (#178042)
- 2.13.112
* Tue May 23 2006 jsrain@suse.cz
- added different desktop files for SLE and BOX/openSUSE
- 2.13.111
* Tue May 23 2006 jdsn@suse.de
- fixed layouting in inst_ask_online_update (#177559)
* Fri May 19 2006 jdsn@suse.de
- let inst_suse_register ask to install mozilla-xulrunner if
  missing (#175166)
- prevent non-root user to run inst_suse_register (#170736)
- 2.13.110
* Fri May 19 2006 jsrain@suse.cz
- more verbose logging of storing hardware status (#170188)
- 2.13.109
* Thu May 18 2006 hare@suse.de
- start iscsid if root is on iSCSI (#176804)
* Wed May 17 2006 jsrain@suse.cz
- set DISPLAYMANAGER_SHUTDOWN according to control file (#169639)
- 2.13.108
* Tue May 16 2006 jsrain@suse.cz
- marked missed text for translation (#175930)
- 2.13.107
* Mon May 15 2006 jsrain@suse.cz
- handle additional data for installation restart (#167561)
* Fri May 12 2006 jsrain@suse.cz
- initialize callbacks before adding an add-on product, properly
  handle installation sources of add-on products (both if preparing
  AutoYaST configuration (#172837)
- 2.13.106
* Thu May 11 2006 jsrain@suse.cz
- do not disable automatic modprobe before adding add-on products
  (#172149)
- 2.13.105
* Thu May 11 2006 ms@suse.de
- fixed message text (#172766)
* Thu May 11 2006 ms@suse.de
- prevent ssh message from being displayed if vnc+ssh has
  been specified as installation method (#173486)
* Wed May 10 2006 jdsn@suse.de
- removed search bar from registration browser (#169092)
- 2.13.104
* Tue May  9 2006 jdsl@suse.de
- switched to Enterprise wording for inst_suse_register (#173970)
- 2.13.103
* Tue May  9 2006 mvidner@suse.cz
- Save the update sources if registration is done later after the
  installation (#172665).
- When adding upate sources, do not add duplicates (check by the alias
  passed by suse_register on SLE), delete the duplicate beforehand
  (#168740#c3).
- 2.13.102
* Tue May  9 2006 mvidner@suse.cz
- Start the network also when doing a remote X11 installation (#165458,
  hare).
- 2.13.101
* Mon May  8 2006 jdsl@suse.de
- added hard require from y2-installation to suseRegister (hmuelle)
- added new w3m-jail for registration (#167225)
- fixed passing of url to browser(s) for registration (#167225)
- switched to Enterprise strings for inst_suse_register (shorn)
- 2.13.100
* Thu May  4 2006 jsrain@suse.cz
- added congratulate text to the control file (#170881)
- 2.13.99
* Thu May  4 2006 jsrain@suse.cz
- disable timeout in popup before installation reboot in case
  of SSH installation (#160301)
* Thu May  4 2006 locilka@suse.cz
- include proofread message texts
* Wed May  3 2006 locilka@suse.cz
- Busy cursor when "Contacting server" in suse_register (#171061).
- 2.13.97
* Tue May  2 2006 locilka@suse.cz
- Display KDE-related help in the Congratulations dialog only
  in case of KDE as the default windowmanager (#170880).
- 2.13.96
* Fri Apr 28 2006 locilka@suse.cz
- Proper checking for available network when adding an Add-On
  product. Network-related options are disabled in case of missing
  network both in installation and running system (#170147).
- 2.13.95
* Fri Apr 28 2006 jsuchome@suse.cz
- initialize package callbacks for add on product workflow (#170317)
- 2.13.94
* Thu Apr 27 2006 mvidner@suse.cz
- Tell libzypp-zmd-backend not to write sources to zypp db,
  we are going to do it ourselves (#170113).
- 2.13.93
* Thu Apr 27 2006 jsrain@suse.de
- handle missing SHORTLABEL in content file (#170129)
- 2.13.92
* Thu Apr 27 2006 fehr@suse.de
- set limit for separate /home to 14G for SLED (#169232)
* Thu Apr 27 2006 ms@suse.de
- removed update_xf86config call, checking for /dev/psaux was
  broken and is no longer needed because the default mouse device
  is /dev/input/mice since many versions now (#168816)
* Thu Apr 27 2006 mvidner@suse.cz
- When asking for update URLs, go trough products, not patterns (#169836).
- 2.13.91
* Thu Apr 27 2006 locilka@suse.cz
- Making "SLP Catalog" selection bigger (maximum ncurses size)
  (#168718)
- 2.13.90
* Tue Apr 25 2006 jsrain@suse.de
- fixed service proposal in SLES control file (#159771)
* Tue Apr 25 2006 locilka@suse.cz
- Return `next instead of `ok in case of SLP Add-On Source (#165989)
- 2.13.89
* Mon Apr 24 2006 jsrain@suse.de
- GDM is default if both KDE and GNOME installed (#155095)
- 2.13.88
* Mon Apr 24 2006 sh@suse.de
- V 2.13.87
- Removed "Disagree with all" button (bug #163001)
* Mon Apr 24 2006 ug@suse.de
- 2.13.86
* Mon Apr 24 2006 ug@suse.de
- X-SuSE-YaST-AutoInstRequires=lan
  added to desktop file of suse register.
  Otherwise the registration fails.
* Mon Apr 24 2006 lnussel@suse.de
- run rcSuSEfirewall2 reload when installing via vnc or ssh (#153467)
- 2.13.85
* Fri Apr 21 2006 jsrain@suse.de
- determine base product accordign to flag (#160585)
- 2.13.84
* Fri Apr 21 2006 jdsn@suse.de
- added proxy support for registration browser (#165891)
- 2.13.83
* Thu Apr 20 2006 jsrain@suse.de
- handle installation restart with repeating last step (#167561)
- 2.13.82
* Thu Apr 20 2006 jdsn@suse.de
- proxy support for registration process (#165891)
- disable w3m registration by control variable (aj)
- 2.13.81
* Thu Apr 20 2006 mvidner@suse.cz
- When cloning, save installation sources beforehand (#165860).
- 2.13.80
* Wed Apr 19 2006 jsrain@suse.de
- restore buttons after calling DASD or zFCP module (#160399)
- 2.13.79
* Wed Apr 19 2006 locilka@suse.cz
- Added more debugging messages to the inst_proposal (#162831)
- 2.13.78
* Tue Apr 18 2006 jsrain@suse.de
- display proper popup when aborting add-on product installation
  (#159689)
* Tue Apr 18 2006 jdsn@suse.de
- in inst_suse_register:
- busy/waiting popups (#163366, #164794)
- text changes (#165509)
- autodisable checkbox "Registration Code" (# 165841)
- error handling in case no browser is available
- cleanup
- 2.13.77
* Tue Apr 18 2006 jsrain@suse.de
- do not initialize catalogs before booting installed system (#162899)
- 2.13.76
* Tue Apr 18 2006 mvidner@suse.cz
- Do not try to add empty URL as an update source (#165860#c12).
* Tue Apr 18 2006 mvidner@suse.cz
- Fixed a typo in the previous change.
- 2.13.75
* Tue Apr 18 2006 locilka@suse.cz
- Add-On SLP source was allways returning `back also in case
  of `ok (`next) (#165989)
- 2.13.74
* Tue Apr 18 2006 mvidner@suse.cz
- Skip popup and unnecessary work if there are no online update
  sources for add-ons (#167233).
- 2.13.73
* Fri Apr 14 2006 jsrain@suse.de
- prevent from changing installation mode and system for update once
  it is selected (#165832)
- added add-on products to installation/update proposal for SLES/SLED
- 2.13.72
* Fri Apr 14 2006 lslezak@suse.cz
- call vm_finish client at the end of installation - disable
  some services in Xen domU (#161720, #161721, #161756)
- 2.13.71
* Thu Apr 13 2006 jdsn@suse.de
- changed control files according to (#165509)
* Thu Apr 13 2006 mvidner@suse.cz
- Do not display errors if language specific release notes are missing
  on the installation source (#165767).
- 2.13.70
* Wed Apr 12 2006 jdsn@suse.de
- added missing autoyast entries in suse_register.desktop
- 2.13.69
* Wed Apr 12 2006 jsuchome@suse.cz
- control files updated for manual online update run (#165503)
- 2.13.68
* Wed Apr 12 2006 ms@suse.de
- fixed displaying ftp password in plaintext in y2start.log (#164824)
* Wed Apr 12 2006 mvidner@suse.cz
- Do not mangle the URL obtained from suse_register (#165499).
- 2.13.67
* Wed Apr 12 2006 locilka@suse.cz
- fixed Product.ycp - relnotes_url might be defined as an empty
  string (#165314).
- 2.13.66
* Tue Apr 11 2006 jsrain@suse.de
- fixed boot if root is on LVM (initialize udev symlinks) (#163073)
- 2.13.65
* Tue Apr 11 2006 jdsn@suse.de
- in inst_suse_register:
  - resized popups (hmuelle)
  - new info pupop showing new update server (aj)
  - removed cancel button (#164801, shorn)
- 2.13.64
* Tue Apr 11 2006 fehr@suse.de
- flag for evms in control.SLES.xml needs to be true
* Mon Apr 10 2006 mvidner@suse.cz
- Add installation sources for online update (#163192).
- 2.13.63
* Fri Apr  7 2006 jsrain@suse.de
- provide Product::short_name (#163702)
- 2.13.62
* Fri Apr  7 2006 jdsn@suse.de
- fixed evaluation of control file variables (#162988)
- 2.13.61
* Fri Apr  7 2006 jsuchome@suse.cz
- 2.13.60
* Thu Apr  6 2006 ms@suse.de
- allow huge memory allocations (#151515)
* Thu Apr  6 2006 jsuchome@suse.cz
- Product.ycp: read SHORTLABEL value from content file (#163702)
* Wed Apr  5 2006 mvidner@suse.cz
- Call SourceManager::SyncYaSTInstSourceWithZMD () in
  inst_rpmcopy(continue) because inst_suse_register does not run
  without a network connection (#156030#c30).
* Wed Apr  5 2006 jsrain@suse.de
- do not rewrite log from SCR running in chroot during installation
- fix checking for duplicate sources (#159662)
- 2.13.59
* Tue Apr  4 2006 jdsn@suse.de
- fixed w3m registration again (#162462)
- changed Requires to Recommends for suseRegister (hmuelle, aj)
- 2.13.58
* Mon Apr  3 2006 jdsn@suse.de
- fixed w3m in ncuses registration (#162462)
- changes in suse_register to test new server side business logic
- 2.13.57
* Mon Apr  3 2006 locilka@suse.cz
- Using yast-addon icon in the .desktop file and also in the source
  code (#154930).
- 2.13.56
* Mon Apr  3 2006 ug@suse.de
- by default, enable clone box on SLD
* Mon Apr  3 2006 ug@suse.de
- uncheck clone checkbox if cloning is greyed out (#162457)
* Fri Mar 31 2006 mvidner@suse.cz
- Tell ZMD to get the inst source (#156030)
- No unlocking after all (#160319)
  - Don't reset zypp
  - Reenable Back
  - Fetch update source from suse_resigster and add it
- 2.13.55
* Thu Mar 30 2006 mvidner@suse.cz
- Reset zypp and release its lock before suse_register (#160319).
  Therefore disabled the Back button.
- Don't run add-on.ycp if another process has the zypp lock (#160319).
- 2.13.53
* Thu Mar 30 2006 jdsn@suse.de
- included new desktop file in Makefile (162112)
* Wed Mar 29 2006 jsrain@suse.de
- prevent from installing one product multiple times (#159662)
- 2.13.54
* Wed Mar 29 2006 locilka@suse.cz
- Fixed adding SLP-based Add-On product (#161270)
- SLP-based Add-On product handling moved to separate function
- Add-On MediaSelect dialog creation moved to separate function
- Changed icon for License
- 2.13.52
* Wed Mar 29 2006 jdsn@suse.de
- late feature "force registration" for suse_register (aj, shorn)
* Tue Mar 28 2006 jdsn@suse.de
- added 'rm -f /var/lib/zypp/zmd_updated_the_sources'
  flag file to be deleted if suse_register runs during installation
  file checked by online update - deletion requested by mvidner
- 2.13.51
* Tue Mar 28 2006 jdsn@suse.de
- added autoyast part of suse_register
- icon for product registration (#160293)
- fixes for inst_suse_register
- 2.13.50
* Mon Mar 27 2006 jsrain@suse.de
- removed desktop selection from NLD workflow (#160650)
* Fri Mar 24 2006 locilka@suse.cz
- Filling up list of release_notes urls for all installed products
  in the Product.ycp. Needed for internet_test (#160563).
- 2.13.49
* Fri Mar 24 2006 ms@suse.de
- added initvicons call in second stage S05-config (#160299)
* Thu Mar 23 2006 jdsn@suse.de
- fixed security issue: suse-ncc dummy user got his own group
* Thu Mar 23 2006 jdsn@suse.de
- added controlfile configured default settings for suse_register
- 2.13.47
* Thu Mar 23 2006 locilka@suse.cz
- Display license immediately after the Add-On product is scanned
  and added. Handle user interaction.
- 2.13.46
* Thu Mar 23 2006 jdsn@suse.de
- final texts for suse_register
- nonroot - warning for suse_register
- 2.13.45
* Thu Mar 23 2006 locilka@suse.cz
- Displaying license of the Add-On product if exists. Trying the
  localized version first. Waiting for user interaction if needed.
- Displaying info.txt if exists (#160017)
- Adjusting testsuites
- 2.13.44
* Wed Mar 22 2006 jdsn@suse.de
- fixed missing module in makefile
- 2.13.43
* Wed Mar 22 2006 locilka@suse.cz
- Added fallback for adding add-on products without file
  installation.xml. In this case, the product is added as a normal
  installation source and sw_single is called.
- 2.13.42
* Wed Mar 22 2006 jdsn@suse.de
- fixed ssh bug in suse_register
- suse_register reads and writes configuration to sysconfig
- final texts in suse_register
- 2.13.41
* Wed Mar 22 2006 mvidner@suse.cz
- Fixed release notes download (by Product::FindBaseProducts), #159490.
* Wed Mar 22 2006 jdsn@suse.de
- changed help text in suse_register
- patch to make the ComboBox appear longer in release_notes
* Tue Mar 21 2006 locilka@suse.cz
- adding "Local Directory" option for Add-On Products when no
  network is available (#159779).
- avoid from adding "Unknown" Add-On Product when Cancel button
  pressed in the Add New Add-On popup (#159784).
* Tue Mar 21 2006 jsuchome@suse.cz
- returned dependency on yast2-online-update
* Tue Mar 21 2006 visnov@suse.cz
- try to get add-on product control files only optionally (#159116)
- 2.13.40
* Mon Mar 20 2006 locilka@suse.cz
- disabled skipping the 'Installation Mode' dialog when no other
  installed Linux found. Just disabling 'Update' and 'Other'
  options in that case (#157695).
- removed calling uml_finish, client doesn't has been dropped.
* Fri Mar 17 2006 jsrain@suse.de
- added AytoYaST support for add-on products
- 2.13.39
* Fri Mar 17 2006 locilka@suse.cz
- fixed .desktop file for Add-On Products, now it starts add-on
  instead of sw_single when launched from YaST Control Center
  (#158869).
* Thu Mar 16 2006 jsrain@suse.de
- added zFCP and DASD modules to list of modules to be cloned after
  SLES installation (#153378)
- 2.13.38
* Thu Mar 16 2006 jsrain@suse.de
- fixed product handling (&product; macro) (#151050)
- allow multiple installation sources (#151755)
* Thu Mar 16 2006 jdsn@suse.de
- fixed blocker bug (#158628), suse_register call in all products
* Thu Mar 16 2006 fehr@suse.de
- increase maximal size of root fs to 20 Gig (#158608)
- 2.13.37
* Wed Mar 15 2006 jsrain@suse.de
- do not overwrite language settings during update (#156562)
- do not offer network sources for Add-On products if no network is
  configured (#156467)
- 2.13.36
* Tue Mar 14 2006 jdsn@suse.de
- corrected titles in control file
- 2.13.35
* Tue Mar 14 2006 jdsn@suse.de
- 2.13.34
* Tue Mar 14 2006 jdsn@suse.de
- new browser for registration
- new texts for registration module
* Mon Mar 13 2006 jsrain@suse.de
- report an error if creating catalog for add-on product fails
  (#157566)
- 2.13.33
* Fri Mar 10 2006 jsrain@suse.de
- disable add-on products if inst-sys is mounted from CD
- 2.13.32
* Fri Mar 10 2006 jdsn@suse.de
- fixed security bug (#157008)
- added link to browser for Novell privacy statement
* Fri Mar 10 2006 mvidner@suse.cz
- Start ncurses UI in non-threaded mode to enable spawning of
  interactive processes (like w3m for suseRegister, #150799).
- 2.13.31
* Fri Mar 10 2006 ms@suse.de
- forcing using xim for Qt Input (#156962)
* Thu Mar  9 2006 mvidner@suse.cz
- Control files: added network/startmode, being ifplugd for SL and
  SLED, auto for SLES (#156388).
- 2.13.30
* Thu Mar  9 2006 jsrain@suse.de
- fixed asking for add-on product CD (#156469)
* Thu Mar  9 2006 ms@suse.de
- include proofread message texts
* Wed Mar  8 2006 jdsn@suse.de
- fixed launch of yastbrowser (during installation)
- 2.13.29
* Wed Mar  8 2006 ms@suse.de
- fixed createStageList() function to be more restrictive on checking
  for stage files. Adapt startup documentation according to this
  change (#144783)
* Wed Mar  8 2006 lrupp@suse.de
- added suseRegister to Requires
* Tue Mar  7 2006 jdsn@suse.de
- added functionality to skip suse register and/or online update
- 2.13.28
* Tue Mar  7 2006 jsrain@suse.de
- added yastbrowser
* Mon Mar  6 2006 jsrain@suse.de
- fixed back button behavior in installation mode dialog (#155044)
* Mon Mar  6 2006 visnov@suse.cz
- enable media callbacks in the add-on product handling
* Fri Mar  3 2006 jsrain@suse.de
- added .desktop file for add-on product installation (#154930)
- properly initialize source for add-on product (#154980)
- 2.13.27
* Fri Mar  3 2006 visnov@suse.cz
- reset package manager before installing patches
* Wed Mar  1 2006 jsrain@suse.de
- release all medias before registering add-on product CD or DVD
  (#154348)
- check whether files are on the add-on product media before using
  them (#154314)
- 2.13.26
* Mon Feb 27 2006 jsrain@suse.de
- fixed setting default desktop according to destop dialog (#152709)
- 2.13.25
* Fri Feb 24 2006 jsrain@suse.de
- select base product before runing add-on products dialog
- 2.13.24
* Fri Feb 24 2006 ms@suse.de
- added qt plugin check to check_network function (#149025)
* Thu Feb 23 2006 jsrain@suse.de
- changed the name of the add-on product control file (#152770)
- 2.13.23
* Wed Feb 22 2006 jsrain@suse.de
- using correct icon (#151630)
- 2.13.22
* Wed Feb 22 2006 ms@suse.de
- added console startup message when y2base is called (#148165)
* Wed Feb 22 2006 visnov@suse.cz
- adapt BuildRequires
- 2.13.21
* Wed Feb 22 2006 jsrain@suse.de
- do not offer creating AutoYaST profile in first boot mode
  (#152285)
- 2.13.20
* Sun Feb 19 2006 jsrain@suse.de
- made inst_proposal more resistent to incorrect data returned from
  client modules (#148271)
* Fri Feb 17 2006 jsrain@suse.de
- removed dependency on yast2-online-update
- integrated add-on product selection to installation workflow
- 2.13.19
* Fri Feb 17 2006 mvidner@suse.cz
- inst_release_notes: Let the combo box have a label.
- inst_disks_activate: fixed the textdomain (s390 -> installation)
* Thu Feb 16 2006 jsrain@suse.de
- several fixes of add-on product installation
- 2.13.18
* Tue Feb 14 2006 jsrain@suse.de
- added possibility to use standalone-installation proposals when
  installing with base product
- added support for replacing 2nd stage workflow
- added support for disabling individual proposal
- added support for inserting steps to inst_finish for add-on
  products
- added copying merged control files to installed system, merging
  them for 2nd stage workflow
- 2.13.17
* Tue Feb 14 2006 jdsn@suse.de
- new release notes module (multiple release notes) FATE: 120129
- 2.13.16
* Tue Feb 14 2006 jsrain@suse.de
- fixed add-on product workflow and proposal merging
* Mon Feb 13 2006 jsrain@suse.de
- updated patchs on add-on product CD according to spec
- 2.13.15
* Mon Feb 13 2006 visnov@suse.cz
- save zypp.log from instsys
* Sun Feb 12 2006 olh@suse.de
- umount /dev and /sys unconditionally in umount_finish.ycp
* Sun Feb 12 2006 olh@suse.de
- remove obsolete comment from umount_finish.ycp
* Sun Feb 12 2006 visnov@suse.cz
- revert redirect
* Sun Feb 12 2006 kkaempf@suse.de
- redirect stderr to /var/log/YaST2/zypp.log when running
  1st or 2nd stage installation. (#149001)
* Thu Feb  9 2006 jsrain@suse.de
- added add-on product installation in running system
* Wed Feb  8 2006 jsrain@suse.de
- added control file merging functionality
* Tue Feb  7 2006 mvidner@suse.cz
- control files: Configure the hostname in the main installation
  workflow also in SuSE Linux (#142758) and SLED (#137340).
- 2.13.13
* Mon Feb  6 2006 olh@suse.de
- remove the /usr/share/locale/br symlink creation, there is
  no user of /usr/share/locale files inside the inst-sys
- remove the hostname linux, domainname local calls
  the hostname is already set in inst_setup.
  yast can not be restarted with ssh installs
* Tue Jan 31 2006 fehr@suse.de
- disable proposal with separate /home for SLES
* Mon Jan 30 2006 ms@suse.de
- fixed PCI bus ID setup (#145938)
* Fri Jan 27 2006 ms@suse.de
- adding truetype font path to the vnc font path (#139351)
* Thu Jan 26 2006 fehr@suse.de
- remove loading of dm modules, if needed this is done in libstorage
* Tue Jan 24 2006 ms@suse.de
- added check for testutf8 binary (#144699)
* Tue Jan 24 2006 jsrain@suse.cz
- enable iSCSI dialog during installation
- 2.13.12
* Mon Jan 23 2006 mvidner@suse.cz
- Added networkmanager_proposal to the network proposal.
- 2.13.11
* Mon Jan 23 2006 ms@suse.de
- added y2start.log message if YaST exits abnormally (#141016)
- fixed repatching of xorg.conf file (#144538)
* Mon Jan 23 2006 jsrain@suse.cz
- added "enable_clone" option (#144101)
* Mon Jan 16 2006 mvidner@suse.cz
- Prefer the string product feature network/network_manager (always,
  laptop, never) over boolean network/network_manager_is_default.
* Fri Jan 13 2006 jsrain@suse.cz
- run the desktop dialog also on SLES (#142771)
- added iscsi installation to the installatino workflow
- 2.13.10
* Wed Jan 11 2006 jsrain@suse.cz
- call installation clients for DASD/zFCP configuration instead of
  the run-time ones
* Mon Jan  9 2006 jsrain@suse.cz
- write mouse information on PPC (#116406)
- UI mode set to expert for SLES
- reset storage after (de)activating any disk (#140936)
- 2.13.9
* Fri Jan  6 2006 ms@suse.de
- fixed HVC_CONSOLE_HINT text (#140386)
* Thu Jan  5 2006 jsrain@suse.cz
- Removed unneeded stuff from proposals on some architectures for
  SLES (#140999, #140991)
- Added iSCSI to installation workflow (real call still missing)
- moved DASD/zFCP disk activation prior installation mode selection
  (#140936)
- 2.13.8
* Thu Jan  5 2006 sh@suse.de
- V 2.13.7
- Fixed bugs #79289, #114037: trouble with y2cc at end of installation
  Dropped y2cc at end of installation (OK from aj + gp)
* Thu Jan  5 2006 mvidner@suse.cz
- control file: for SLES, ask for the host name in the main workflow (F4126)
* Thu Jan  5 2006 jsuchome@suse.cz
- control file: for NLD, do not enable autologin by default (#140990)
* Tue Jan  3 2006 ms@suse.de
- don't call initvicons on s390/s390x architectures (#140383)
* Thu Dec 22 2005 fehr@suse.de
- added try_separate_home to partitioning section of control.xml
* Wed Dec 21 2005 ms@suse.de
- fixed startup Makefile.am
* Wed Dec 21 2005 visnov@suse.cz
- merged proofread texts
* Tue Dec 20 2005 ms@suse.de
- added support for graphical installation on ia64 archs (#140142)
* Mon Dec 19 2005 sh@suse.de
- Implemented feature #300359: Show Beta notice during installation
  Now showing /info.txt in a popup (with a simple "OK" button)
  over the license agreement
- V 2.13.6
* Fri Dec 16 2005 jsrain@suse.cz
- do not call obsolete gnome-postinstall script
- added list of modules to offer clone at the end of installation
  to control files
- 2.13.5
* Wed Dec 14 2005 ms@suse.de
- make service startup more robust (#138433)
* Fri Dec  2 2005 mvidner@suse.cz
- Added control file variables network_manager_is_default,
  force_static_ip.
- 2.13.4
* Fri Dec  2 2005 jsrain@suse.cz
- mark missing texts for translation (#136021)
* Wed Nov 30 2005 lslezak@suse.cz
- removed Xen and UML sections from control files
  (moved to yast2-vm package)
- 2.13.4
* Tue Nov 29 2005 sh@suse.de
- Implemented feature #110081: License translations
- V 2.13.3
* Mon Nov 28 2005 jsrain@suse.cz
- adjusted default desktop in control files (#132491)
* Tue Nov 22 2005 jsrain@suse.cz
- added default desktop to control files
* Fri Nov 11 2005 jsrain@suse.cz
- write hwcfg-static-printer only if parallel port is present
  (#116406)
- 2.13.2
* Tue Nov  1 2005 jsrain@suse.cz
- adapted to inst_desktop_new.ycp -> inst_desktop.ycp rename
* Tue Oct 18 2005 ms@suse.de
- added update check: update_xf86config to be called in case of
  update. The script will fix the mouse configuration if the device
  /dev/mouse or /dev/psaux is in use (#118755)
* Mon Oct 17 2005 ms@suse.de
- added testX binary check
* Thu Oct 13 2005 ms@suse.de
- fixed startup scripts because Stefan changed the X11 module
  naming from drv.o to drv.so :-(
* Fri Sep 30 2005 jsrain@suse.cz
- remove checking whether to run language selection (language
  module knows better whether it is needed)
* Mon Sep 26 2005 jsrain@suse.cz
- do close target before switching from update to bare metal
  installation (#115075)
- do not set default window manager in sysconfig if neither KDE
  nor GNOME are installed (#115412)
- 2.13.0
* Fri Sep  9 2005 ms@suse.de
- fixed service startup sequence of HAL and DBUS (#115815)
* Wed Sep  7 2005 jsrain@suse.cz
- fixed typo in the cursor scheme name for GNOME (#74309)
- 2.12.28
* Wed Sep  7 2005 jsuchome@suse.cz
- 2.12.27
* Tue Sep  6 2005 jsrain@suse.cz
- fixed freezing installation while saving configured hardware
  (#115387)
* Tue Sep  6 2005 jsrain@suse.cz
- use correct icons for license agreement and installation mode
  dialogs (#105158)
- 2.12.26
* Mon Sep  5 2005 ms@suse.de
- fixed braille setup (#115278)
* Mon Sep  5 2005 ms@suse.de
- start dbus in Second-Stage/S06-services (#114667)
* Mon Sep  5 2005 jsrain@suse.cz
- save all configured hardware at the end of installation (#104676)
- 2.12.25
* Thu Sep  1 2005 ms@suse.de
- start hald in Second-Stage/S06-services (#114667)
* Mon Aug 29 2005 jsrain@suse.cz
- reset package manager when switched installation mode (#105857)
- 2.12.24
* Fri Aug 26 2005 jsrain@suse.cz
- set default cursor theme according to default desktop (#74309)
- 2.12.23
* Wed Aug 24 2005 ms@suse.de
- fixed umount_result setting in /etc/install.inf. A space is
  needed between the colon and the value (#112620)
* Tue Aug 23 2005 ms@suse.de
- fixed umount call in First-Stage setup -> added F03-umount (#103800)
* Tue Aug 23 2005 jsrain@suse.cz
- mark correct tab selected after language is changed (#105995)
- reset target map when switching between installation and upgrade
  (#106627)
* Mon Aug 22 2005 jsrain@suse.cz
- fixed title icons for proposal dialogs (#105165)
- 2.12.22
* Fri Aug 19 2005 jsrain@suse.cz
- reverted forcing language dialog in NCurses (#102958)
- 2.12.21
* Fri Aug 19 2005 ms@suse.de
- fixed mouse probing call, was never called in initial stage (#100665)
* Fri Aug 19 2005 arvin@suse.de
- improved initialisation of libstorage callbacks (bug #105562)
* Wed Aug 17 2005 ms@suse.de
- added umount_result key to /etc/install.inf containing the exit
  code from trying to umount the inst-sys (#103800)
- 2.12.19
* Wed Aug 17 2005 jsrain@suse.cz
- handle correctly if _proposal client returns nil as warning level
  (#105154)
* Wed Aug 17 2005 arvin@suse.de
- check if /sbin/splash exists (bug #105159)
- 2.12.18
* Tue Aug 16 2005 jsrain@suse.cz
- build relation between old keys and new UDIs (#104676)
* Mon Aug 15 2005 jsrain@suse.cz
- merged texts from proofread
- 2.12.17
* Mon Aug 15 2005 ms@suse.de
- fixed vncpassword handling (#104377)
* Mon Aug 15 2005 jsrain@suse.cz
- make the OK button in other installatino options popup default
  button (#104589)
* Fri Aug 12 2005 jsrain@suse.cz
- force language selection in NCurses (#102958)
- 2.12.16
* Fri Aug 12 2005 ms@suse.de
- fixed use of graphical installer within SSH session (#53767)
* Fri Aug 12 2005 ms@suse.de
- fixed set_splash function to work with SuSE 10.0
* Tue Aug  9 2005 ms@suse.de
- fixed shell warning (#100729)
* Mon Aug  8 2005 jsrain@suse.cz
- show URL of product vendor in congratulation dialog (#102542)
* Fri Aug  5 2005 lslezak@suse.cz
- added virtual machine proposal into contol file
- 2.12.15
* Wed Aug  3 2005 jsrain@suse.cz
- fixed behavior in proposal with tabs if one of the submodules
  returned an error (#100203)
- 2.12.14
* Tue Aug  2 2005 jsrain@suse.cz
- do not allow going back after 2nd stage installation is
  interrupted by reboot
- restore settings after reboot during 2nd stage installation
* Thu Jul 28 2005 jsrain@suse.cz
- updated the installation confirmation popup (#98841)
- changed label of push button to access boot and repair (#98836),
  added help text
- 2.12.13
* Mon Jul 25 2005 ms@suse.de
- include functions start_yast_and_reboot() and start_yast_again()
  according to a feature request for Jiri.
* Fri Jul 22 2005 jsrain@suse.cz
- fixed dialog captions of proposals
* Thu Jul 21 2005 fehr@suse.de
- replace obsolete SCR agent calls by call to Storage::ActivateHld()
* Thu Jul 21 2005 ms@suse.de
- fixed YaST2.call::wait_for_x11() to set an initial value
  for server_running (#97381)
- 2.12.12
* Tue Jul 19 2005 jsrain@suse.cz
- fixed switch from installation to update and vice versa
- added support for reboot and restart of YaST during 2nd stage
  installation
- updated control file to show 3 installation stages
* Mon Jul 18 2005 jsrain@suse.cz
- updated control file
- minor inst_proposal clean-up
- 2.12.11
* Fri Jul 15 2005 jsrain@suse.cz
- fixed behavior of several dialogs
- 2.12.10
* Thu Jul 14 2005 jsrain@suse.cz
- added installation workflow
- added support for tabs in proposals
- adapted to new partitioner using storage-lib (arvin)
- moved inst_desktop.ycp to yast2-packager
- 2.12.9
* Mon Jul 11 2005 jsrain@suse.cz
- removed dependency on vanished Display.ycp to fix build
- 2.12.8
* Mon Jul 11 2005 ms@suse.de
- fixed race condition in checking servers exit code (#91342)
- fixed testX and xupdate paths
* Thu Jun  2 2005 jsrain@suse.cz
- put focus on the release notes to allow scrolling without pushing
  Tab many times to move the focus (#80215)
* Wed Jun  1 2005 mvidner@suse.cz
- Added a scr file for .etc.install_inf_options (#75720).
- 2.12.7
* Tue May 31 2005 ms@suse.de
- implement check for driver update mode (#84155)
* Tue May 31 2005 ms@suse.de
- applied patch from Olaf to avoid some time consuming calls (#86178)
- allow "vnc=1 usessh=1" as install and debug method (#45127)
* Mon May 30 2005 jsrain@suse.cz
- display message when fallen into text mode installation (#53748)
* Mon May 16 2005 jsrain@suse.cz
- renamed 'default' variable
- 2.12.6
* Tue May 10 2005 jsrain@suse.cz
- copy /etc/X11/xorg.conf instead of XF86Config to the target
  system
- 2.12.5
* Mon May  9 2005 ms@suse.de
- removed sed update of BusID (#78950)
* Wed Apr 27 2005 jsrain@suse.cz
- modularized inst_finish.ycp
- 2.12.4
* Thu Apr 21 2005 ms@suse.de
- fixed X11 config patching code, related to (#66989)
* Mon Apr 18 2005 jsrain@suse.cz
- one more fix for new ProductFeatures.ycp interface
- 2.12.3
* Mon Apr 18 2005 jsrain@suse.cz
- adapted to new interface of ProductFeatures.ycp
- 2.12.2
* Thu Apr 14 2005 visnov@suse.cz
- 2.12.1
* Wed Apr  6 2005 ms@suse.de
- inst-sys move XF86Config to xorg.conf (#66989)
* Tue Mar 29 2005 jsrain@suse.cz
- updated the layout of the source files in the repository
- 2.12.0
* Wed Mar 23 2005 ms@suse.de
- fixed vnc server arguments (#70896)
* Sat Mar 19 2005 ms@suse.de
- fixed second stage locale setup for textbased installation (#73631)
* Tue Mar 15 2005 ms@suse.de
- IMPORTANT: fixed locale setup (#72145)
* Tue Mar 15 2005 jsrain@suse.cz
- enable netdaemon if GNOME is default desktop (#72018)
* Mon Mar 14 2005 jsrain@suse.cz
- enable FAM daemon when GNOME is installed
* Mon Mar 14 2005 ms@suse.de
- fixed missing reboot on SSH installation (#67043)
* Fri Mar 11 2005 ms@suse.de
- added option --auto-fonts to Y2_QT_ARGS (#72174)
* Fri Mar 11 2005 ms@suse.de
- fixed setting TERM variable (#71771)
* Mon Mar  7 2005 jsrain@suse.cz
- initialize &product; macro in inst_suseconfig (#70899)
- set hwcfg file for parallel printer (#64412)
* Thu Mar  3 2005 ms@suse.de
- fixed LANG setting in F03-language (#66498)
* Thu Mar  3 2005 ms@suse.de
- fixed startup scripts for pcmcia/usb network installations (#65164)
* Wed Mar  2 2005 jsrain@suse.cz
- merged texts from proofread
* Wed Mar  2 2005 nashif@suse.de
- url in last dialog is set to www.novell.com/linux
* Tue Mar  1 2005 jsrain@suse.cz
- removed obsolete symlink juggling (#66016)
* Thu Feb 24 2005 ms@suse.de
- added logsize check to FirstStage/F07-logging
* Wed Feb 23 2005 jsrain@suse.cz
- fixed comments for translators
* Tue Feb 22 2005 ms@suse.de
- fixed check for X11 configuration in continue mode (#66224)
* Tue Feb 22 2005 sh@suse.de
- V 2.11.17
* Tue Feb 22 2005 ms@suse.de
- fixed Y2MAXLOGSIZE setting, which was set to 0 because df within
  inst-sys is not an option for checking the filesystem space
* Mon Feb 21 2005 sh@suse.de
- Proper log-rotating in inst_finish
- V 2.11.16
* Fri Feb 18 2005 jsrain@suse.cz
- added "Initializing..." title to installation before something
  else is shown (#51039)
* Thu Feb 17 2005 ms@suse.de
- fixed inst-sys copy process of XF86Config to take care
  about the new name xorg.conf
* Wed Feb 16 2005 jsrain@suse.cz
- fix displaying release notes if the localized version is not
  available (#50911)
* Thu Feb 10 2005 jsrain@suse.cz
- reduced forced minimal size of the release notes popup (#50637)
- fixed the order of proposal creation (and thus firewall
  is enabled again) (#50622)
- 2.11.15
* Wed Feb  9 2005 nashif@suse.de
- Save files control.xml and info.txt from installation into
  /etc/YaST2.
* Wed Feb  9 2005 jsrain@suse.cz
- additional kernel parameters in control file Prof moved to
  the new variable (#50369)
* Tue Feb  8 2005 nashif@suse.de
- Moved ProductControl to yast2 package
* Mon Feb  7 2005 jsrain@suse.cz
- fixed order of items in the "Change" button in proposals (#50204)
- merged texts from proofread
- added label informing about release notes from media
- fixed translating empty string in the installation steps
- 2.11.12
* Fri Feb  4 2005 jsrain@suse.cz
- display release notes from installation proposal
* Wed Feb  2 2005 ms@suse.de
- fixed control center call (#50389)
* Tue Feb  1 2005 nashif@suse.de
- Fixed left "steps" display problems (#50388)
* Wed Jan 26 2005 nashif@suse.de
- install inst_default_desktop.ycp (#49838)
* Tue Jan 25 2005 nashif@suse.de
- Fixed arguments in control file
- Fixed deleting completed steps
- 2.11.10
* Mon Jan 24 2005 nashif@suse.de
- Moved installation workflow routines out of installation.ycp
- Adapted arguments of installation clients
- Enhanced control file and made it more readable (arguments of clients
  are clearer now)
* Mon Jan 24 2005 ms@suse.de
- fixed language environment (#49811)
* Thu Jan 13 2005 jsrain@suse.cz
- changed the "System will boot now..." message at the end of
  isnt_finish.ycp (#41592)
- 2.11.8
* Wed Jan 12 2005 ms@suse.de
- removed xmset calls to disable/enable the mouse pointer.
- prevent patching X11 configuration in continue mode
* Wed Jan 12 2005 ms@suse.de
- fixed yast startup in continue mode. The evaluation of the
  variables USE_SSH and VNC was wrong in S08-start and
  S09-cleanup
* Tue Jan 11 2005 jsrain@suse.cz
- prevent disabling the Next button in the proposal (#46708)
* Wed Jan  5 2005 jsrain@suse.cz
- removed unneeded imports and variables from installation.ycp
- adapted to changed interface of Kernel.ycp
- 2.11.7
* Tue Jan  4 2005 jsrain@suse.cz
- on SGI Altix add fetchop and mmtimer to MODULES_LOADED_ON_BOOT
  (was disabled due to problems in Kernel.ycp) (bug #46971)
- disable Back/Accept buttons in inst_finish.ycp (#37025)
* Thu Dec 16 2004 sh@suse.de
- Applied patch from bug #49275: Enable user to skip proposal
  even if there is a blocker error in it
* Thu Dec  9 2004 arvin@suse.de
- disable inclusion of fetchop and mmtimer in
  MODULES_LOADED_ON_BOOT on SGI Altix (bug #46971)
* Fri Dec  3 2004 ms@suse.de
- include some patches from old startup code which has been
  changed while developing the new startup concept. Please note
  all architecture dependant code has to be part of the startup/arch
  directories and must be included in a clean way to the new scripts.
  I will not include any arch changes made in the last weeks because
  this will lead to the same horrible situation we had in the past.
  if there is anything which has to be handled differntly on another
  architecture this must be done separately to be able to maintain
  that code longer than two days
* Wed Dec  1 2004 sh@suse.de
- Fixed bug #48722: Inconsistent lower/upper case in mode dialog
* Mon Nov 29 2004 ms@suse.de
- startup scripts ready now. reports can be send using bug: (#46886)
* Thu Nov 11 2004 arvin@suse.de
- always use Directory::logdir
* Thu Nov 11 2004 sh@suse.de
- Record macros during installation:
  /var/log/YaST2/macro_inst_initial.ycp for initial stage,
  /var/log/YaST2/macro_inst_cont.ycp  for "continue" mode
* Tue Nov  2 2004 arvin@suse.de
- allow to select repair/boot in installation mode selection even
  when no update is possible (bug #39874)
* Mon Nov  1 2004 visnov@suse.cz
- set product name in wizard (#46247)
* Wed Oct 27 2004 arvin@suse.de
- on SGI Altix add fetchop and mmtimer to MODULES_LOADED_ON_BOOT
  (bug #46971)
* Tue Oct 26 2004 jsrain@suse.cz
- moved parts of Mode.ycp to Installation.ycp
- adapted to Mode.ycp clean-up
- 2.11.2
* Tue Oct 19 2004 lslezak@suse.cz
- UML mode: copy /etc/mtab file to host system (#42859)
- version 2.11.1
* Mon Oct 11 2004 jsrain@suse.cz
- adapted to functional interface of Arch.ycp
* Mon Oct 11 2004 jsrain@suse.cz
- moved default logon/window manager setting to extra client,
  setting it according to the base package selection (#46619)
- 2.11.0
* Thu Sep 30 2004 sh@suse.de
- V 2.10.30
- Made final confirmation popup higher to accomodate all text
  without scrolling even in more verbose languages (de, fr)
* Wed Sep 29 2004 mls@suse.de
- stop splash animation before starting yast
- go to verbose mode if X didn't start
* Mon Sep 27 2004 arvin@suse.de
- don't create top-level "media" convenience links (bug #46152)
* Wed Sep 22 2004 sh@suse.de
- Made final installation confirmation dialog wider and higher
  to avoid scrolling even for more verbose languages (de, fr)
- V 2.10.27
* Wed Sep 22 2004 visnov@suse.cz
- reinitialize dialog after mode chosen (#45784)
* Tue Sep 21 2004 arvin@suse.de
- use suse marble in congratulation screen (bug #45712)
* Mon Sep 20 2004 sh@suse.de
- V 2.10.24
- Merged accidentially split translatable messages
* Fri Sep 17 2004 sh@suse.de
- V 2.10.23
- Changed final installation confirmation dialog according to
  bug #45279
* Fri Sep 17 2004 arvin@suse.de
- moved popup with boot message further to the end (bug #45432)
* Thu Sep 16 2004 snwint@suse.de
- use language info from linuxrc to set LANG in YaST.start; this is
  just to run ncurses yast in fbiterm for exotic languages
* Wed Sep 15 2004 arvin@suse.de
- fixed back button in internet test dialog (bug #45319)
* Wed Sep 15 2004 visnov@suse.cz
- initialize proposal heading before creating dialog (#45340)
* Tue Sep 14 2004 sh@suse.de
- V 2.10.20
- Fixed bug #45271: Mixture of en_UK / en_US: "licence" / "license"
* Tue Sep 14 2004 mvidner@suse.cz
- Copy the DHCP cache to the right place (#45150).
* Tue Sep 14 2004 arvin@suse.de
- fixed help text in main proposal (bug #45093)
* Tue Sep 14 2004 jsrain@suse.cz
- added enable_firewall and firewall_ssh_enable to control file
  for PROF
- added related handlinng to ProductControl
* Mon Sep 13 2004 jsrain@suse.cz
- set FAM_ONLY_LOCAL and start fam according to default windowmanager
- 2.10.18
* Mon Sep 13 2004 arvin@suse.de
- added system info entry to update proposal (bug #45096)
* Fri Sep 10 2004 snwint@suse.de
- use vesa driver as fallback, not vga (see #38253, comment #11)
* Thu Sep  9 2004 mvidner@suse.cz
- Added a client to test the network and hardware proposals (#44677).
- 2.10.16
* Wed Sep  8 2004 visnov@suse.cz
- implemented reordering of proposal items
- implemented support for hyperlinks in proposal summaries
* Tue Sep  7 2004 arvin@suse.de
- added proposal step to initialize sources during update before
  mounting filesystems (needed to solve bug #44724)
* Mon Sep  6 2004 mvidner@suse.cz
- Copy the DHCP client cache so that we can request the same IP
  (#43974).
- 2.10.14
* Mon Sep  6 2004 jsrain@suse.cz
- avoid asking to confirm one license multiple times (#44145)
* Fri Sep  3 2004 arvin@suse.de
- call Bootloader::Update instead of Bootloader::Write during
  update (bug #44286)
* Mon Aug 30 2004 jsrain@suse.cz
- ask to confirm licenses of packages before installing/updating
  (#44145)
- 2.10.12
* Fri Aug 27 2004 mvidner@suse.cz
- When showing the address for a VNC installation, don't rely on
  install.inf, print the current IP (#43974).
- 2.10.11
* Fri Aug 27 2004 arvin@suse.de
- merged proof read messages
* Wed Aug 25 2004 arvin@suse.de
- avoid tmp file in /tmp (bug #39444)
* Wed Aug 18 2004 arvin@suse.de
- updated fvwmrc.yast2 (see bug #43796)
* Tue Aug 17 2004 nashif@suse.de
- XFree86 -> xorg-x11 (#43832)
* Fri Aug 13 2004 nashif@suse.de
- Fixed update (#43795)
* Wed Aug 11 2004 nashif@suse.de
- Copy EULA to installed system for later use in firstboot module
* Wed Aug 11 2004 nashif@suse.de
- Added firewall to network proposal (#43718)
* Tue Aug 10 2004 nashif@suse.de
- Add default label for proposals
* Tue Aug 10 2004 mvidner@suse.cz
- Fixed arguments for proposals (`initial)
* Mon Aug  9 2004 nashif@suse.de
- Enable locking of proposals in control file
- Updated DTD for control file
* Thu Jul 29 2004 nashif@suse.de
- New variables for ui and language handling added to control file
- Use Linuxrc module for install.inf and yast.inf handling
* Tue Jul 20 2004 arvin@suse.de
- use capitalized SUSE in congratulation screen (bug #38853)
* Tue Jun 15 2004 sh@suse.de
- Fixed typo in ssh install script (#42058)
* Tue Jun 15 2004 sh@suse.de
- Fixed bug #41597: EULA must be scrolled in both dimensions
* Tue Jun 15 2004 arvin@suse.de
- added Requires for yast2-update (bug #42013)
* Thu Jun 10 2004 nashif@suse.de
- Added variable software_proposal to control file (NLD)
* Thu Jun 10 2004 nashif@suse.de
- Added control for NLD
* Tue Jun  8 2004 nashif@suse.de
- Also install control file for SLES to avoid lots of possible
  confusion when control file is not found on installation media
  and fallback file is used.
  (#41696)
* Tue Jun  8 2004 nashif@suse.de
- Fixed bug #41696: yast uses elevator=anticipatory instead of
  elevator=as
* Sat May 29 2004 nashif@suse.de
- Added Services to main control file for translation (#41367)
- 2.9.83
* Thu May 27 2004 mvidner@suse.cz
- Added variables to ProductFeatures
  so that yast2-nis-client testsuite passes (~#41038).
- 2.9.82
* Thu May 27 2004 arvin@suse.de
- added special console handling for iSeries (bug #39025)
* Wed May 26 2004 arvin@suse.de
- set LD_LIBRARY_PATH in 1st stage installation start script
  (bug #40833)
* Tue May 25 2004 jsrain@suse.cz
- set the I/O scheduler in ProductFeatures (#41038)
- 2.9.79
* Mon May 24 2004 arvin@suse.de
- again ask for TERM variable if it's set to "vt100" (bug #40991)
* Tue May 18 2004 arvin@suse.de
- moved fvwmrc.notitle from sax2 here (bug #37480)
* Tue May 11 2004 lslezak@suse.cz
- don't ask for TERM variable if it's already set to "xterm"
  or "vt100" from linuxrc (don't ask in UML installation) (#39947)
- version 2.9.76
* Tue May  4 2004 arvin@suse.de
- merged proofread messages
* Fri Apr 30 2004 arvin@suse.de
- readded vnc remote proposal to SLES workflow (bug #31023)
* Wed Apr 28 2004 arvin@suse.de
- quick implementation of execution of update.post2 scripts
  (bug #38677)
* Wed Apr 28 2004 lslezak@suse.cz
- set Ctrl+Alt+Del handler in /etc/inittab to halt (instead of
  reboot) in UML system (safe shutdown from host system using
  uml_mconsole)
- version 2.9.73
* Tue Apr 27 2004 gs@suse.de
- write Console: entry for p690 hvc console before reading
  /etc/install.inf (bug #39527)
* Tue Apr 27 2004 arvin@suse.de
- call Pkg::SetAdditionalLocales after language change from
  proposal (bug #38366)
* Mon Apr 26 2004 arvin@suse.de
- activate lvm and md before booting into a installed system
  (bug #39423)
* Thu Apr 22 2004 arvin@suse.de
- removed support of starting yast2 installation without keyboard
  (linuxrc always reports a keyboard now) (bug #39235)
* Thu Apr 22 2004 arvin@suse.de
- run unicode_{start,stop} only if they are present (bug #35714)
* Wed Apr 21 2004 arvin@suse.de
- uses special sles screen for user authentication on sles
* Mon Apr 19 2004 lslezak@suse.cz
- UML mode fixes: don't copy mtab to the host (it's not needed),
  find kernel and initrd even when symlinks are missing
  (workaround for bug #39063)
- added help text in UML installation proposal
- version 2.9.64
* Fri Apr 16 2004 nashif@suse.de
- store variables needed in run-time in a sysconfig like file
- first try to load saved control file before fallback to packaged one.
* Fri Apr 16 2004 arvin@suse.de
- fixed network start for remote x11 installation (bug #38832)
* Fri Apr 16 2004 lslezak@suse.cz
- UML mode fixes: don't copy mtab to the host (it's not needed),
  find kernel and initrd even when symlinks are missing
  (workaround for bug #39063)
- added help text in UML installation proposal
* Fri Apr 16 2004 arvin@suse.de
- removed keyboard proposal from update proposal for the update
  in the running system (bug #37817)
* Fri Apr 16 2004 arvin@suse.de
- don't run on serial console in case of vnc or ssh installation
  (bug #37325)
* Thu Apr 15 2004 arvin@suse.de
- add "service" proposal to SLES installation
* Thu Apr 15 2004 arvin@suse.de
- log fvwm output for vnc installation (bug #30061)
* Wed Apr  7 2004 arvin@suse.de
- avoid tmp file creation in check.boot script (bug #38572)
* Tue Apr  6 2004 arvin@suse.de
- use fbiterm for CJK locales if appropriate (bug #37823)
* Tue Apr  6 2004 nashif@suse.de
- only_update_selected option added to product feature set
- V 2.9.56
* Tue Apr  6 2004 sh@suse.de
- V 2.9.55
- Fixed bug #36908: Use dynamic fonts based on resolution
* Mon Apr  5 2004 fehr@suse.de
- load module dm-snapshort at to prevent hangs if LVM contains
  snapshot LVs (#36422)
* Mon Apr  5 2004 arvin@suse.de
- show correct warning in second stage installation when xserver
  can't be started (bug #38298)
* Mon Apr  5 2004 arvin@suse.de
- adjusted decision of frontend depending on memory size to memory
  requirements of new interpreter (bug #38298)
- fixed memory value in warning popup
* Sat Apr  3 2004 arvin@suse.de
- use fbiterm for CJK locales if appropriate (bug #37823)
* Fri Apr  2 2004 arvin@suse.de
- finally changed license to GPL for good
* Thu Apr  1 2004 arvin@suse.de
- symmetricalized calls to inst_netsetup (bug #37763)
* Thu Apr  1 2004 arvin@suse.de
- removed step label for inst_netsetup (bug #37546)
* Wed Mar 31 2004 nashif@suse.de
- Added 2 options to control file:
  inform_about_suboptimal_distribution
  use_desktop_scheduler
* Wed Mar 31 2004 lslezak@suse.cz
- inst_finish.ycp - copy kernel image, initrd and /etc/mtab to
  the host system in UML installation mode
* Tue Mar 30 2004 arvin@suse.de
- disable virtual desktops in fvwm during vnc installation
  (bug #37480)
* Mon Mar 29 2004 fehr@suse.de
- call Storage::FinishInstall() at end of installation
* Mon Mar 29 2004 sh@suse.de
- Fixed bug #36713 (relies on yast2-core with fix for bug #36711):
  textdomain for wizard steps should come from control.xml
* Mon Mar 29 2004 nashif@suse.de
- fixed copying of hook script logs into installed system
* Sun Mar 28 2004 nashif@suse.de
- fixed hook scrips, now using WFM::Read(.local...) (#36831 )
- Not executing any scripting after last client
- Detecting mode before installation steps are sets (#37070 )
- logging hook output to /var/log/YaST2 and copying those
  file to installed system.
* Thu Mar 25 2004 sh@suse.de
- Fixed bug #34618: Don't use full-screen if started remotely
* Thu Mar 25 2004 ms@suse.de
- fixed driver to use on ia64 systems. there is no framebuffer
  available but the vesa driver is working now (#34909)
- fixed possible loop at installation. handle different exit codes
  from testX in scripts/YaST2. The needed changes to testX have
  been made within the sax2 package (#36794)
* Thu Mar 25 2004 arvin@suse.de
- removed network proposal from update work flow
* Wed Mar 24 2004 arvin@suse.de
- renamed usbdevfs to usbfs (bug #31869)
* Wed Mar 24 2004 sh@suse.de
- Fixed bug #36850: Strange texts in y2qt wizard side bar
- V 2.9.42
* Wed Mar 24 2004 gs@suse.de
- workaround beta3 pre bug: deactivate Hooks::Run
  (causes crash after inst_finish)
- V 2.9.41
* Mon Mar 22 2004 nashif@suse.de
- Execute features client if variables are set in control file
- V 2.9.40
* Mon Mar 22 2004 sh@suse.de
- V 2.9.39
- Fixed bug #36292: Wizard steps not translated
- Preliminary fix for bug #36713: Use textdomain from XML file
* Mon Mar 22 2004 arvin@suse.de
- introduced and handle new variable Installation::scr_destdir
  to be used by Storage (bug #34996)
* Sun Mar 21 2004 nashif@suse.de
- read/set language/keyboard/timezone
- added client to set product variables before entering proposal
* Fri Mar 19 2004 arvin@suse.de
- omit skip/don't skip buttons in uml proposal
* Thu Mar 18 2004 arvin@suse.de
- fixed update work flow setting (bug #36429 and #35007)
* Thu Mar 18 2004 mvidner@suse.cz
- Fall back to runlevel 3 if we accidentally don't set it
  in the installation proposal. It would be 0 (#35662).
* Wed Mar 17 2004 nashif@suse.de
- Add runlevel to s390 proposal
- remove x11 from autoinst workflow (handled differently)
* Wed Mar 17 2004 nashif@suse.de
- update wizard steps at the right spot to enable switching back
  to installation mode
* Tue Mar 16 2004 kkaempf@suse.de
- run cleanup script for GNOME (#36196)
* Tue Mar 16 2004 msvec@suse.cz
- added icons to network and hardware proposals
* Tue Mar 16 2004 fehr@suse.de
- fix typo devmap_mkmod.sh -> devmap_mknod.sh
- 2.9.32
* Tue Mar 16 2004 nashif@suse.de
- Enabled evms_config in control file
* Tue Mar 16 2004 nashif@suse.de
- Update steps when switching modes (#35590)
* Mon Mar 15 2004 arvin@suse.de
- don't ask for terminal type during vnc installation (bug #33534)
* Fri Mar 12 2004 nashif@suse.de
- Update control file for autoinst
- Enable swittching of steps upon mode change
- Added possibility to disable a workflow step in runtime
* Thu Mar 11 2004 sh@suse.de
- Fixed bug #34618: Don't use full screen in remote installation
* Wed Mar 10 2004 arvin@suse.de
- don't warn if only no disk controller can be found (bug #35546)
* Wed Mar 10 2004 arvin@suse.de
- extended uml installation work flow
* Wed Mar 10 2004 nashif@suse.de
- Set wizard steps depending on installation mode
* Wed Mar 10 2004 nashif@suse.de
- removed include dir from spec
* Wed Mar 10 2004 sh@suse.de
- V 2.9.24
- Migration to new wizard
* Tue Mar  9 2004 msvec@suse.cz
- replaced X11 version detection code with (simpler) YCP
- package could be noarch currently (reduced NFB a lot)
* Mon Mar  8 2004 arvin@suse.de
- call more generalized storage function during update
* Fri Mar  5 2004 arvin@suse.de
- load correct device mapper module and create nodes
* Thu Mar  4 2004 visnov@suse.cz
- added type info
- 2.9.20
* Wed Mar  3 2004 nashif@suse.de
- Moved product features to new feature module
* Wed Mar  3 2004 sh@suse.de
- Applied rw's patch for bug #34531
* Wed Mar  3 2004 arvin@suse.de
- call storage function to update fstab (bug #34996)
* Tue Mar  2 2004 sh@suse.de
- Added user-visible workflow step descriptions for new wizard
  layout
* Mon Mar  1 2004 arvin@suse.de
- work on UML installation
* Fri Feb 27 2004 nashif@suse.de
- New control file based installation merged
* Fri Feb 20 2004 arvin@suse.de
- handle abort button in inst_finish (bug #30303)
* Fri Feb 20 2004 arvin@suse.de
- removed obsolete code from start scripts (bug #31805)
* Mon Feb 16 2004 mvidner@suse.cz
- set the runlevel according to the proposal
- 2.9.15
* Mon Feb 16 2004 arvin@suse.de
- added more flexible package handling for products
* Mon Feb 16 2004 mvidner@suse.cz
- added runlevel_proposal to installation_proposals (#30028)
- 2.9.14
* Mon Feb 16 2004 arvin@suse.de
- removed obsolete Mode::hardBoot
* Fri Feb 13 2004 sh@suse.de
- Applied patch from bug #34531: Kernel 2.6 hotplug handling
* Wed Feb 11 2004 arvin@suse.de
- more control over base selection handling
* Tue Feb 10 2004 arvin@suse.de
- added type specification in inst_proposal.ycp
* Tue Feb 10 2004 nashif@suse.de
- remove x11 from workflow for autoyast
* Tue Feb 10 2004 arvin@suse.de
- fixed building on s390
* Sat Feb  7 2004 nashif@suse.de
- remove vendor.y2cc file
* Fri Feb  6 2004 arvin@suse.de
- set default runlevel to 3 or 5 during installation depending
  on the presents of X11 (see bug #32366)
* Fri Feb  6 2004 arvin@suse.de
- fixed copying of temporary X11 config
* Mon Feb  2 2004 lslezak@suse.cz
- InitHWinfo module enabled in installation proposal
- version 2.9.4
* Sat Jan 31 2004 arvin@suse.de
- removed useless 'global'
* Mon Jan 26 2004 jsrain@suse.de
- removed cfg_susecnfig.scr from file list (was moved to yast2.rpm)
- 2.9.2
* Fri Dec 12 2003 jsrain@suse.de
- don't check if module is present in initrd before loading it
* Fri Oct 24 2003 ms@suse.de
- added stuff from yast2/library/x11 to installation package
* Fri Oct 24 2003 arvin@suse.de
- added help text for "Repair Installed System" (bug #30402)
* Fri Oct 17 2003 ms@suse.de
- inst_finish: (#32366)
  removed runlevel setup code which is handled within the X11
  module now (XProposal.ycp). The update code for initdefault
  is still present because during update the X11 configuration
  is not started
- inst_x11: (#32366)
  removed dead code which sets the default runlevel to 3 if there
  is no XF86Config file present. This task is done if the X11
  configuration is finished and if there is no X11 configuration
  the default initdefault with aaa_base is set to 3 already
* Wed Sep 24 2003 snwint@suse.de
- look for x11 drivers in lib64 dir on x86_64 (#31649)
* Thu Sep 18 2003 arvin@suse.de
- shut down temporary network before online test during update
  (bug #31030)
* Thu Sep 18 2003 arvin@suse.de
- don't use external pcmcia during firstboot (bug #31252)
* Mon Sep 15 2003 msvec@suse.cz
- 2.8.34
* Mon Sep 15 2003 gs@suse.de
- YaST2.start: set default value for LANGUAGE
* Mon Sep 15 2003 arvin@suse.de
- skip network probing during update (bug #30545)
* Sun Sep 14 2003 arvin@suse.de
- reset packagemanager when changing installation mode (bug #27970)
* Sun Sep 14 2003 snwint@suse.de
- added test for utf8 serial console to YaST2.{start,firstboot}
* Sat Sep 13 2003 nashif@suse.de
- remove inst_startup from autoinst workflow, add it autoinst_init
  (bug #30678)
* Fri Sep 12 2003 ms@suse.de
- added milestone texts for X11 config update/inject (#30612)
- fixed lookup path for XFree86 3.x config (#30612)
* Fri Sep 12 2003 arvin@suse.de
- fixed permissions of /var/lib/YaST2/install.inf (bug #30630)
* Thu Sep 11 2003 kkaempf@suse.de
- use kernel k_smp4G on SMP-systems with
  memory <= 4GB or without PAE support
* Thu Sep 11 2003 arvin@suse.de
- check for /proc/splash (bug #30472)
* Wed Sep 10 2003 sh@suse.de
- Fixed max log file size calculation:
  Set LANG only in subshell,
  don't rely on /dev in 'df' output - use last line instead
* Tue Sep  9 2003 kkaempf@suse.de
- use kernel k_psmp on smp-systems with
  less than 4GB memory or without PAE support
* Tue Sep  9 2003 arvin@suse.de
- added kernel option desktop
* Mon Sep  8 2003 sh@suse.de
- V 2.8.24
- Fixed bug #29927: Logfile setting too restrictive
  Now checking free space on RAM disk with 'df' and using
  max 10%% of that per log file (max 5000)
* Mon Sep  8 2003 snwint@suse.de
- advance splash progress bar in YaST2{,.start}
- driver updates are applied in inst_setup (used to be in YaST2.start)
- don't clear screen in YaST2.start
* Thu Sep  4 2003 arvin@suse.de
- proof-read messages
* Wed Sep  3 2003 gs@suse.de
- installation.ycp: call UI::SetKeyboard in continue mode
  (enable unicode for ncurses in UTF-8 locale)
* Wed Sep  3 2003 kkaempf@suse.de
- copy XF86Config from inst-sys to XF86Config.install in
  the system (#29910)
* Tue Sep  2 2003 kkaempf@suse.de
- make repair system accessible
* Mon Sep  1 2003 arvin@suse.de
- removed obsolete inst_hw_config.ycp and inst_confirm_abort.ycp
* Sun Aug 31 2003 arvin@suse.de
- use Popup::ConfirmAbort
* Sat Aug 30 2003 arvin@suse.de
- moved reactivation of network to yast2-network (bug #29561)
- moved display of into.txt into separate file
* Thu Aug 28 2003 ms@suse.de
- fixed xmigrate call (#29535)
* Thu Aug 28 2003 kkaempf@suse.de
- Install default kernel on SMP systems without 'PAE'
  (i.e. Pentium1-SMP)
- Drop check for unsupported Cyrix-CPUs without 'TSC'
* Tue Aug 26 2003 arvin@suse.de
- don't gray out next button in proposal in case of blockers
  (bug #29320)
* Fri Aug 22 2003 arvin@suse.de
- fixed reading of memory info (bug #29017)
* Fri Aug 22 2003 arvin@suse.de
- fixed update workflow
* Thu Aug 21 2003 arvin@suse.de
- removed obsolete installation_ui.ycp
* Thu Aug 21 2003 kkaempf@suse.de
- copy badlist (if existing) to installed system (#29092)
* Tue Aug 19 2003 arvin@suse.de
- better way for mouse probing in text mode (bug #29005)
* Mon Aug 18 2003 arvin@suse.de
- don't probe mouse in text mode (bug #29005)
* Fri Aug 15 2003 arvin@suse.de
- removed obsolete showlog_defines.ycp
* Tue Aug 12 2003 arvin@suse.de
- added remote administration proposal to network proposal
* Tue Aug 12 2003 gs@suse.de
- YaST2.start: don't run in UTF-8 mode on a console which is
  connected to a serial port
* Mon Aug 11 2003 arvin@suse.de
- use ycp based ncurses menu at end of installation
* Fri Aug  8 2003 arvin@suse.de
- variable handling of release notes url
* Wed Aug  6 2003 arvin@suse.de
- don't copy kernel config from to /usr/src/linux (bug #28496)
* Fri Aug  1 2003 arvin@suse.de
- call inst_netprobe during install
- added desktop files
* Wed Jul 30 2003 arvin@suse.de
- don't complain when no storage controllers can be found
  (bug #23686)
* Wed Jul 30 2003 arvin@suse.de
- always let YaST run in an UTF-8 environment during installation
  (bug #14751)
* Fri Jul 25 2003 arvin@suse.de
- removed handling of XFree86 Version 3 from YaST2.start
* Fri Jul 25 2003 gs@suse.de
- YaST2.firstboot: read RC_LANG from /etc/sysconfig/language and
    export LANG accordingly;
  call unicode_start/unicode_stop (if required)
* Thu Jul 24 2003 gs@suse.de
- YaST2.start: call unicode_start/unicode_stop;
    export YAST_DOES_ACS removed
* Fri Jul  4 2003 arvin@suse.de
- convert update workflow into a proposal
* Fri May 23 2003 arvin@suse.de
- take kernel command line from install.inf (bug #25745)
* Mon Apr 28 2003 arvin@suse.de
- fixes for live eval (bug #26457)
* Wed Apr 23 2003 ms@suse.de
- add config migration from 3x to 4x if possible
- ensure XF86Config is available if someone performs an update
  within a XFree86 3.x environment
* Tue Apr 15 2003 arvin@suse.de
- removed call of SuSEconfig.3ddiag and switch2mesasoft after
  reboot during installation since they don't exist anymore
* Thu Apr 10 2003 ms@suse.de
- fixed conditions of xmset calls (#26214)
* Tue Apr  8 2003 jsrain@suse.de
- fixed parsing of kernel parameters containing blank space
  (#26147)
* Tue Apr  1 2003 jsrain@suse.de
- added init= kernel parameter to discard list (#25478)
* Tue Mar 18 2003 kkaempf@suse.de
- drop "insserv apache" again, opens port 80
- 2.7.43
* Mon Mar 17 2003 kkaempf@suse.de
- "insserv apache" if it's DOC_SERVER (#25436)
- 2.7.42
* Mon Mar 17 2003 arvin@suse.de
- start fvwm2 for vnc installation (bug #25405)
* Mon Mar 17 2003 arvin@suse.de
- turn of silent splash mode before displaying messages during
  vnc and ssh installation (bug #25407)
* Mon Mar 17 2003 kkaempf@suse.de
- start apache as doc_server if suse_help_viewer isn't provided
  by kdebase3-SuSE (25436)
- 2.7.39
* Sat Mar 15 2003 kkaempf@suse.de
- gdm2 might not be installed yet but earmarked for installation
  (#25410)
- 2.7.38
* Fri Mar 14 2003 sh@suse.de
- The final and super-great ultimate path for release notes:
  /usr/share/doc/release-notes/RELEASE-NOTES.*.rtf
* Fri Mar 14 2003 sh@suse.de
- Moved RTF version of release notes from /usr/share/doc to
  /usr/share/doc/release_notes
* Fri Mar 14 2003 sh@suse.de
- Using file name RELEASE_NOTES.rtf to allow coexistence with
  RELEASE_NOTES.html for Konqueror
* Fri Mar 14 2003 fehr@suse.de
- remove handling of IDE recorders from inst_finish.ycp
  this is now done much sooner in StorageDevices.ycp (bug #25293)
* Wed Mar 12 2003 arvin@suse.de
- fixed focus in last installation dialog (bug #25171)
* Wed Mar 12 2003 ms@suse.de
- fixed broken mouse bug in continue mode (#24914)
* Tue Mar 11 2003 kkaempf@suse.de
- also set /etc/sysconfig/displaymanager:DISPLAYMANAGER (#25087)
* Mon Mar 10 2003 kkaempf@suse.de
- check for existance of /usr/src/linux/include/linux before
  copying kernel config.
- 2.7.32
* Mon Mar 10 2003 mvidner@suse.de
- Added .etc.install_inf_alias to work around an ini-agent
  limitation (#24836).
- 2.7.31
* Mon Mar 10 2003 arvin@suse.de
- fixed compose characters for certain locales (bug #14751)
* Fri Mar  7 2003 nashif@suse.de
- Dont read product data from installed system if in config mode
  (#24772 )
* Fri Mar  7 2003 kkaempf@suse.de
- copy kernel config to /usr/src/linux/... (#24835)
* Thu Mar  6 2003 fehr@suse.de
- umount fs based on crypto loop files before all other umounts
  (#24751)
* Thu Mar  6 2003 ms@suse.de
- removed mouse probing code from inst_startup.ycp and put
  that code into installation.ycp. Changed the mouse probing
  code to disconnect the device in front of the probing and
  re-connect it after the probing is done to avoid any
  jumping mouse cursors (#24355)
* Tue Mar  4 2003 arvin@suse.de
- handle flags from content file in Product module (bug #21561)
* Tue Mar  4 2003 sh@suse.de
- Fixed bug #24542: Bad license agreement button text
* Mon Mar  3 2003 sh@suse.de
- Fixed bug #10990: Boot installed system does not unmount
* Mon Mar  3 2003 fehr@suse.de
- call win resize module not only on i386 but also on x86_64 and ia64
* Thu Feb 27 2003 arvin@suse.de
- kill (with SIGKILL) shell on tty2 after installation (bug #24404)
* Wed Feb 26 2003 kkaempf@suse.de
- pass language to packagemanager (#23828)
* Wed Feb 26 2003 arvin@suse.de
- disable all sources if user aborts installation (bug #24292)
* Tue Feb 25 2003 arvin@suse.de
- make Hardware Configuration Dialog unconfuseable (bug #24020)
* Mon Feb 24 2003 kkaempf@suse.de
- add debug hooks (#23787)
* Mon Feb 24 2003 sh@suse.de
- V 2.7.20
- Fixed bug #24038: Installation language re-selection does not work
* Mon Feb 24 2003 gs@suse.de
- don't add .UTF-8 to LANG variable (causes problems with ncurses)
  bug #23348
* Mon Feb 24 2003 mvidner@suse.de
- Added proxy to the network configuration proposal (#24204).
* Fri Feb 21 2003 arvin@suse.de
- better text for "abort installation" popup (bug #24019)
* Fri Feb 21 2003 arvin@suse.de
- fixed button labels and help texts (bug #23912)
* Fri Feb 21 2003 sh@suse.de
- Fixed bug #24027: Root exploit in inst_suseconfig
* Fri Feb 21 2003 arvin@suse.de
- always do hard reboot (bug #23903)
* Thu Feb 20 2003 kkaempf@suse.de
- drop /etc/XF86Config (#23965)
* Thu Feb 20 2003 arvin@suse.de
- use title-style capitalization for menu names (bug #23848)
* Thu Feb 20 2003 ms@suse.de
- add support for mouse wheel during installation (#21660)
* Wed Feb 19 2003 arvin@suse.de
- disable all sources if user aborts installation (bug #23776)
* Wed Feb 19 2003 fehr@suse.de
- fix wrong variable of keyboard module in inst_finish.ycp (#23782)
* Wed Feb 19 2003 arvin@suse.de
- run SuSEconfig fonts during inst_finish for anti aliased fonts
  (bug #23768)
* Tue Feb 18 2003 arvin@suse.de
- fixed reading of content file if FLAGS line is missing
* Sat Feb 15 2003 nashif@suse.de
- call inst_x11 in autoinst mode
* Wed Feb 12 2003 kkaempf@suse.de
- remove call to mkinfodir (#23588)
* Wed Feb 12 2003 fehr@suse.de
- Write keytable info to yast.inf again in inst_finish.ycp
* Tue Feb 11 2003 arvin@suse.de
- handle update flag from content file (bug #21561)
* Mon Feb 10 2003 arvin@suse.de
- setup complete environment for qt during installation
* Mon Feb 10 2003 arvin@suse.de
- skip proposal dialog if it's empty (bug #23520)
* Fri Feb  7 2003 jsuchome@suse.de
- adapted inst_confirm_abort for the use from yast2-repair
* Thu Feb  6 2003 jsrain@suse.de
- removed missleading help text about starting of network during
  hardware proposal, when network has already been started (#20912)
* Wed Feb  5 2003 arvin@suse.de
- merged proofread messages
* Mon Feb  3 2003 sh@suse.de
- V 2.7.7
- Added default function key handling
* Thu Jan 30 2003 kkaempf@suse.de
- call /usr/bin/mkinfodir in inst_suseconfig
  (replaces SuSEconfig.man_info)
* Wed Jan 29 2003 arvin@suse.de
- added dialog to ask for preferred method of user authentication
* Tue Jan 28 2003 arvin@suse.de
- added final congratulations dialog
- added dialog with release notes
* Mon Jan 27 2003 sh@suse.de
- V 2.7.5
- Use new y2base/qt command line options for better WM cooperation
- Don't start a WM any more in YaST2 start script
  (testX does that now)
* Wed Jan 22 2003 arvin@suse.de
- use newer interface to modules agent (bug #22995)
* Wed Jan 22 2003 jsrain@suse.de
- returned accidentally removed call of Bootloader::Write ()
  function (bug #23018)
- 2.7.3
* Fri Dec 20 2002 arvin@suse.de
- changed label of second button of popup with info.txt (EULA)
  from "Cancel" to "Do Not Accept" (bug #21874)
* Fri Dec 20 2002 arvin@suse.de
- merged from 8.1 branch:
  - only set hostname during vnc installation if necessary
    (bug #21454)
  - popup with info.txt (EULA) now has a timeout during
    autoinstallation (bug #21413)
  - remove /root/.vnc/passwd after installation (bug #21360)
  - popup with info.txt now has two buttons (accept and cancel)
  - start portmapper if instmode==nfs also on s390 (#21094)
* Thu Dec 12 2002 jsrain@suse.de
- added handling of modules required to be loaded early after
  mounting root
- not adding ide-scsi to initrd, but scheduling relevant modules
  to be loaded after boot (#19376)
* Wed Dec 11 2002 lslezak@suse.cz
- .proc.cpuinfo agent rewritten to INI-agent (now supports
  multiple CPU, all keys from /proc/cpuinfo can be read)
* Mon Dec  9 2002 arvin@suse.de
- add modules ide-cd and cdrom before ide-scsi to INITRD_MODULES
  when an ide cdwriter is found (bug #22343)
* Wed Dec  4 2002 jsrain@suse.cz
- adapted to new bootloader module interface
- 2.7.1
* Tue Oct 22 2002 ms@suse.de
- removed inst_x11 to be part of the installation workflow
- add x11_proposal to:
  hw-config-proposals-home-pc.ycp
  hw-config-proposals-networked-pc.ycp
* Wed Oct 16 2002 arvin@suse.de
- correctly handle quotes in /etc/install.inf (bug #20986)
* Wed Oct 16 2002 kkaempf@suse.de
- use proper tmpdir for vendor-supplied script when loading
  vendor driver disk (#20967)
- 2.6.87
* Tue Oct 15 2002 choeger@suse.de
- renamed product id text from "Open Team Server" to "Openexchange Server",
  because this text is shown into the installation window and the name of
  the cd is associated with this name
* Mon Oct 14 2002 sh@suse.de
- V 2.6.85
- Fixed bug #19214: Return to proposal after update
* Mon Oct 14 2002 kkaempf@suse.de
- use "UpdateDir" from install.inf when checking vendor
  update media (#19442)
- set /sysconfig/suseconfig/CWD_IN_USER_PATH="no" on non-box
  products (#17464)
- 2.6.84
* Mon Oct 14 2002 sh@suse.de
- V 2.6.83
- Fixed bug #19628: Obsolete MediaUI::ChangeMedium() call
* Thu Oct 10 2002 arvin@suse.de
- make info text (aka beta warning) scroll-able (bug #20063)
* Wed Oct  9 2002 jsrain@suse.cz
- now not enabling 2 gettys on same serial line on p690 (#19788)
* Tue Oct  8 2002 kkaempf@suse.de
- disable update for non-box products (#20695)
- 2.6.80
* Mon Oct  7 2002 kkaempf@suse.de
- display media.1/info.txt if exists before starting installation
  (#18504)
* Tue Oct  1 2002 kkaempf@suse.de
- runlevel 5 only where applicable (#20369)
* Thu Sep 26 2002 arvin@suse.de
- remove console kernel option if it's autodectected like
  pseries can do (bug #20177)
* Thu Sep 26 2002 choeger@suse.de
- call product specific YaST2 modules before finishing the
  installation
* Tue Sep 24 2002 arvin@suse.de
- run depmod after network setup for ssh and vnc installation
  (bug #20040)
* Mon Sep 23 2002 arvin@suse.de
- again fix for qt background color (bug #18926)
* Fri Sep 20 2002 arvin@suse.de
- in final proposal screen hide button to start control center if
  the control center is not available (bug #19926)
* Fri Sep 20 2002 kkaempf@suse.de
- re-init Product module in running system from cached
  product data properly
- 2.6.72
* Fri Sep 20 2002 kkaempf@suse.de
- initialize Product module from content data
- 2.6.71
* Fri Sep 20 2002 kkaempf@suse.de
- add agent to read "/content" file
- 2.6.69
* Fri Sep 20 2002 kkaempf@suse.de
- linuxrc provides 'content' at / now, no need to mount the source.
- 2.6.70
* Fri Sep 20 2002 kkaempf@suse.de
- force reboot on s390 after installation
- 2.6.69
* Thu Sep 19 2002 kkaempf@suse.de
- umount /var/adm/mount after retrieving content file
- 2.6.68
* Wed Sep 18 2002 kkaempf@suse.de
- added product hooks to installation workflow
- 2.6.67
* Wed Sep 18 2002 arvin@suse.de
- removed all code regarding zilo (bug #19821)
- fixed qt background color (bug #18926)
* Wed Sep 18 2002 arvin@suse.de
- provides/obsoletes the old yast
* Mon Sep 16 2002 kkaempf@suse.de
- remove unneeded Save() functions (#19591)
* Thu Sep 12 2002 fehr@suse.de
- remove obsolete LVM and MD initialisation in inst_mode.ycp
- 2.6.63
* Thu Sep 12 2002 kkaempf@suse.de
- remove control files (#19564)
- 2.6.62
* Thu Sep 12 2002 kkaempf@suse.de
- fix vendor path for UnitedLinux (#19442)
- 2.6.61
* Thu Sep 12 2002 kkaempf@suse.de
- dont warn about kernel if not in update mode.
- 2.6.60
* Thu Sep 12 2002 kkaempf@suse.de
- symlink *.shipped to *.suse on update for LILO compatibility
- 2.6.59
* Wed Sep 11 2002 kkaempf@suse.de
- properly unmount sources also on abort and end of update
- move package log to yast2-packager
- handle run-time kernel switch extra
- 2.6.58
* Tue Sep 10 2002 kkaempf@suse.de
- remove obsolete package data after update
- release source (CD) and target (rpmdb)
- 2.6.57
* Tue Sep 10 2002 arvin@suse.de
- added more provides/obsoletes (bug #19325)
* Tue Sep 10 2002 arvin@suse.de
- again fix initial language
* Mon Sep  9 2002 kkaempf@suse.de
- fix initial language
- 2.6.54
* Mon Sep  9 2002 arvin@suse.de
- run ncurses control center after installation (instead of ycp
  based one) (bug #19246)
* Mon Sep  9 2002 kkaempf@suse.de
- drop "noarch"
- 2.6.53
* Mon Sep  9 2002 arvin@suse.de
- setup proxy configuration for installation (bug #19189)
* Mon Sep  9 2002 kkaempf@suse.de
- remove runme_at_boot at end
- 2.6.51
* Fri Sep  6 2002 kkaempf@suse.de
- s390'ers want it different -> k_deflt on smp systems (#18990)
- 2.6.50
* Fri Sep  6 2002 kkaempf@suse.de
- properly detect update_mode after restart
- 2.6.49
* Thu Sep  5 2002 kkaempf@suse.de
- continue with inst_rpmcopy after update
- 2.6.48
* Thu Sep  5 2002 arvin@suse.de
- more old trans-package fun
* Thu Sep  5 2002 arvin@suse.de
- always run depmod after installation (bug #18382)
- set HOME=/root during installation (bug #18882)
* Wed Sep  4 2002 kkaempf@suse.de
- move update branch to yast2-update (#18876)
- 2.6.45
* Wed Sep  4 2002 arvin@suse.de
- fixed provide/obsolete of trans packages (bug #18691)
* Tue Sep  3 2002 kkaempf@suse.de
- adapt update workflow to package manager
- 2.6.41
* Mon Sep  2 2002 arvin@suse.de
- set default runlevel back to 3 if X11 is not configured
  (bug #18705)
* Mon Sep  2 2002 arvin@suse.de
- set HOME=/tmp during installation so qt doesn't pollute root
  filesystem (bug #18663)
* Fri Aug 30 2002 arvin@suse.de
- hide output of kill in YaST2.firstboot (bug #18585)
- moved X11Version.ycp to yast2 package
* Thu Aug 29 2002 arvin@suse.de
- fixed network start for ssh installation (bug #18506)
- fixed password saving for ssh installation (bug #18507)
- start in textmode for ssh installation (bug #18571)
* Thu Aug 29 2002 kkaempf@suse.de
- close source in inst_finish (#18508)
* Wed Aug 28 2002 kkaempf@suse.de
- trigger cache copying at end
- 2.6.35
* Tue Aug 27 2002 kkaempf@suse.de
- init packagemanager properly
- drop all references to old data (suse/setup/descr/info)
* Tue Aug 27 2002 arvin@suse.de
- load firewire support during installation (bug #18379)
- create_interfaces has moved from / to /sbin
* Tue Aug 27 2002 arvin@suse.de
- fixes for ssh installation
* Mon Aug 26 2002 arvin@suse.de
- don't run x11 configuration if x11 is missing (bug #18208)
* Mon Aug 26 2002 kkaempf@suse.de
- ignore even more boot options (#18154)
* Thu Aug 22 2002 fehr@suse.de
- call /sbin/vgscan if root filesystem is on LVM before calling
  Boot::Save() (#18180)
* Thu Aug 22 2002 arvin@suse.de
- use the same workflow on s390 as on other architectures
* Thu Aug 22 2002 kkaempf@suse.de
- drop "ht" flag probing, done in libhd now (#13532).
* Thu Aug 22 2002 kkaempf@suse.de
- run "SuSEconfig --module bootsplash" before bootloader
  V 2.6.29
* Thu Aug 22 2002 kkaempf@suse.de
- selected packages are also provided after installation
  V 2.6.28
* Thu Aug 22 2002 kkaempf@suse.de
- dont use .package agent in inst_finish
  V 2.6.27
* Wed Aug 21 2002 kkaempf@suse.de
- fix for build
  V 2.6.26
* Wed Aug 21 2002 kkaempf@suse.de
- adaptions to new packager
- V 2.6.25
* Tue Aug 20 2002 arvin@suse.de
- use new Mode::x11_setup_needed and Arch::x11_setup_needed
* Tue Aug 20 2002 arvin@suse.de
- don't probe for mouse, floppy and usb devices on iseries
* Mon Aug 19 2002 olh@suse.de
- implemented starting of ssh in installed system (needed for
  some kinds of remote installation)
* Mon Aug 19 2002 arvin@suse.de
- don't probe for mouse, floppy and usb devices on s390
* Mon Aug 19 2002 arvin@suse.de
- don't run X11 configuration on S390 (bug #17371)
* Mon Aug 19 2002 kkaempf@suse.de
- Moving target by ppc team. One bit more entered to #17739.
* Fri Aug 16 2002 kkaempf@suse.de
- drop BOOT_IMAGE=apic evaluation. enableapic is passed
  as normal kernel parameter to k_deflt now.
- add "SuSE" to list of kernel parameters to discard.
* Thu Aug 15 2002 kkaempf@suse.de
- linuxrc doesn't reboot on PCMCIA systems any more (#17739)
* Wed Aug 14 2002 arvin@suse.de
- added special hardware configuration list for ppc64 and s390
  (bug #17742)
* Wed Aug 14 2002 kkaempf@suse.de
- fix NoShell: check (#17714)
* Mon Aug 12 2002 kkaempf@suse.de
- fix network parameters passing from /etc/install.inf
- install k_athlon if vendor_id == "AuthenticAMD"  && cpu family >= 6
- drop "acpismp=force" for hyperthreading SMP
* Mon Aug 12 2002 kkaempf@suse.de
- read /etc/install.inf:InstMode correctly
* Thu Aug  8 2002 kkaempf@suse.de
- honor "/etc/install.inf:NoShell" to suppress extra shell on tty2.
* Wed Aug  7 2002 kkaempf@suse.de
- allow for multiple foreign primary partitions (#17458)
* Wed Aug  7 2002 arvin@suse.de
- removed access to variable DEFAULT_LANGUAGE in YaST2 start
  script (now only RC_LANG is unsed)
* Tue Aug  6 2002 arvin@suse.de
- don't start vnc server twice after reboot during installation
  (bug #17415)
* Mon Aug  5 2002 arvin@suse.de
- even more changed for new /etc/install.inf agent
* Mon Aug  5 2002 ms@suse.de
- do not call module x11 if serial_console or vnc session
  is active: (#17233)
* Mon Aug  5 2002 kkaempf@suse.de
- call "/create_interface <destdir>" on S/390 in order to get network
  setup data to installed system.
* Mon Aug  5 2002 arvin@suse.de
- further changed for new /etc/install.inf agent
* Sat Aug  3 2002 arvin@suse.de
- removed option -noxim for qt frontend since bug #17161 is now
  solved by changes to yast2-qt
* Fri Aug  2 2002 arvin@suse.de
- run qt frontend with option -noxim (bug #17161)
- configure only network card on iSeries
* Fri Aug  2 2002 olh@suse.de
- export Y2DEBUG and increase logsize in YaST2.firstboot when
  booted with 'debug'
* Wed Jul 31 2002 msvec@suse.cz
- remove MakeCDLinks from inst_finish.ycp (#17309)
* Wed Jul 31 2002 msvec@suse.cz
- new agent for /etc/install.inf
* Mon Jul 29 2002 arvin@suse.de
- fixed return value in inst_x11.ycp
* Fri Jul 26 2002 ms@suse.de
- add subdirectory x11 and include the base modules
  X11Version and inst_x11 to be present at any time
* Tue Jul 23 2002 olh@suse.de
- new kernel names and binaries for ppc.
* Tue Jul 23 2002 olh@suse.de
- add -httpd /usr/share/vnc/classes to inst_setup_vnc
* Sat Jul 20 2002 olh@suse.de
- use WFM::Execute (.local to copy vnc data to target directory
* Fri Jul 19 2002 fehr@suse.de
- removed writing of /etc/fstab from inst_finish it is now in
  inst_prepdisk
- version 2.6.5
* Thu Jul 18 2002 fehr@suse.de
- moved variable immediate_prepdisk from module Installation to
  module Storage.
* Wed Jul 17 2002 arvin@suse.de
- fixed S390 reboot message (bug #17049)
* Tue Jul 16 2002 sh@suse.de
- provide/obsolete yast2-trans-inst-proposal and
  yast2-trans-inst-general
* Wed Jul 10 2002 arvin@suse.de
- omit keyboard, mouse and bootloader in initial proposal on s390
- fixed location of ycp data files
* Thu Jul  4 2002 arvin@suse.de
- moved non binary files to /usr/share/YaST2
* Mon Jun 24 2002 kkaempf@suse.de
- New package: split off purely installation related code
  from yast2.rpm
